@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
@@ -31,7 +31,7 @@
 #include <kseparator.h>
 #include <klocale.h>
 #include <kapplication.h>
-
+#include <kstdguiitem.h>
 
 #include <unistd.h>
 #include "execdlg.h"
@@ -42,7 +42,7 @@
 #ifndef KDE_USE_FINAL
 static void min_size(QWidget *w) {
   w->setMinimumSize(w->sizeHint());
-} 
+}
 #endif
 
 ExecDlg::ExecDlg(QWidget *parent, ExecutableStructure *structure)
@@ -115,14 +115,14 @@ ExecDlg::ExecDlg(QWidget *parent, ExecutableStructure *structure)
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"), this, SLOT( help() ));
+	bbox->addButton(KStdGuiItem::help().text(), this, SLOT( help() ));
 
 	bbox->addStretch(1);
 
-	QButton *savebutton = bbox->addButton(i18n("&Save As..."));
+	QButton *savebutton = bbox->addButton(KStdGuiItem::saveAs().text());
 	connect( savebutton, SIGNAL( clicked() ), SLOT(saveSession() ) );
 
-	QButton *okbutton = bbox->addButton(i18n("&Quit"));
+	QButton *okbutton = bbox->addButton(KStdGuiItem::ok().text());
 	connect( okbutton, SIGNAL( clicked() ), SLOT(accept() ) );
 
 	bbox->layout();
