@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
@@ -110,8 +110,14 @@ void Module::initModule()
 	_pixmap = new QPixmap(iconloader.loadIcon(iconname, KIcon::User));
 	if(!_pixmap->height())
 	{
+		iconname = _name + ".png";
 		delete _pixmap;
-		_pixmap = 0;
+		_pixmap = new QPixmap( iconloader.loadIcon( iconname, KIcon::User ) );
+		if( !_pixmap->height() )
+		{
+			delete _pixmap;
+			_pixmap = 0;
+		}
 	}
 // try again without Arts:: - prefix
 
@@ -122,8 +128,14 @@ void Module::initModule()
 		_pixmap = new QPixmap(iconloader.loadIcon(iconname, KIcon::User));
 		if(!_pixmap->height())
 		{
+			iconname.replace( iconname.length() - 4, 3, "png" );
 			delete _pixmap;
-			_pixmap = 0;
+			_pixmap = new QPixmap(iconloader.loadIcon(iconname, KIcon::User));
+			if( !_pixmap->height() )
+			{
+				delete _pixmap;
+				_pixmap = 0;
+			}
 		}
 	}
 /*
@@ -423,3 +435,5 @@ QString Module::name()
 {
 	return _name;
 }
+
+// vim: sw=4 ts=4 noet
