@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
@@ -26,7 +26,7 @@
 #include <qlistbox.h>
 #include <kbuttonbox.h>
 #include <klocale.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
 #include <kapplication.h>
@@ -36,6 +36,7 @@
 #include <stdio.h>
 #include <arts/debug.h>
 #include <qpushbutton.h>
+#include <kstdguiitem.h>
 
 using namespace std;
 
@@ -110,7 +111,7 @@ PortPosDlg::PortPosDlg(QWidget *parent, Structure *structure) :QDialog(parent,"P
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("&Help"), this, SLOT( help() ));
+	bbox->addButton(KStdGuiItem::help().text(), this, SLOT( help() ));
 	bbox->addStretch(1);
 
 	KIconLoader iconloader;
@@ -125,7 +126,7 @@ PortPosDlg::PortPosDlg(QWidget *parent, Structure *structure) :QDialog(parent,"P
 	QButton *rename = bbox->addButton(i18n("R&ename..."));
 	connect( rename, SIGNAL( clicked() ), SLOT( rename() ));
 
-	QButton *okbutton = bbox->addButton(i18n("&OK"));
+	QButton *okbutton = bbox->addButton(KStdGuiItem::ok().text());
 	connect( okbutton, SIGNAL( clicked() ), SLOT(accept() ) );
 
 /*
@@ -186,12 +187,13 @@ void PortPosDlg::rename()
 	StructurePort *port = listports[i];
 	assert(port);
 
-	KLineEditDlg dlg(i18n("Enter port name:"), port->name(), this);
-	dlg.setCaption(i18n("Rename Port"));
-	if (dlg.exec())
+    bool ok;
+    QString name = KInputDialog::getText( i18n( "Rename Port" ),
+      i18n( "Enter port name:" ), port->name(), &ok, this );
+	if (ok)
 	{
 		arts_debug("rename OK...");
-		port->rename(dlg.text().local8Bit());
+		port->rename(name.local8Bit());
 	}
 	update();
 
