@@ -1,6 +1,6 @@
-	/*
+/*
 
-	Copyright (C) 1998 Stefan Westerfeld
+    Copyright (C) 1998 Stefan Westerfeld
                        stefan@space.twc.de
 
     This program is free software; you can redistribute it and/or modify
@@ -15,32 +15,36 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
 #include "choosebusdlg.h"
 
 #include <artsflow.h>
+
 #include <qlayout.h>
 #include <qlabel.h>
 #include <qlistbox.h>
+#include <qpushbutton.h>
+
 #include <kbuttonbox.h>
 #include <kseparator.h>
-#include <qbuttongroup.h>
-#include <qradiobutton.h>
-#include <qlineedit.h>
+#include <klineedit.h>
 #include <klocale.h>
 #include <kapplication.h>
-#include <qpushbutton.h>
+#include <kdebug.h>
+#include <kstdguiitem.h>
 
 using namespace std;
 
 static void min_size(QWidget *w) {
   w->setMinimumSize(w->sizeHint());
-} 
+}
 
-ChooseBusDlg::ChooseBusDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
+ChooseBusDlg::ChooseBusDlg(QWidget *parent)
+	: KDialog(parent,"X", TRUE)
+	, _newbusitemindex( -1 )
 {
 	setCaption(i18n("Choose Bus"));
 
@@ -82,6 +86,8 @@ ChooseBusDlg::ChooseBusDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 			listbox->insertItem((*destinations)[i].c_str());
 		delete destinations;
 	}
+	if( listbox->count() > 0 )
+		listbox->setCurrentItem( 0 );
 
 	mainlayout->addWidget(listbox);
 
@@ -92,25 +98,44 @@ ChooseBusDlg::ChooseBusDlg(QWidget *parent) :QDialog(parent,"X", TRUE)
 	mainlayout->addWidget(ruler);
 	mainlayout->addSpacing(5);
 
+// new bus lineedit
+
+	QBoxLayout * layout2 = new QHBoxLayout( mainlayout );
+	//mainlayout->addLayout( layout2 );
+	QLabel * newbuslabel = new QLabel( i18n( "New bus:" ), this );
+	layout2->addWidget( newbuslabel );
+	lineedit = new KLineEdit( this );
+	connect( lineedit, SIGNAL( textChanged( const QString & ) ), SLOT( textChanged( const QString & ) ) );
+	layout2->addWidget( lineedit );
+
+// hruler
+
+	mainlayout->addSpacing(5);
+	KSeparator *ruler3 = new KSeparator( KSeparator::HLine, this);
+	mainlayout->addWidget(ruler3);
+
+	mainlayout->addSpacing(5);
+
 // buttons
 
-	QHBoxLayout *buttonlayout = new QHBoxLayout;
 	mainlayout->addSpacing(5);
-	mainlayout->addLayout(buttonlayout);
+	QHBoxLayout *buttonlayout = new QHBoxLayout( mainlayout );
+	//mainlayout->addLayout(buttonlayout);
 	mainlayout->addSpacing(5);
 
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"), this, SLOT( help() ));
+	bbox->addButton(KStdGuiItem::help().text(), this, SLOT( help() ));
 	bbox->addStretch(1);
 
-	QButton *cancelbutton = bbox->addButton(i18n("Cancel"));
-	connect( cancelbutton, SIGNAL( clicked() ), SLOT(reject() ) );
-
-	QButton *okbutton = bbox->addButton(i18n("OK"));
+	QPushButton * okbutton = bbox->addButton(KStdGuiItem::ok().text());
+	okbutton->setDefault( true );
 	connect( okbutton, SIGNAL( clicked() ), SLOT(accept() ) );
 
+	QButton *cancelbutton = bbox->addButton(KStdGuiItem::cancel().text());
+	connect( cancelbutton, SIGNAL( clicked() ), SLOT(reject() ) );
+
 	bbox->layout();
 
 	buttonlayout->addWidget(bbox);
@@ -132,4 +157,28 @@ void ChooseBusDlg::help()
 {
 	KApplication::kApplication()->invokeHelp("", "artsbuilder");
 }
+
+void ChooseBusDlg::textChanged( const QString & busname )
+{
+	if( ! busname.isEmpty() )
+	{
+		if( _newbusitemindex > -1 )
+			listbox->changeItem( busname, _newbusitemindex );
+		else
+		{
+			_newbusitemindex = listbox->count();
+			listbox->insertItem( busname, _newbusitemindex );
+			listbox->setCurrentItem( _newbusitemindex );
+		}
+	}
+	else
+	{
+		listbox->removeItem( _newbusitemindex );
+		listbox->setCurrentItem( _newbusitemindex - 1 );
+		_newbusitemindex = -1;
+	}
+}
+
 #include "choosebusdlg.moc"
+
+// vim: sw=4 ts=4
