@@ -1,6 +1,6 @@
-	/*
+/*
 
-	Copyright (C) 1998 Stefan Westerfeld
+    Copyright (C) 1998 Stefan Westerfeld
                        stefan@space.twc.de
 
     This program is free software; you can redistribute it and/or modify
@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     */
 
@@ -79,11 +79,15 @@ MidiPortDlg::MidiPortDlg(QWidget *parent, const char *oldname, const char *title
 	buttonlayout->addSpacing(5);
 	KButtonBox *bbox = new KButtonBox(this);
 
-	bbox->addButton(i18n("Help"), this, SLOT( help() ));
+	QPushButton *helpbutton = bbox->addButton(i18n("Help"), this, SLOT( help() ));
 	bbox->addStretch(1);
+	helpbutton->setAutoDefault( true );
+	helpbutton->setDefault( true );
 
-	QButton *okbutton = bbox->addButton(i18n("OK"));
+	QPushButton *okbutton = bbox->addButton(i18n("OK"));
 	connect( okbutton, SIGNAL( clicked() ), SLOT(accept() ) );
+	okbutton->setAutoDefault( true );
+	okbutton->setDefault( true );
 
 	bbox->layout();
 
