@@ -39,7 +39,7 @@ static KCmdLineOptions options[] =
 #ifndef NDEBUG
 	{ "qdebug", I18N_NOOP("Turn on Qt Debug output"), 0 },
 #endif
-	{ 0, 0, 0}
+	KCmdLineLastOption
 };
 
 int main(int argc, char **argv)
