@@ -17,7 +17,7 @@
  **/
 
 #include "job.h"
-#include "kmacroexpander.h"
+#include <kmacroexpander.h>
 
 // Clean up the string so that it doesn't wander off to unexpected directories
 static QString sanitize(const QString &s)
@@ -43,13 +43,11 @@ void Job::replaceSpecialChars(QString &str, bool quote, QMap<QString, QString> _
   map.insert("artist", sanitize(group));
   map.insert("year", QString::number(year));
   map.insert("song", sanitize(song));
-  if( track < 10 )
-      map.insert("track", "0" + QString::number(track) );
-  else
-      map.insert("track", QString::number(track) );
+  map.insert("track", QString().sprintf("%02d", track));
 
   if (quote)
-      KAudioCreatorNS::KHandDelimitedMacroMapExpander::expandMacrosShellQuote(str, map);
+      str = KMacroExpander::expandMacrosShellQuote(str, map);
   else
-      KAudioCreatorNS::KHandDelimitedMacroMapExpander::expandMacros(str, map);
+      str = KMacroExpander::expandMacros(str, map);
 }
+
