@@ -62,7 +62,7 @@ KAboutData *KMidFactory::aboutData()
         I18N_NOOP("(c) 1997,98,99,2000, Antonio Larrosa Jimenez"),"",
         "http://perso.wanadoo.es/antlarr/kmid.html");
     aboutdata->addAuthor("Antonio Larrosa Jimenez",
-        I18N_NOOP("Original Developer/Mantainer"),"larrosa@kde.org",
+        I18N_NOOP("Original Developer/Maintainer"),"larrosa@kde.org",
         "http://perso.wanadoo.es/antlarr/index.html");
     return aboutdata;
 }
@@ -87,7 +87,7 @@ KInstance *KMidFactory::instance()
   setWidget(widget);
 
   // create and connect our actions
-   (void)new KAction(i18n("Play"), "1rightarrow", 0, this,
+   (void)new KAction(i18n("Play"), "player_play", 0, this,
       SLOT(slotPlay()), actionCollection(),
       "play");
 
