@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
@@ -71,19 +71,19 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     cfg->setGroup("KMid");
     midifile_opened=0L;
     loopsong=cfg->readNumEntry("Loop",0);
-    collectionplaymode=0;	
+    collectionplaymode=0;
     collectionplaylist=0L;
     channelView=0L;
     noteArray=0L;
     shuttingdown=false;
-    
+
     KConfig *kconf=KGlobal::instance()->config();
-    
-    kconf->setGroup("KMid"); 
+
+    kconf->setGroup("KMid");
     QString tmp2 = locateLocal("appdata", "collections");
-    collectionsfile=kconf->readEntry("CollectionsFile",tmp2);
+    collectionsfile=kconf->readPathEntry("CollectionsFile",tmp2);
     slman=new SLManager();
-    slman->loadConfig(collectionsfile.ascii());
+    slman->loadConfig(QFile::encodeName(collectionsfile));
     currentsl=NULL;
     //	currentsl=slman->getCollection(activecollection);
     itsme=0;
@@ -92,13 +92,13 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     timebar->setSteps(30000,60000);
     timebar->setValue(0);
     connect (timebar,SIGNAL(valueChanged(int)),this,SLOT(slotSeek(int)));
-    
+
     timetags = new QSliderTime(timebar,this);
     timetags->setMinimumSize(timetags->sizeHint());
- 
+
     qlabelTempo= new QLabel(i18n("Tempo:"), this,"tempolabel",
                             QLabel::NoFrame);
-    
+
     tempoLCD = new KLCDNumber( true, 3, this, "TempoLCD");
     tempoLCD->setValue(120);
     tempoLCD->display(120);
@@ -113,8 +113,8 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     connect (comboSongs,SIGNAL(activated(int)),this,SLOT(slotSelectSong(int)));
 
     rhythmview= new RhythmView( this, "RhythmView");
-    rhythmview->setMaximumHeight(7);   
-    rhythmview->setMinimumHeight(7);   
+    rhythmview->setMaximumHeight(7);
+    rhythmview->setMinimumHeight(7);
 
     volumebar = new QSlider(0,200,10,100,QSlider::Vertical, this );
     volumebar->setSteps(10,20);
@@ -126,21 +126,21 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
     visiblevolumebar=cfg->readNumEntry("ShowVolumeBar",0);
     if (visiblevolumebar) volumebar->show();
     else volumebar->hide();
-   
+
     typeoftextevents=1;
     kdispt=new KDisplayText( this, "KaraokeWindow");
     kdispt->show();
-    
-    timer4timebar=new QTimer(this);	
+
+    timer4timebar=new QTimer(this);
     connect (timer4timebar,SIGNAL(timeout()),this,SLOT(timebarUpdate()));
-    timer4events=new QTimer(this);	
+    timer4events=new QTimer(this);
     connect (timer4events,SIGNAL(timeout()),this,SLOT(processSpecialEvent()));
-    
-    QString samplefile = 
+
+    QString samplefile =
       KGlobal::dirs()->findAllResources("appdata", "fm/*.o3").last();
     samplefile.truncate(samplefile.findRev('/'));
-    FMOut::setFMPatchesDirectory(samplefile.ascii());
-    
+    FMOut::setFMPatchesDirectory(QFile::encodeName(samplefile));
+
     m_kMid.pctlsmID=shmget(IPC_PRIVATE,sizeof(PlayerController),0666 | IPC_CREAT );
     if (m_kMid.pctlsmID==-1)
     {
@@ -148,7 +148,7 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
                "Please report to larrosa@kde.org\n");
 	exit(1);
     }
-    
+
     m_kMid.pctl=(PlayerController *)shmat(m_kMid.pctlsmID,0L,0);
     if (!m_kMid.pctl)
         printf("ERROR: Can't get shared memory !!! "
@@ -163,30 +163,30 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
         m_kMid.pctl->forcepgm[i]=0;
         m_kMid.pctl->pgm[i]=0;
     }
-    
-    
-    kconf->setGroup("KMid"); 
+
+
+    kconf->setGroup("KMid");
     int mididev=kconf->readNumEntry("MidiPortNumber",-1);
-    
+
     midi = new DeviceManager(mididev);
     midi->initManager();
     m_kMid.midi=midi;
     player= new MidiPlayer(midi,m_kMid.pctl);
-    
+
     kconf->setGroup("Midimapper");
-    QCString qs=QFile::encodeName(kconf->readEntry("Loadfile","gm.map"));
-    
+    QCString qs=QFile::encodeName(kconf->readPathEntry("Loadfile","gm.map"));
+
 #ifdef KMidDEBUG
     printf("Read Config file: %s\n",qs.data());
 #endif
     setMidiMapFilename(qs.data());
-    
+
     initializing_songs=1;
-    kconf->setGroup("KMid"); 
+    kconf->setGroup("KMid");
     setActiveCollection(kconf->readNumEntry("ActiveCollection",0));
     initializing_songs=0;
-    
-    setMinimumSize(300,180);   
+
+    setMinimumSize(300,180);
 
     QVBoxLayout *lv=new QVBoxLayout( this );
     lv->addWidget( timebar );
@@ -205,7 +205,7 @@ kmidClient::kmidClient(QWidget *parent, KActionCollection *ac, const char *name)
 
 }
 
-/*void kmidClient::resizeEvent(QResizeEvent *) 
+/*void kmidClient::resizeEvent(QResizeEvent *)
 {
     //timebar->resize(width()-5,timebar->height());
     timebar->setGeometry(5,10,width()-5,timebar->height());
@@ -224,7 +224,7 @@ kmidClient::~kmidClient()
         stop();
         //    sleep(1);
     }
-    
+
     if (m_kMid.pid!=0)
     {
         kill(m_kMid.pid,SIGTERM);
@@ -234,8 +234,8 @@ kmidClient::~kmidClient()
     }
 
     allNotesOff();
-    
-    if (midifile_opened) delete midifile_opened;
+
+    delete midifile_opened;
     delete player;
     delete midi;
     delete [] collectionplaylist;
@@ -281,7 +281,7 @@ int kmidClient::openFile(const char *filename)
         QString errormsg;
         switch (r)
         {
-        case (-1) : errormsg = 
+        case (-1) : errormsg =
                             i18n("The file %1 doesn't exist or can't be opened.").arg(filename);
         break;
         case (-2) : errormsg =
@@ -306,10 +306,10 @@ int kmidClient::openFile(const char *filename)
         kdispt->ClearEv();
         kdispt->repaint(TRUE);
         topLevelWidget()->setCaption("KMid");
-        
-        return -1; 
+
+        return -1;
     }
-    
+
     if (midifile_opened) delete midifile_opened;
     midifile_opened=new char[strlen(filename)+1];
     strcpy(midifile_opened,filename);
@@ -324,13 +324,13 @@ int kmidClient::openFile(const char *filename)
     spev=player->specialEvents();
     while (spev)
     {
-        if ((spev->type==1) || (spev->type==5)) 
+        if ((spev->type==1) || (spev->type==5))
         {
             kdispt->AddEv(spev);
         }
         spev=spev->next;
     }
-    
+
     kdispt->calculatePositions();
     kdispt->CursorToHome();
 //    kdispt->updateScrollBars();
@@ -339,7 +339,7 @@ int kmidClient::openFile(const char *filename)
     tempoLCD->display(tempoToMetronomeTempo(m_kMid.pctl->tempo));
     currentTempo=tempoLCD->getValue();
     tempoLCD->setDefaultValue(tempoToMetronomeTempo(m_kMid.pctl->tempo)*m_kMid.pctl->ratioTempo);
-    
+
     char *fn=new char[strlen(filename)+20];
     extractFilename(filename,fn);
     char *capt=new char[strlen(fn)+20];
@@ -347,7 +347,7 @@ int kmidClient::openFile(const char *filename)
     delete fn;
     topLevelWidget()->setCaption(capt);
     delete capt;
-    
+
     timebar->setValue(0);
     return 0;
 }
@@ -355,8 +355,8 @@ int kmidClient::openFile(const char *filename)
 int kmidClient::openURL(const QString _url)
 {
     KURL u(_url);
-    if (u.isMalformed()) {printf("Malformed URL\n");return -1;};
-    
+    if (!u.isValid()) {printf("Malformed URL\n");return -1;};
+
     QString filename;
     bool deleteFile=false;
     if (!u.isLocalFile())
@@ -366,7 +366,7 @@ int kmidClient::openURL(const QString _url)
 	downloaded=false;
 	connect( iojob, SIGNAL( result( KIO::Job *) ), this, SLOT(downloadFinished( KIO::Job * ) ) );
 
-	if (!downloaded) 
+	if (!downloaded)
             kapp->enter_loop();
 	deleteFile=true;
 
@@ -378,7 +378,7 @@ int kmidClient::openURL(const QString _url)
 
     QCString filename_8bit = QFile::encodeName(filename);
     int r=-1;
-    if (!filename_8bit.isEmpty()) 
+    if (!filename_8bit.isEmpty())
     {
         r=openFile(filename_8bit.data());
 
@@ -395,8 +395,8 @@ ulong kmidClient::timeOfNextEvent(int *type)
 {
     int t=0;
     ulong x=0;
-    
-    
+
+
     if (!channelView)
     {
         if ((spev)&&(spev->type!=0))
@@ -437,16 +437,16 @@ ulong kmidClient::timeOfNextEvent(int *type)
                         t=2;
                         x=ncmd->ms;
                     }
-                    
+
                 }
             }
         }
     }
-    
+
     if (type) *type=t;
     return x;
     /*
-     
+
      if (type!=NULL) *type=0;
      if (channelView==NULL)
      {
@@ -457,7 +457,7 @@ ulong kmidClient::timeOfNextEvent(int *type)
      }
      else return 0;
      }
-     
+
     if (noteArray==NULL) return 0;
     noteCmd *ncmd=noteArray->get();
     if (ncmd==NULL)
@@ -488,7 +488,7 @@ ulong kmidClient::timeOfNextEvent(int *type)
                 if (type!=NULL) *type=2;
                 return ncmd->ms;
             }
-           
+
         }
     }
     */
@@ -526,7 +526,7 @@ void kmidClient::slotPlay()
     passcount=0;
 #endif
     noteArray->iteratorBegin();
-    
+
     QApplication::flushX();
     if ((m_kMid.pid=fork())==0)
     {
@@ -558,9 +558,9 @@ void kmidClient::slotPlay()
     ulong x=timeOfNextEvent(&type);
     if (type!=0)
         timer4events->start(x,TRUE);
-    
+
     timer4timebar->start(1000);
-    
+
 #ifdef KMidDEBUG
     printf("PlayerProcess: %d . ParentProcessID: %d\n",m_kMid.pid,getpid());
     printf("******************************-\n");
@@ -579,7 +579,7 @@ void kmidClient::timebarUpdate()
     gettimeofday(&tv, NULL);
     ulong currentmillisec=tv.tv_sec*1000+tv.tv_usec/1000;
     m_kMid.pctl->millisecsPlayed=(currentmillisec-beginmillisec);
-    
+
     timebar->setValue((int)(m_kMid.pctl->millisecsPlayed));
     itsme=0;
     if ((m_kMid.pctl->playing==0)&&(m_kMid.pctl->finished==1))
@@ -599,7 +599,7 @@ void kmidClient::slotSeek(int i)
 {
     if (itsme) return;
 
-    if (m_kMid.pctl->playing==0) 
+    if (m_kMid.pctl->playing==0)
     {
         itsme=1;
         timebar->setValue(0);
@@ -620,40 +620,40 @@ void kmidClient::slotSeek(int i)
         m_kMid.pid=0;
     }
     allNotesOff();
-    
-    
+
+
 #ifdef KMidDEBUG
     printf("change Time: %d\n",i);
 #endif
 
     timer4events->stop();
     if (channelView!=NULL) channelView->reset(0);
-    
+
     moveEventPointersTo((ulong)i);
-    
+
     m_kMid.pctl->playing=0;
     m_kMid.pctl->OK=0;
     m_kMid.pctl->error=0;
     m_kMid.pctl->gotomsec=i;
     m_kMid.pctl->message|=PLAYER_SETPOS;
-    
+
     QApplication::flushX();
     if ((m_kMid.pid=fork())==0)
     {
 #ifdef KMidDEBUG
         printf("Player_ProcessID: %d\n",getpid());
 #endif
-        
+
         player->play(0,(void (*)(void))kmidOutput);
-        
+
 #ifdef KMidDEBUG
         printf("End of child process\n");
 #endif
         _exit(0);
     }
-    
+
     while ((m_kMid.pctl->playing==0)&&(m_kMid.pctl->error==0)) ;
-    
+
     if (m_kMid.pctl->error==1) return;
     beginmillisec=m_kMid.pctl->beginmillisec-i;
     ulong currentmillisec=m_kMid.pctl->beginmillisec;
@@ -662,7 +662,7 @@ void kmidClient::slotSeek(int i)
     ulong x=timeOfNextEvent(&type);
     if (type!=0)
         timer4events->start(x-(currentmillisec-beginmillisec),TRUE);
-    
+
     /*
      if (spev==NULL) return;
      ulong delaymillisec=spev->absmilliseconds-(currentmillisec-beginmillisec);
@@ -687,7 +687,7 @@ void kmidClient::moveEventPointersTo(ulong ms)
     ulong tempo=(ulong)(500000 * m_kMid.pctl->ratioTempo);
     int num=4;
     int den=4;
-    
+
     while ((spev!=NULL)&&(spev->absmilliseconds<ms))
     {
         if (spev->type==3) tempo=spev->tempo;
@@ -699,7 +699,7 @@ void kmidClient::moveEventPointersTo(ulong ms)
     tempoLCD->setDefaultValue(tempoToMetronomeTempo(tempo)*m_kMid.pctl->ratioTempo);
 
     rhythmview->setRhythm(num,den);
-    
+
     kdispt->gotomsec(ms);
 //    if (noteArray!=NULL) noteArray->moveIteratorTo(ms);
     if (noteArray!=NULL)
@@ -715,7 +715,7 @@ void kmidClient::moveEventPointersTo(ulong ms)
             }
         }
     }
-    
+
     /*
      if (noteArray!=NULL)
      {
@@ -735,17 +735,17 @@ void kmidClient::slotSetVolume(int i)
 {
     int autochangemap=0;
     if ((m_kMid.pctl->playing==1)&&(m_kMid.pctl->paused==0)) autochangemap=1;
-    
+
     if (autochangemap)
     {
         pause();
     }
     i=200-i;
     m_kMid.pctl->volumepercentage=i;
-    
+
     if (autochangemap)
     {
-        pause(); 
+        pause();
     }
 }
 
@@ -765,7 +765,7 @@ void kmidClient::slotPrevSong()
      {
      int r;
      while ((r=1+(int) ((double)(currentsl->NumberOfSongs())*rand()/(RAND_MAX+1.0)))==currentsl->getActiveSongID()) ;
-     
+
      currentsl->setActiveSong(r);
      }
      */
@@ -773,19 +773,19 @@ void kmidClient::slotPrevSong()
     if (idx==0) return;
     idx--;
     currentsl->setActiveSong(collectionplaylist[idx]);
-    
+
     if (currentsl->getActiveSongID()==-1)
     {
         //    comboSongs->setCurrentItem(0);
         //    currentsl->setActiveSong(1);
         return;
     }
-    
+
     if (m_kMid.pctl->paused) emit stopPause();
     comboSongs->setCurrentItem(currentsl->getActiveSongID()-1);
     if (openURL(currentsl->getActiveSongName())==-1) return;
     play();
-    
+
 }
 
 void kmidClient::slotNextSong()
@@ -793,7 +793,7 @@ void kmidClient::slotNextSong()
     if (currentsl==NULL) return;
     if (collectionplaylist==NULL) generateCPL();
     if (collectionplaylist==NULL) return;
-    
+
     /*if (collectionplaymode==0)
      {
      if (currentsl->getActiveSongID()==currentsl->NumberOfSongs()) return;
@@ -803,7 +803,7 @@ void kmidClient::slotNextSong()
      {
      int r;
      while ((r=1+(int) ((double)(currentsl->NumberOfSongs())*rand()/(RAND_MAX+1.0)))==currentsl->getActiveSongID()) ;
-     
+
      #ifdef KMidDEBUG
      printf("random number:%d\n",r);
      #endif
@@ -820,7 +820,7 @@ void kmidClient::slotNextSong()
         //    currentsl->setActiveSong(1);
         return;
     }
-    
+
     if (m_kMid.pctl->paused) emit stopPause();
     comboSongs->setCurrentItem(currentsl->getActiveSongID()-1);
     if (openURL(currentsl->getActiveSongName())==-1) return;
@@ -844,7 +844,7 @@ void kmidClient::slotPause()
         }
         pausedatmillisec=(ulong)m_kMid.pctl->millisecsPlayed;
         m_kMid.pctl->paused=1;
-        timer4timebar->stop(); 
+        timer4timebar->stop();
         timer4events->stop();
         allNotesOff();
         //    kill(m_kMid.pid,SIGSTOP);
@@ -870,23 +870,23 @@ void kmidClient::slotPause()
 #endif
             _exit(0);
         }
-        
+
         while ((m_kMid.pctl->playing==0)&&(m_kMid.pctl->error==0)) ;
-        
+
         if (m_kMid.pctl->error) return;
 
         m_kMid.pctl->OK=0;
         m_kMid.pctl->paused=0;
-        
+
         beginmillisec=m_kMid.pctl->beginmillisec-pausedatmillisec;
         ulong currentmillisec=m_kMid.pctl->beginmillisec;
-        
+
         int type;
         ulong x=timeOfNextEvent(&type);
         if (type!=0)
             timer4events->start(x-(currentmillisec-beginmillisec),TRUE);
         timer4timebar->start(1000);
-        
+
         if (noteArray!=NULL)
         {
             int pgm[16];
@@ -901,7 +901,7 @@ void kmidClient::slotPause()
             }
 
         }
-       
+
     }
 }
 
@@ -926,7 +926,7 @@ void kmidClient::slotStop()
          tempoLCD->setDefaultValue(tempoToMetronomeTempo(m_kMid.pctl->tempo)*m_kMid.pctl->ratioTempo);
        }
     }
-    
+
     if (m_kMid.pctl->playing==0) return;
 
     if (m_kMid.pctl->paused) return;
@@ -995,11 +995,11 @@ void kmidClient::kmidOutput(void)
 // Should do nothing
     /*
     Midi_event *ev=pctl->ev;
-    
+
     timeval tv;
     gettimeofday(&tv, NULL);
     ulong currentmillisec=tv.tv_sec*1000+tv.tv_usec/1000;
-    
+
     if ((ev->command==MIDI_SYSTEM_PREFIX)&&((ev->command|ev->chn)==META_EVENT))
     {
         if ((ev->d1==5)||(ev->d1==1))
@@ -1016,7 +1016,7 @@ void kmidClient::kmidOutput(void)
             int tempo=(ev->data[0]<<16)|(ev->data[1]<<8)|(ev->data[2]);
             //	    printf("Change tempo: %d , %g, played at:%ld\n",tempo,tempoToMetronomeTempo(tempo),currentmillisec-beginmillisec);
         }
-       
+
     }
      */
 }
@@ -1042,7 +1042,7 @@ void kmidClient::processSpecialEvent()
     ulong x;
 
     long delaymillisec=~0;
-    
+
     while (processNext)
     {
         /*
@@ -1104,7 +1104,7 @@ void kmidClient::processSpecialEvent()
         x=timeOfNextEvent(&type);
 
         if (type==0) return;
-        
+
         timeval tv;
         ulong currentmillisec;
         gettimeofday(&tv, NULL);
@@ -1133,8 +1133,8 @@ void kmidClient::setSongType(int i)
 {
     int autochangetype=0;
     if ((m_kMid.pctl->playing==1)&&(m_kMid.pctl->paused==0)) autochangetype=1;
-    
-    if (autochangetype) 
+
+    if (autochangetype)
     {
         pause();
     }
@@ -1144,7 +1144,7 @@ void kmidClient::setSongType(int i)
     {
         pause();
     }
-    
+
 }
 
 
@@ -1179,15 +1179,15 @@ void kmidClient::setMidiMapFilename(const char *mapfilename)
     }
     int autochangemap=0;
     if ((m_kMid.pctl->playing==1)&&(m_kMid.pctl->paused==0)) autochangemap=1;
-    
+
     if (autochangemap)
     {
         pause();
     }
-    midi->setMidiMap(map); 
-    if (autochangemap) 
+    midi->setMidiMap(map);
+    if (autochangemap)
     {
-        pause(); 
+        pause();
     }
 }
 
@@ -1201,8 +1201,8 @@ void kmidClient::setActiveCollection(int i)
 {
     activecollection=i;
     KConfig *kconf=KGlobal::instance()->config();
-    
-    kconf->setGroup("KMid"); 
+
+    kconf->setGroup("KMid");
     kconf->writeEntry("ActiveCollection",activecollection);
     currentsl=slman->getCollection(activecollection);
     generateCPL();
@@ -1248,7 +1248,7 @@ void kmidClient::slotSelectSong(int i)
     if ((i<=0))  // The collection may be empty, or it may be just a bug :-)
     {
 #ifdef KMidDEBUG
-        printf("Empty\n"); 
+        printf("Empty\n");
 #endif
         emit stopPause();
         if (m_kMid.pctl->playing) stop();
@@ -1265,17 +1265,17 @@ void kmidClient::slotSelectSong(int i)
         topLevelWidget()->setCaption("KMid");
         return;
     }
-    
+
     if ((i==currentsl->getActiveSongID())&&(!initializing_songs)) return;
     int pl=0;
     if (m_kMid.pctl->playing==1) pl=1;
-    
+
     if (m_kMid.pctl->paused) emit stopPause();
     if (/*(i!=currentsl->getActiveSongID())&&*/(pl==1)) stop();
     currentsl->setActiveSong(i);
     if (openURL(currentsl->getActiveSongName())==-1) return;
     if (pl) play();
-    
+
 }
 
 
@@ -1296,9 +1296,9 @@ void kmidClient::generateCPL(void)
 {
     delete [] collectionplaylist;
     collectionplaylist=0;
-    
+
     if (currentsl==NULL) return;
-    
+
     if (collectionplaymode==0)
         collectionplaylist=generate_list(currentsl->NumberOfSongs());
     else
@@ -1318,7 +1318,7 @@ void kmidClient::saveCollections(void)
 #ifdef KMidDEBUG
     printf("Saving collections in: %s\n",collectionsfile.ascii());
 #endif
-    slman->saveConfig(collectionsfile.ascii());
+    slman->saveConfig(QFile::encodeName(collectionsfile));
 }
 
 void kmidClient::saveLyrics(FILE *fh)
@@ -1373,7 +1373,7 @@ void kmidClient::visibleChannelView(int i)
     {
         delete channelView;
         channelView=NULL;
-        
+
     }
     rethinkNextEvent();
 }
@@ -1389,19 +1389,19 @@ void kmidClient::rethinkNextEvent(void)
 {
     if (m_kMid.pctl->playing==0) return;
     timer4events->stop();
-    
+
     int type;
     ulong delaymillisec;
     ulong x=timeOfNextEvent(&type);
-    
+
     if (type==0) return;
-    
+
     timeval tv;
     ulong currentmillisec;
     gettimeofday(&tv, NULL);
     currentmillisec=tv.tv_sec*1000+tv.tv_usec/1000;
     delaymillisec=x-(currentmillisec-beginmillisec);
-    
+
     timer4events->start(delaymillisec,TRUE);
 }
 
@@ -1412,7 +1412,7 @@ void kmidClient::communicationFromChannelView(int *i)
     if ((i[0]==CHN_CHANGE_PGM)||((i[0]==CHN_CHANGE_FORCED_STATE)&&(i[3]==1)))
     {
         if ((m_kMid.pctl->playing==1)&&(m_kMid.pctl->paused==0)) autocontplaying=1;
-        
+
         if (autocontplaying)
         {
             pause();
@@ -1429,7 +1429,7 @@ void kmidClient::communicationFromChannelView(int *i)
             pause();
         }
     }
-    
+
 }
 
 void kmidClient::slotSetTempo(double value)
@@ -1448,7 +1448,7 @@ void kmidClient::slotSetTempo(double value)
     int autocontplaying=0;
 
     if ((m_kMid.pctl->playing==1)&&(m_kMid.pctl->paused==0)) autocontplaying=1;
-    
+
 
     if (autocontplaying)
     {
@@ -1467,7 +1467,7 @@ void kmidClient::slotSetTempo(double value)
     printf("ratio: (%.9g = %g ) tempo now: %g , new tempo %g\n",ratio,ratio,tempoToMetronomeTempo(m_kMid.pctl->tempo),value);
     printf("OldValue: %g , value %g\n",tempoLCD->getOldValue(),value);
 #endif
-    
+
     if (m_kMid.pctl->paused==1)
     {
         pausedatmillisec=(long)(((double)pausedatmillisec/m_kMid.pctl->ratioTempo)*ratio);
@@ -1486,26 +1486,26 @@ void kmidClient::slotSetTempo(double value)
     noteArray=player->noteArray();
     spev=player->specialEvents();
     currentTempo=value;
-    
+
     while (spev!=NULL)
     {
-        if ((spev->type==1) || (spev->type==5)) 
+        if ((spev->type==1) || (spev->type==5))
         {
             kdispt->AddEv(spev);
         }
         spev=spev->next;
     }
-    
+
     kdispt->calculatePositions();
     kdispt->CursorToHome();
     if (m_kMid.pctl->paused==1)
         moveEventPointersTo(pausedatmillisec);
-    
+
     if (autocontplaying)
     {
         pause();
     }
-    
+
 }
 
 void kmidClient::downloadFinished(KIO::Job *)
@@ -1571,7 +1571,7 @@ void kmidClient::setSongEncoding( int i )
 {
    KListAction *tmplistaction=
     ((KListAction*)actionCollection->action("file_type"));
- 
+
   tmplistaction->setCurrentItem(i);
 }
 void kmidClient::setLyricEvents( int i )
@@ -1587,6 +1587,6 @@ void kmidClient::setCurrentSong(int i)
 }
 void kmidClient::setPlayListMode(int i)
 {
-  ((KListAction*)actionCollection->action("play_order"))->setCurrentItem(i); 
+  ((KListAction*)actionCollection->action("play_order"))->setCurrentItem(i);
 }
 #include "kmidclient.moc"
