@@ -15,9 +15,9 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-    Send comments and bug fixes to antlarr@arrakis.es
+    Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
 
 ***************************************************************************/
@@ -103,6 +103,7 @@ private:
     void fillInComboSongs(void);
 
     int openFile(const char *filename);
+    void allNotesOff(void);
 public:
     kmidClient(QWidget *parent, KActionCollection *ac, const char *name=0);
     ~kmidClient();
