@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
@@ -28,7 +28,6 @@
 #include <sys/wait.h>
 #include <sys/stat.h>
 
-#include <qdragobject.h>
 #include <qkeycode.h>
 #include <qstring.h>
 
@@ -48,6 +47,8 @@
 #include <kdebug.h>
 #include <kaction.h>
 #include <kstdaction.h>
+#include <kurldrag.h>
+
 #include <dcopclient.h>
 
 #include "kmidframe.h"
@@ -65,7 +66,7 @@ kmidFrame::kmidFrame(const char *name)
     kmidclient->setSongType(1);
     kmidclient->show();
     setCentralWidget( kmidclient );
-/*    
+/*
     kKeysAccel=new KAccel(this);
     kKeysAccel->insertItem(i18n("Play/Pause"),"Play/Pause", Key_Space);
     kKeysAccel->connectItem("Play/Pause", this, SLOT(spacePressed()));
@@ -75,46 +76,46 @@ kmidFrame::kmidFrame(const char *name)
     kKeysAccel->connectItem("Previous Song",kmidclient,SLOT(song_PlayPrevSong()));
     kKeysAccel->insertItem(i18n("Next Song"),"Next Song", Key_Right);
     kKeysAccel->connectItem("Next Song",kmidclient,SLOT(song_PlayNextSong()));
-    kKeysAccel->insertItem(i18n("Scroll down karaoke"),"Scroll down karaoke",Key_Down);
-    kKeysAccel->connectItem("Scroll down karaoke",kmidclient->getKDisplayText(),SLOT(ScrollDown()));
-    kKeysAccel->insertItem(i18n("Scroll up karaoke"),"Scroll up karaoke",Key_Up);
-    kKeysAccel->connectItem("Scroll up karaoke",kmidclient->getKDisplayText(),SLOT(ScrollUp()));
-    kKeysAccel->insertItem(i18n("Scroll page down karaoke"),"Scroll page down karaoke",Key_PageDown);
-    kKeysAccel->connectItem("Scroll page down karaoke",kmidclient->getKDisplayText(),SLOT(ScrollPageDown()));
-    kKeysAccel->insertItem(i18n("Scroll page up karaoke"),"Scroll page up karaoke",Key_PageUp);
-    kKeysAccel->connectItem("Scroll page up karaoke",kmidclient->getKDisplayText(),SLOT(ScrollPageUp()));
+    kKeysAccel->insertItem(i18n("Scroll Down Karaoke"),"Scroll down karaoke",Key_Down);
+    kKeysAccel->connectItem("Scroll Down karaoke",kmidclient->getKDisplayText(),SLOT(ScrollDown()));
+    kKeysAccel->insertItem(i18n("Scroll Up Karaoke"),"Scroll up karaoke",Key_Up);
+    kKeysAccel->connectItem("Scroll Up Karaoke",kmidclient->getKDisplayText(),SLOT(ScrollUp()));
+    kKeysAccel->insertItem(i18n("Scroll Page Down Karaoke"),"Scroll page down karaoke",Key_PageDown);
+    kKeysAccel->connectItem("Scroll Page Down Karaoke",kmidclient->getKDisplayText(),SLOT(ScrollPageDown()));
+    kKeysAccel->insertItem(i18n("Scroll Page Up Karaoke"),"Scroll page up karaoke",Key_PageUp);
+    kKeysAccel->connectItem("Scroll Page Up Karaoke",kmidclient->getKDisplayText(),SLOT(ScrollPageUp()));
 
     kKeysAccel->readSettings();
 */
     KStdAction::open(this, SLOT(file_Open()), actionCollection());
-    (void)new KAction(i18n("&Save Lyrics..."), 0, this, 
+    (void)new KAction(i18n("&Save Lyrics..."), 0, this,
 	SLOT(file_SaveLyrics()), actionCollection(), "file_save_lyrics");
     KStdAction::quit(kapp, SLOT(quit()), actionCollection());
 
-    (void)new KAction(i18n("&Play"), "1rightarrow", Qt::Key_Space, 
-		kmidclient, SLOT(slotPlay()), actionCollection(), "song_play"); 
-    (void)new KAction(i18n("P&ause"), "player_pause", Qt::Key_P, kmidclient, 
-			SLOT(slotPause()), actionCollection(), "song_pause"); 
-    (void)new KAction(i18n("&Stop"), "player_stop", Qt::Key_Backspace, 
-		kmidclient, SLOT(slotStop()), actionCollection(), "song_stop"); 
+    (void)new KAction(i18n("&Play"), "player_play", Qt::Key_Space,
+		kmidclient, SLOT(slotPlay()), actionCollection(), "song_play");
+    (void)new KAction(i18n("P&ause"), "player_pause", Qt::Key_P, kmidclient,
+			SLOT(slotPause()), actionCollection(), "song_pause");
+    (void)new KAction(i18n("&Stop"), "player_stop", Qt::Key_Backspace,
+		kmidclient, SLOT(slotStop()), actionCollection(), "song_stop");
 
-    (void)new KAction(i18n("P&revious Song"), "player_start", Key_Left, 
+    (void)new KAction(i18n("P&revious Song"), "player_start", Key_Left,
 		kmidclient, SLOT(slotPrevSong()), actionCollection(),
-		"song_previous");  
-    (void)new KAction(i18n("&Next Song"), "player_end", Key_Right, 
-		kmidclient, SLOT(slotNextSong()), actionCollection(), 
-		"song_next");  
+		"song_previous");
+    (void)new KAction(i18n("&Next Song"), "player_end", Key_Right,
+		kmidclient, SLOT(slotNextSong()), actionCollection(),
+		"song_next");
     (void)new KToggleAction(i18n("&Loop"), 0, this, SLOT(song_Loop()),
-		actionCollection(), "song_loop");  
+		actionCollection(), "song_loop");
 
-    (void)new KAction(i18n("Rewind"), "2leftarrow", 0, kmidclient, 
-		SLOT(slotRewind()), actionCollection(), "song_rewind");  
+    (void)new KAction(i18n("Rewind"), "2leftarrow", 0, kmidclient,
+		SLOT(slotRewind()), actionCollection(), "song_rewind");
 
     (void)new KAction(i18n("Forward"), "2rightarrow", 0, kmidclient,
-		SLOT(slotForward()), actionCollection(), "song_forward");  
+		SLOT(slotForward()), actionCollection(), "song_forward");
 
     (void)new KAction(i18n("&Organize..."), 0, this, SLOT(collect_organize()),
-		actionCollection(), "collect_organize");  
+		actionCollection(), "collect_organize");
 
     QStringList playmodes;
     playmodes.append(i18n("In Order"));
@@ -123,15 +124,15 @@ kmidFrame::kmidFrame(const char *name)
     KSelectAction *act=new KSelectAction(i18n("Play Order"), 0, /*this, SLOT(collect_PlayOrder(int)),*/
                       actionCollection(), "play_order");
     connect(act,SIGNAL(activated(int)),this, SLOT(collect_PlayOrder(int)));
-    act->setItems(playmodes);  
+    act->setItems(playmodes);
+
+    (void)new KToggleAction(i18n("Auto-Add to Collection"), 0, this,
+	SLOT(collect_AutoAdd()), actionCollection(), "collect_autoadd");
 
-    (void)new KToggleAction(i18n("Auto-Add to Collection"), 0, this, 
-	SLOT(collect_AutoAdd()), actionCollection(), "collect_autoadd"); 
-    
     playmodes.clear();
     playmodes.append(i18n("&General MIDI"));
     playmodes.append(i18n("&MT-32"));
-    
+
     act=new KSelectAction(i18n("File Type"), 0,/* this, SLOT(options_FileType(int)),*/
                       actionCollection(), "file_type");
     connect(act,SIGNAL(activated(int)),this, SLOT(options_FileType(int)));
@@ -142,12 +143,12 @@ kmidFrame::kmidFrame(const char *name)
     playmodes.append(i18n("&Lyric Events"));
 
     act=new KSelectAction(i18n("Display Events"), Key_T, /*this,
-		SLOT(options_DisplayEvents(int)),*/ actionCollection(), 
+		SLOT(options_DisplayEvents(int)),*/ actionCollection(),
 		"display_events");
     connect(act,SIGNAL(activated(int)),this, SLOT(options_DisplayEvents(int)));
-    act->setItems(playmodes);  
+    act->setItems(playmodes);
 
-    (void)new KToggleAction(i18n("Automatic Text Chooser"), 0, this, 
+    (void)new KToggleAction(i18n("Automatic Text Chooser"), 0, this,
 		SLOT(options_AutomaticText()), actionCollection(),
 		"option_automatictext");
 
@@ -194,16 +195,16 @@ kmidFrame::kmidFrame(const char *name)
     if (cfg->readNumEntry("Loop",0)==1)
 	((KToggleAction*)actionCollection()->action("song_loop"))->setChecked(true);
 
-    if (cfg->readNumEntry("ShowVolumeBar",0)==1) 
+    if (cfg->readNumEntry("ShowVolumeBar",0)==1)
 	((KToggleAction*)actionCollection()->action("toggle_volumebar"))->setChecked(true);
-    
+
 
     tmplistaction=((KSelectAction*)actionCollection()->action("play_order"));
     if (cfg->readNumEntry("CollectionPlayMode",0)==0)
         tmplistaction->setCurrentItem(0);
     else
         tmplistaction->setCurrentItem(1);
-    
+
     if ((cfg->readNumEntry("AutoAddToCollection",0))==1)
 	((KToggleAction*)actionCollection()->action("collect_autoadd"))->setChecked(true);
 
@@ -214,10 +215,10 @@ kmidFrame::kmidFrame(const char *name)
 
     connect( kmidclient, SIGNAL( mustRechooseTextEvent() ),
              this, SLOT( rechooseTextEvent() ) );
-    
+
     connect( kmidclient, SIGNAL( stopPause() ),
              this, SLOT( song_stopPause() ) );
-    
+
 //    connect( kmidclient, SIGNAL( channelView_Destroyed() ),
 //             this, SLOT( channelViewDestroyed() ) );
 
@@ -228,20 +229,20 @@ kmidFrame::kmidFrame(const char *name)
 //        printf("Opening command line file...\n");
         int backautoadd=cfg->readNumEntry("AutoAddToCollection",0);
         cfg->writeEntry("AutoAddToCollection",0);
-        
+
         char ttt[40];
         sprintf(ttt,"%d",kapp->argc());
         int i=0;
         int c=autoAddSongToCollection( args->url( 0 ).path() , 1 );
         i++;
-        while (i<args->count()) 
+        while (i<args->count())
         {
             autoAddSongToCollection( args->url( i ).path() , 0 );
-            i++; 
+            i++;
         }
-        
+
         kmidclient->setActiveCollection(c);
-        
+
         ///	    kmidclient->openURL((kapp->argv())[1]);
         /*	    if ((cfg->readNumEntry("AutomaticTextEventChooser",1))==1)
          {
@@ -253,7 +254,7 @@ kmidFrame::kmidFrame(const char *name)
         if (kmidclient->midiFileName()!=NULL) kmidclient->play();
         cfg->writeEntry("AutoAddToCollection",backautoadd);
     }
-    
+
     args->clear();
         /*
          kKeys->addKey("Play/Pause",Key_Space);
@@ -277,16 +278,16 @@ kmidFrame::~kmidFrame()
 void kmidFrame::file_Open()
 {
   KURL url = KFileDialog::getOpenURL(QString::null, "*.kar *.mid *.kar.gz *.mid.gz\n*.kar *.kar.gz\n*.mid *.mid.gz\n*",this);
-    
+
   if( url.isEmpty() )
     return;
-      
+
   if( !url.isLocalFile() )
   {
     KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
     return;
   }
-      
+
   openURL(url.path());
 }
 
@@ -294,9 +295,9 @@ void kmidFrame::file_Open()
 
 void kmidFrame::song_stopPause()
 {
-  if (kmidclient->isPaused()) 
+  if (kmidclient->isPaused())
   {
-    //   song_Pause(); 
+    //   song_Pause();
     ((KToggleAction*)actionCollection()->action("song_pause"))->setChecked(false);
     kmidclient->pause();
   }
@@ -354,7 +355,7 @@ int kmidFrame::autoAddSongToCollection(const QString& filename,int setactive)
     if (setactive) slman->createTemporaryCollection();
     sl=slman->getCollection(0);
     if (filename==NULL) sl->AddSong(kmidclient->midiFileName());
-    else sl->AddSong(filename.ascii());
+    else sl->AddSong(QFile::encodeName(filename));
   }
   else
   {
@@ -364,49 +365,64 @@ int kmidFrame::autoAddSongToCollection(const QString& filename,int setactive)
     if (sl==NULL) return 0;
     int id;
     if (filename==NULL) id=sl->AddSong(kmidclient->midiFileName());
-    else id=sl->AddSong(filename.ascii());
+    else id=sl->AddSong(QFile::encodeName(filename));
     if (setactive)
-    { 
+    {
       sl->setActiveSong(id);
     }
   }
   return r;
 }
 
-void kmidFrame::urlDrop_slot(QDropEvent* e) 
+void kmidFrame::urlDrop_slot(QDropEvent* e)
 {
   dropEvent(e);
-}                                                                                
+}
 
 void kmidFrame::dragEnterEvent(QDragEnterEvent* e)
 {
-  e->accept(QUriDrag::canDecode(e));
-}  
+  e->accept(KURLDrag::canDecode(e));
+}
 
 void kmidFrame::dropEvent( QDropEvent * event )
 {
-  QStringList list;
-  QUriDrag::decodeToUnicodeUris(event, list);
-  
+  KURL::List list;
+  KURLDrag::decode(event, list);
+
   if (list.count()==0) return;
 
-  QStringList::ConstIterator it = list.begin();
+  bool first = true;
+  int c = true;
 
-  int c = autoAddSongToCollection(*it,1);
-  
-  for (it++ ; it != list.end(); it++) {
-    autoAddSongToCollection(*it,0);
+  for (KURL::List::ConstIterator it = list.begin();
+       it != list.end(); ++it)
+  {
+     if (!(*it).isLocalFile())
+        continue;
+
+     if (first)
+     {
+         c = autoAddSongToCollection((*it).path(),1);
+         first = false;
+     }
+     else
+     {
+         autoAddSongToCollection((*it).path(),0);
+     }
   }
 
-  kmidclient->setActiveCollection(c);
+  if (!first)
+  {
+     kmidclient->setActiveCollection(c);
 
-  if ((!kmidclient->isPlaying())&&(kmidclient->midiFileName()!=NULL))
+     if ((!kmidclient->isPlaying())&&(kmidclient->midiFileName()!=NULL))
 		kmidclient->play();
-}  
+  }
+}
 
 void kmidFrame::shuttingDown()
 {
-   if (kmidclient->isPlaying()==1) 
+   if (kmidclient->isPlaying()==1)
    {
 //      kmidclient->stop();
       kmidclient->shuttingDown();
@@ -435,10 +451,10 @@ void kmidFrame::readProperties(KConfig *cfg)
   kmidclient->setActiveCollection(activecol);
   kmidclient->slotSelectSong(activesong-1);
 
-  if ((activecol==0)&&(wasplaying)) // It was the temporary collection, 
-  {		// surely the user would like to continue 
+  if ((activecol==0)&&(wasplaying)) // It was the temporary collection,
+  {		// surely the user would like to continue
     // hearing the song
-    QString s = cfg->readEntry("File",QString::null);
+    QString s = cfg->readPathEntry("File");
     int c=autoAddSongToCollection(s,1);
     kmidclient->setActiveCollection(c);
   }
@@ -448,7 +464,7 @@ void kmidFrame::readProperties(KConfig *cfg)
 
 void kmidFrame::options_MidiSetup()
 {
-  if (kmidclient->devman()->checkInit()<0) 
+  if (kmidclient->devman()->checkInit()<0)
   {
     KMessageBox::error(this,
 	i18n("Couldn't open /dev/sequencer to get some info.\nProbably there is another program using it."));
@@ -457,15 +473,15 @@ void kmidFrame::options_MidiSetup()
   MidiConfigDialog *dlg;
 
   dlg=new MidiConfigDialog(kmidclient->devman(),NULL,"MidiDialog");
-  if (dlg->exec() == QDialog::Accepted) 
+  if (dlg->exec() == QDialog::Accepted)
   {
     KConfig *cfg=kapp->config();
     cfg->setGroup("KMid");
     cfg->writeEntry("MidiPortNumber",MidiConfigDialog::selecteddevice);
     kmidclient->setMidiDevice(MidiConfigDialog::selecteddevice);
-    cfg->setGroup("Midimapper"); 
-    cfg->writeEntry("LoadFile",
-	(MidiConfigDialog::selectedmap==NULL)? "":MidiConfigDialog::selectedmap);
+    cfg->setGroup("Midimapper");
+    cfg->writePathEntry("LoadFile",
+	(MidiConfigDialog::selectedmap==NULL)? QString::null:MidiConfigDialog::selectedmap);
     kmidclient->setMidiMapFilename(MidiConfigDialog::selectedmap);
   }
   delete dlg;
@@ -478,14 +494,14 @@ void kmidFrame::collect_organize()
   int idx=kmidclient->getActiveCollection();
 
   dlg=new CollectionDialog(slman,idx,NULL,"MidiDialog");
-  if (dlg->exec() == QDialog::Accepted) 
+  if (dlg->exec() == QDialog::Accepted)
     {
     kmidclient->setSLManager(slman);
     kmidclient->setActiveCollection(CollectionDialog::selectedC);
     kmidclient->slotSelectSong(
      (slman->getCollection(CollectionDialog::selectedC))->getActiveSongID()-1);
     }
-   else 
+   else
     {
     delete slman;
     }
@@ -549,15 +565,15 @@ void kmidFrame::file_SaveLyrics()
 
   QString filename = url.path();
   struct stat statbuf;
-  
-  if (stat(filename.ascii(), &statbuf)!=-1)
+
+  if (stat(QFile::encodeName(filename), &statbuf)!=-1)
   {
     QString s = i18n("File %1 already exists\nDo you want to overwrite it?").arg(filename);
     if (KMessageBox::warningYesNo(this,s)==1)
       return;
   }
 
-  FILE *fh=fopen(filename.ascii(),"wt");
+  FILE *fh=fopen(QFile::encodeName(filename),"wt");
   kmidclient->saveLyrics(fh);
   fclose(fh);
 }
@@ -581,9 +597,9 @@ void kmidFrame::options_ShowChannelView()
   if (!((KToggleAction*)actionCollection()->action("toggle_channelview"))->isChecked())
   {
     kmidclient->visibleChannelView(0);
-  } else 
+  } else
   {
-    kmidclient->visibleChannelView(1); 
+    kmidclient->visibleChannelView(1);
     connect (kmidclient->getChannelView(),SIGNAL(destroyMe()),this,SLOT(channelViewDestroyed()));
   }
 
@@ -592,7 +608,7 @@ void kmidFrame::options_ShowChannelView()
 void kmidFrame::channelViewDestroyed()
 {
   kmidclient->channelViewDestroyed();
-  ((KToggleAction*)actionCollection()->action("toggle_channelview"))->setChecked(false); 
+  ((KToggleAction*)actionCollection()->action("toggle_channelview"))->setChecked(false);
 }
 
 void kmidFrame::options_ChannelViewOptions()
@@ -600,7 +616,7 @@ void kmidFrame::options_ChannelViewOptions()
   ChannelViewConfigDialog *dlg;
 
   dlg=new ChannelViewConfigDialog(NULL,"ChannelViewConfigDialog");
-  if (dlg->exec() == QDialog::Accepted) 
+  if (dlg->exec() == QDialog::Accepted)
   {
     if (kmidclient->getChannelView())
       kmidclient->getChannelView()->lookMode(
@@ -617,7 +633,7 @@ void kmidFrame::slotConfigureKeys()
 
 void kmidFrame::openURL( const QString url )
 {
-  int c=autoAddSongToCollection(url.ascii(),1);
+  int c=autoAddSongToCollection(url,1);
   kmidclient->setActiveCollection(c);
 }
 
@@ -710,8 +726,8 @@ void kmidFrame::setCollectionPlayMode(int i)
 
 void kmidFrame::setMidiDevice(int i)
 {
-  
-  
+
+
 }
 */
 
