@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
     Send comments and bug fixes to larrosa@kde.org
     or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain
@@ -59,7 +59,7 @@ int main(int argc, char **argv)
     static KCmdLineOptions options[] =
     {
        { "+file", I18N_NOOP("File to open"), 0 },
-       { 0, 0, 0}
+       KCmdLineLastOption
     };
     KCmdLineArgs::addCmdLineOptions(options);
 
