@@ -21,6 +21,8 @@
  */
 
 #include "channel.h"
+#include <qcheckbox.h>
+#include <qlineedit.h>
 
 ChannelSetup::ChannelSetup(int num,QLineEdit *qleName, QCheckBox *qcbShow, QCheckBox *qcbSplit)
 {
