@@ -28,46 +28,30 @@
 #endif
 
 // include files for Qt
-#include <qstrlist.h>
-#include <qtabwidget.h>
+#include <qstring.h>
+#include <qmap.h>
+
+class QHBox;
+class QTimer;
+class QWidgetStack;
 
 // include files for KDE
-#include <kapplication.h>
 #include <kmainwindow.h>
-#include <kaccel.h>
-#include <kaction.h>
-#include <kiconloader.h>
-#include <kuniqueapplication.h>
-
-#include "mixer.h"
-
-class QTimer;
 
+class KAccel;
+class KComboBox;
 class KMixerWidget;
 class KMixerPrefWidget;
 class KMixPrefDlg;
 class KMixDockWidget;
 class KMixWindow;
+class Mixer;
 
-class KMixApp : public KUniqueApplication
-{
-Q_OBJECT
- public:
-    KMixApp();
-    ~KMixApp();
-    int newInstance ();
+#include "mixer.h"
 
-    public slots:
-    void quitExtended();  // For a hack on visibility()
 
- signals:
-    void stopUpdatesOnVisibility();
-    
- private:
-    KMixWindow *m_kmix;
-};
-
-class KMixWindow : public KMainWindow
+class 
+KMixWindow : public KMainWindow
 {
    Q_OBJECT
 
@@ -76,19 +60,21 @@ class KMixWindow : public KMainWindow
    ~KMixWindow();
 
   protected slots:
-   void saveConfig();
-  //   void dummySlot();
+   void saveSettings();
+
   protected:
+   void saveConfig();
    void loadConfig();
 
    void initMixer();
    void initPrefDlg();
    void initActions();
    void initWidgets();
+   void initMixerWidgets();
 
    void updateDocking();
 
-   void closeEvent( QCloseEvent * e );
+	bool queryClose();
    void showEvent( QShowEvent * );
    void hideEvent( QHideEvent * );
 
@@ -98,13 +84,13 @@ class KMixWindow : public KMainWindow
    void showHelp();
    void showAbout();
    void toggleMenuBar();
-   void closeMixer();
-   void newMixer();
    void loadVolumes();
    void saveVolumes();
    virtual void applyPrefs( KMixPrefDlg *prefDlg );
    void updateDockIcon();
+   void updateDockTip(Volume vol);
    void stopVisibilityUpdates();
+   void slotConfigureKeys();
 
   private:
    KAccel *m_keyAccel;
@@ -120,27 +106,34 @@ class KMixWindow : public KMainWindow
    bool m_startVisible;
    bool m_showMenubar;
    bool m_isVisible;
+   bool m_multiDriverMode;
    bool m_visibilityUpdateAllowed;
    int m_maxId;
 
    QPtrList<Mixer> m_mixers;
    QPtrList<KMixerWidget> m_mixerWidgets;
 
-   QTabWidget *m_tab;
-   QWidget *m_buttons;
+   QTimer *m_layoutTimer;
+   int m_lockedLayout;
+
+   QHBox* mixerNameLayout;
+   KComboBox *m_cMixer;
+   QWidgetStack *m_wsMixers;
    KMixPrefDlg *m_prefDlg;
    KMixDockWidget *m_dockWidget;
    QTimer *timer;	// Timer for reading volume from HW
-
-   bool isCategoryUsed(Mixer* mixer, MixDevice::DeviceCategory categoryMask);
+   QString m_hwInfoString;
+	QVBoxLayout *widgetsLayout;
+   //bool isCategoryUsed(Mixer* mixer, MixDevice::DeviceCategory categoryMask);
 
   private slots:
-   void insertMixerWidget( KMixerWidget *mw );
-   void removeMixerWidget( KMixerWidget *mw );
-   void updateLayout();
+   //void removeMixerWidget( KMixerWidget *mw );
+   //void updateLayout();
    void dockMute();
-
-   void toggleVisibility();
+   void slotHWInfo();
+	void showSelectedMixer( int mixer );
+	void triggerUpdateLayout();
+	void updateLayoutNow();
 };
 
 #endif // KMIX_H
