@@ -24,25 +24,30 @@
 #define KMIXDOCKWIDGET_H
 
 #include <qwidget.h>
+#include <qvbox.h>
 #include <ksystemtray.h>
 
 class Mixer;
 class QFrame;
+class KAudioPlayer;
+class KMixMasterVolume;
+class MixDeviceWidget;
 
 class KMixDockWidget : public KSystemTray  {
    Q_OBJECT
 
    friend class KMixWindow;
 
- public: 
+ public:
    KMixDockWidget(Mixer *, QWidget *parent=0, const char *name=0);
    ~KMixDockWidget();
 
    void updatePixmap();
    void setErrorPixmap();
+   void ignoreNextEvent();
 
- public slots:  
-   void setVolumeTip(int, Volume);
+ public slots:
+   void setVolumeTip(int, Volume );
 
  protected:
    void createMasterVolWidget();
@@ -54,8 +59,24 @@ class KMixDockWidget : public KSystemTray  {
 
  private:
    Mixer *m_mixer;
-   QFrame *masterVol;   
-   bool m_mixerVisible;
+   KMixMasterVolume *masterVol;
+   KAudioPlayer *audioPlayer;
+   bool m_playBeepOnVolumeChange;
+   bool m_ignoreNextEvent;
+};
+
+class KMixMasterVolume : public QVBox
+{
+    public:
+        KMixMasterVolume(QWidget* parent, const char* name, Mixer* mixer, KMixDockWidget *dockW);
+        ~KMixMasterVolume() {}
+        MixDeviceWidget* mixerWidget() { return mdw; }
+
+    protected:
+        MixDeviceWidget *mdw;
+        KMixDockWidget *dock;
+
+        void mousePressEvent(QMouseEvent *e);
 };
 
 #endif
