@@ -22,74 +22,110 @@
 #ifndef KMIXERWIDGET_H
 #define KMIXERWIDGET_H
 
-#include <kpanelapplet.h>
-
 #include <qwidget.h>
-#include <qcheckbox.h>
-#include <qlayout.h>
 #include <qptrlist.h>
-#include <qstring.h>
+class QString;
+class QGridLayout;
+
+#include <kpanelapplet.h>
+class KPopupMenu;
 
 #include "channel.h"
 #include "mixer.h"
+#include "mixdevicewidget.h"
 
-class Mixer;
+// QT
 class QSlider;
-class Channel;
+
+
+// KDE
 class KActionCollection;
+class KActionMenu;
 class KConfig;
+class KTabWidget;
+
+// KMix
+class Channel;
+class Mixer;
 
 
-class KMixerWidget : public QWidget  {
+class 
+Channel
+{
+   public:
+      Channel() : dev( 0 ) {};
+      ~Channel() { delete dev; };
+
+      MixDeviceWidget *dev;
+};
+
+class 
+KMixerWidget : public QWidget  
+{
    Q_OBJECT
 
   public:
-   KMixerWidget( int _id, Mixer *mixer, QString mixerName, int mixerNum,
+   KMixerWidget( int _id, Mixer *mixer, const QString &mixerName, int mixerNum,
                  bool small, KPanelApplet::Direction, MixDevice::DeviceCategory categoryMask = MixDevice::ALL ,
                  QWidget *parent=0, const char *name=0 );
    ~KMixerWidget();
+	
+   enum KMixerWidgetIO { OUTPUT=0, INPUT };
 
    void addActionToPopup( KAction *action );
 
-   QString name() { return m_name; };
-   void setName( QString name ) { m_name = name; };
+   QString name() const { return m_name; };
+   void setName( const QString &name ) { m_name = name; };
 
-   Mixer *mixer() { return m_mixer; };
-   QString mixerName() { return m_mixerName; };
-   int mixerNum() { return m_mixerNum; };
+   const Mixer *mixer() const { return m_mixer; };
+   QString mixerName()  const { return m_mixerName; };
+   int mixerNum() const { return m_mixerNum; };
 
-   int id() { return m_id; };
+   int id() const { return m_id; };
 
-   struct Colors {      
+   KPopupMenu* getPopup();
+   void popupReset();
+
+   KActionCollection* getActionCollection() const { return m_actions; }
+	
+   struct Colors {
        QColor high, low, back, mutedHigh, mutedLow, mutedBack;
    };
 
   signals:
    void updateLayout();
    void masterMuted( bool );
+   void newMasterVolume(Volume vol);
 
-  public slots:     
+  public slots:
    void setTicks( bool on );
    void setLabels( bool on );
    void setIcons( bool on );
    void setColors( const Colors &color );
-    
-   void saveConfig( KConfig *config, QString grp );
-   void loadConfig( KConfig *config, QString grp );
+   void hideShowDetail(bool on);
 
-   void showAll();
+   void saveConfig( KConfig *config, const QString &grp ) const;
+   void loadConfig( KConfig *config, const QString &grp );
 
-  private slots:	
-   void rightMouseClicked();	
+  private slots:
+   void rightMouseClicked();
    void updateBalance();
    void updateSize();
+   void slotFillPopup();
+   void slotToggleMixerDevice(int id);
 
   private:
    Mixer *m_mixer;
    QSlider *m_balanceSlider;
-   QBoxLayout *m_topLayout;
-   QBoxLayout *m_devLayout;
-   QPtrList<Channel> m_channels;
+   QWidget *m_swWidget;
+   QVBoxLayout *m_topLayout;
+   QBoxLayout *m_appletLayout;
+   QWidget *m_iWidget;
+   QWidget *m_oWidget;
+   QGridLayout *m_devSwitchLayout;
+	
+   mutable QPtrList<Channel> m_channels;
+   KTabWidget *m_ioTab;
 
    QString m_name;
    QString m_mixerName;
@@ -97,16 +133,21 @@ class KMixerWidget : public QWidget  {
    int m_id;
 
    KActionCollection *m_actions;
+   KActionMenu *m_toggleMixerChannels;
+   KPopupMenu *m_popMenu;
 
    bool m_small;
    KPanelApplet::Direction m_direction;
    bool m_iconsEnabled;
    bool m_labelsEnabled;
    bool m_ticksEnabled;
+   MixDevice::DeviceCategory m_categoryMask;
 
    void mousePressEvent( QMouseEvent *e );
-   void createDeviceWidgets( KPanelApplet::Direction, MixDevice::DeviceCategory categoryMask );
+   void createDeviceWidgets();
+   void createLayout();
    void createMasterVolWidget(KPanelApplet::Direction);
+   void updateSize(bool force);
 };
 
 #endif
