@@ -22,8 +22,11 @@
 
 #include <qlayout.h>
 #include <qwhatsthis.h>
+#include <qcheckbox.h>
 
 #include <klocale.h>
+// For "kapp"
+#include <kapplication.h>
 
 #include "kmix.h"
 #include "kmixprefdlg.h"
@@ -31,7 +34,7 @@
 
 
 KMixPrefDlg::KMixPrefDlg( QWidget *parent )
-    : KDialogBase(  Plain, i18n( "KMix Preferences" ),
+    : KDialogBase(  Plain, i18n( "Configure" ),
           Ok|Cancel|Apply, Ok, parent )
 {
    // general buttons
@@ -71,7 +74,16 @@ KMixPrefDlg::~KMixPrefDlg()
 
 void KMixPrefDlg::apply()
 {
+   // disabling buttons => users sees that we are working
+   enableButtonOK(false);
+   enableButtonCancel(false);
+   enableButtonApply(false);
+   kapp->processEvents();
    emit signalApplied( this );
+   // re-enable (in case of "Apply")
+   enableButtonOK(true);
+   enableButtonCancel(true);
+   enableButtonApply(true);
 }
 
 #include "kmixprefdlg.moc"
