@@ -25,26 +25,27 @@
 #include <kglobal.h>
 #include <kstandarddirs.h>
 
-#include "kmix.h"
+#include "KMixApp.h"
 #include "version.h"
 
-static const char *description =
+static const char description[] =
 I18N_NOOP("KMix - KDE's full featured mini mixer");
 
 static KCmdLineOptions options[] =
 {
-   { 0, 0, 0 }
+   KCmdLineLastOption
    // INSERT YOUR COMMANDLINE OPTIONS HERE
 };
 
-int main(int argc, char *argv[])
+extern "C" int kdemain(int argc, char *argv[])
 {
    KAboutData aboutData( "kmix", I18N_NOOP("KMix"),
                          APP_VERSION, description, KAboutData::License_GPL,
-                         I18N_NOOP("(c) 1996-2000 Christian Esken\n(c) 2000-2003  Christian Esken, Stefan Schimanski"));
+                         I18N_NOOP("(c) 1996-2000 Christian Esken\n(c) 2000-2003 Christian Esken, Stefan Schimanski\n(c) 2002-2003 Christian Esken, Helio Chissini de Castro"));
 
+   aboutData.addAuthor("Christian Esken", "Current maintainer", "esken@kde.org");
+   aboutData.addAuthor("Helio Chissini de Castro", I18N_NOOP("Current redesign, Alsa 0.9x port"), "helio@kde.org" );
    aboutData.addAuthor("Stefan Schimanski", 0, "schimmi@kde.org");
-   aboutData.addAuthor("Christian Esken", 0, "esken@kde.org");
    aboutData.addAuthor("Sven Leiber", 0, "s.leiber@web.de");
    aboutData.addAuthor("Brian Hanson", I18N_NOOP("Solaris port"), "bhanson@hotmail.com");
    aboutData.addAuthor("Paul Kendall", I18N_NOOP("SGI Port"), "paul@orion.co.nz");
@@ -53,7 +54,7 @@ int main(int argc, char *argv[])
    aboutData.addAuthor("Nick Lopez", I18N_NOOP("ALSA port"), "kimo_sabe@usa.net");
    aboutData.addAuthor("Helge Deller", I18N_NOOP("HP/UX port"), "deller@gmx.de");
    aboutData.addAuthor("Jean Labrousse", I18N_NOOP("NAS port"), "jean.labrousse@alcatel.com" );
-   aboutData.addAuthor("Helio Chissini de Castro", I18N_NOOP("ALSA 0.9x port"), "helio@conectiva.com.br" );
+   aboutData.addCredit("Nadeem Hasan", I18N_NOOP("Mute and volume preview, other fixes"), "nhasan@kde.org");
 
    KCmdLineArgs::init( argc, argv, &aboutData );
    KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
