@@ -190,9 +190,9 @@ int Mixer_SUN::openMixer()
          {
             Volume vol( 2, AUDIO_MAX_GAIN );
             readVolumeFromHW( idx, vol );
-            MixDevice* md = new MixDevice( idx, vol, 0,
+            MixDevice* md = new MixDevice( idx, vol, false, true,
                QString(MixerDevNames[idx]), MixerChannelTypes[idx]);
-            md->setRecsrc( isRecsrcHW( idx ) );
+				md->setRecSource( isRecsrcHW( idx ) );
             m_mixDevices.append( md );
          }
      }
@@ -476,3 +476,8 @@ void Mixer_SUN::GainBalanceToVolume( uint_t& gain, uchar_t& balance, Volume& vol
       }
    }
 }
+
+QString SUN_getDriverName() {
+        return "SUNAudio";
+}
+
