@@ -1,9 +1,9 @@
 
-/*   
+/*
    Kscd - A simple cd player for the KDE Project
 
-   $Id: inexact.h,v 1.9.8.2 2003/02/25 16:28:54 rnolden Exp $
- 
+   $Id: inexact.h,v 1.12 2003/03/27 18:24:44 nhasan Exp $
+
    Copyright (c) 1997 Bernd Johannes Wuebben math.cornell.edu
 
    This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
  */
@@ -28,17 +28,16 @@
 
 #include <stdlib.h>
 
-#include <qdialog.h>
-#include <qfont.h>
 #include <qstring.h>
-#include <qpainter.h>
 #include <qlabel.h>
+#include <qmultilineedit.h>
 #include <qpushbutton.h>
 #include <qlistbox.h>
 #include <qstrlist.h>
-#include <qmultilineedit.h>
 
-class InexactDialog : public QDialog {
+#include <kdialogbase.h>
+
+class InexactDialog : public KDialogBase {
 
 Q_OBJECT
 
@@ -48,7 +47,7 @@ public:
 
   void insertList(const QStringList& list);
   void insertText(const QString& str);
-  void getSelection(QString& string);
+  QString selection();
 
   void setTitle(const QString& t);
   void setErrorString(const QString& t);
@@ -59,9 +58,6 @@ private slots:
   void checkit();
 
 private:
-    bool            listbox;
-    QPushButton     *ok_button;
-    QPushButton     *cancel_button;
     QListBox 	    *list_box;
     QMultiLineEdit  *edit;
     QLabel 	    *statuslabel;
