@@ -1,7 +1,7 @@
 /*
    Kscd - A simple cd player for the KDE Project
 
-   $Id: kscd.h,v 1.64.2.1 2003/07/04 15:14:14 wstephens Exp $
+   $Id: kscd.h,v 1.86.2.2 2004/03/12 14:38:40 waba Exp $
 
    Copyright (c) 1997 Bernd Johannes Wuebben math.cornell.edu
 
@@ -17,7 +17,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 
  */
@@ -29,13 +29,16 @@
 
 #include "bwlednum.h"
 
+// CDDB support via libkcddb
+#include <libkcddb/cddb.h>
+#include <libkcddb/client.h>
+
 
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qdialog.h>
 #include <qapplication.h>
 #include <qtimer.h>
-#include <qbitmap.h>
 #include <qcombobox.h>
 #include <qscrollbar.h>
 #include <qslider.h>
@@ -74,10 +77,9 @@
 #define KSCDMAGIC 0
 #endif
 
-#include "cddb.h"
-#include "smtp.h"
-#include "ledlamp.h"
 
+#include "ledlamp.h"
+#include "panel.h"
 #include <kapplication.h>
 #include <kprocess.h>
 #include <krandomsequence.h>
@@ -86,9 +88,12 @@
 class CDDBSetup;
 class ConfigDlg;
 class CDDialog;
+class QGridLayout;
+class KActionCollection;
+class KVolumeControl;
 
-class SMTPConfig;
-struct SMTPConfigData;
+
+using namespace KCDDB;
 
 struct mgconfigstruct
 {
@@ -101,9 +106,8 @@ struct mgconfigstruct
 };
 
 typedef QValueList<int> RandomList;
-typedef QValueListIterator<int> RandomListIt;
 
-class KSCD : public QWidget, public KSessionManaged, virtual public DCOPObject {
+class KSCD : public kscdPanelDlg, public KSessionManaged, virtual public DCOPObject {
 
     Q_OBJECT
     K_DCOP
@@ -113,16 +117,11 @@ class KSCD : public QWidget, public KSessionManaged, virtual public DCOPObject {
 
 
 k_dcop:
-    /**
-     * Check KsCD's current state
-     */
-    bool playing();
     void play() { playClicked(); }
     void stop() { stopClicked(); }
     void previous() { prevClicked(); }
     void next() { nextClicked(); }
-    void forward() { fwdClicked(); }
-    void backward() { bwdClicked(); }
+    void jumpTo(int seconds) { jumpToTime(seconds); }
     void eject() { ejectClicked(); }
     void quit() { quitClicked(); }
     void toggleLoop() { loopClicked(); }
@@ -131,148 +130,115 @@ k_dcop:
     void cddbDialog() { CDDialogSelected(); }
     void optionDialog() { showConfig(); }
     void setTrack(int t) { trackSelected(t >= 1 ? t - 1 : 0); }
-    void setVolume(int v) { volChanged(v); volSB->setValue(v); }
+    void setVolume(int v);
     int  getVolume() { return volume; }
     int currentTrack();
     QString currentTrackTitle();
+    QString currentAlbum();
+    QString currentArtist();
     QStringList trackList();
-    void emailSettingsChanged();
 
 public:
     KSCD( QWidget *parent = 0, const char *name = 0 );
     ~KSCD();
-    void initialShow();
-	virtual bool saveState(QSessionManager& sm);
+    virtual bool saveState(QSessionManager& sm);
 
     bool dock() { return docking; }
     void setDocking(bool dock);
-    bool randomOnce() { return randomonce; }
-    void setRandomOnce(bool shuffle);
     bool stopOnExit() { return stopexit; }
     void setStopOnExit(bool stop) { stopexit = stop; }
     bool autoPlay() { return autoplay; }
     void setAutoplay(bool play) { autoplay = play; }
     bool ejectOnFinish() { return ejectonfinish; }
     void setEjectOnFinish(bool eject) { ejectonfinish = eject; }
+    bool digitalPlayback();
     unsigned int skipInterval() { return skipDelta; }
     void setSkipInterval(unsigned int skip) { skipDelta = skip; }
     QColor ledColor() { return led_color; }
     QColor bgColor() { return background_color; }
     void setColors(const QColor& LEDs, const QColor& bground);
-    void setToolTips(bool on);
-    bool toolTips() { return tooltips; }
-    void setDevicePath(QString path);
+    void setDevicePaths(QString cd_device, QString audio_system, QString audio_device);
     QString devicePath() { return cd_device_str; }
-    SMTPConfigData* smtpData() { return smtpConfigData; }
+    QString audioSystem() { return audio_system_str; }
+    QString audioDevice() { return audio_device_str; }
+    QStringList audioSystems() { return audio_systems_list; }
 
 signals:
     void trackChanged(const QString&);
     void newServerList(const QStringList&);
 
 public slots:
-    void smtpMessageSent(void);
-    void smtpError(int);
-    void magicdone(KProcess*);
-    void magicslot();
-    void magicslot(int);
-    void togglequeryled();
-    void cddb_done();
-    void cddb_timed_out();
-    void cddb_ready();
-    void edm_save_cddb_entry(QString& path);
-    void cddb_failed();
-    void randomSelected();
-    void readSettings();
-    void writeSettings();
     void setColors();
-    void playClicked();
+    void togglequeryled();
+    void randomSelected();
+    void setShuffle(bool shuffle);
+    void writeSettings();
     void initCDROM();
-    void stopClicked();
-    void prevClicked();
+    void playClicked();
     void nextClicked();
-    void fwdClicked();
-    void bwdClicked();
+    void prevClicked();
+    void stopClicked();
+    void ejectClicked();
+    void jumpToTime(int seconds);
     void quitClicked();
     void loopOn();
     void loopOff();
     void loopClicked();
     void cdMode();
-    void ejectClicked();
     void trackSelected( int );
     void showConfig();
     void incVolume();
     void decVolume();
     void volChanged( int );
-    void mycddb_inexact_read();
-    void cddb_no_info();
     void led_on();
     void led_off();
     void titlelabeltimeout();
-    void CDDialogSelected();
     void cycleplaytimemode();
     void cycletimeout();
-    void get_cddb_info(bool);
-    void CDDialogDone();
-    void getCDDBservers();
-    void getCDDBserversDone();
-    void getCDDBserversFailed();
-    void updateCurrentCDDBServer(const QString&);
+
     void performances(int);
     void purchases(int);
     void information(int);
     void jumpTracks();
 
-    /*
-     * TODO
-     * not the prettiest things in the world
-     * but getting rid of them will require some more work
-     * with the CDDB and magic config pages
-     */
-    void getCDDBOptions(CDDBSetup* config);
-    void setCDDBOptions(CDDBSetup* config);
-    void getMagicOptions(mgconfigstruct& config);
-    void setMagicOptions(const mgconfigstruct& config);
-
     void make_random_list(); /* koz: 15/01/00 */
 
 protected slots:
     void configDone();
+    void configureKeys();
+    void setIcons();
 
 protected:
+    // mostly start up stuff
+    void readSettings();
+    void initFont();
+    void initWorkMan();
+    void drawPanel();
+    void setupPopups();
+    void setLEDs(const QString& symbols);
+
     void closeEvent( QCloseEvent *e );
     void keyPressEvent( QKeyEvent* e );
     bool event( QEvent *e );
     //    void focusOutEvent(QFocusEvent *e);
     void playtime();
-    void setupPopups();
-    void startBrowser(const QString& querystring);
     bool getArtist(QString& artist);
-    void get_pathlist(QStringList& _patlist);
 
     void clearSongList();
     void setSongListTo(int whichTrack);
     void populateSongList();
- 
+    void updatePlayPB(bool playing);
+
 private:
-    SMTPConfigData  *smtpConfigData;
     ConfigDlg       *configDialog;
     CDDialog        *cddialog;
-    QPushButton     *playPB;
-    QPushButton     *stopPB;
-    QPushButton     *prevPB;
-    QPushButton     *nextPB;
-    QPushButton     *fwdPB;
-    QPushButton     *bwdPB;
-    QPushButton     *dockPB;
-    QPushButton     *magicPB;
-    QPushButton     *replayPB;
-    QPushButton     *ejectPB;
-    QPushButton     *aboutPB;
-    QPushButton     *infoPB;
     QPopupMenu      *mainPopup;
     QPopupMenu      *purchPopup;
     QPopupMenu      *infoPopup;
 
+    // ML XXX
+    QGridLayout		*outerLO;
+
     QColor              background_color;
     QColor              led_color;
     BW_LED_Number       *trackTimeLED[6];
@@ -283,64 +249,48 @@ private:
     QLabel              *tracklabel;
     QLabel              *totaltimelabel;
     QLabel              *nLEDs;
-    QPushButton         *optionsbutton;
-    QPushButton         *shufflebutton;
-    QPushButton         *cddbbutton;
     QTimer              timer;
     QTimer              titlelabeltimer;
     QTimer              queryledtimer;
     QTimer              cycletimer;
     QTimer              jumpTrackTimer;
-    QComboBox           *songListCB;
-    QSlider             *volSB;
 
-    // random plyalists
+    // random playlists
     KRandomSequence     randSequence;
     RandomList          random_list;
-    RandomListIt        random_current;
+    RandomList::iterator random_current;
+
 
-    KProcess*           magicproc;
     int                 jumpToTrack;
     unsigned int        skipDelta;
-    int                 volChnl;
-    int                 mixerFd;
     int                 volume;
-    int                 magic_width;
-    int                 magic_height;
-    int                 magic_brightness;
-    bool                magic_pointsAreDiamonds;
-    QFrame              *backdrop;
     LedLamp             *queryled;
     LedLamp             *loopled;
-    bool                tooltips;
-    bool                randomplay ;
+    bool                randomplay;
+    bool                randomplay_pending;
+    void song_list_complete(void);
     bool                looping;
-    bool                cycle_flag;
-    QString             cycle_str;
-    bool                volstartup;
     bool                cddrive_is_ok;
     bool                have_new_cd;
     int                 time_display_mode;
     QString             cd_device_str;
-    bool                hidden_controls;
+    QString             audio_system_str; /* arts, alsa or sun. empty means no cdda */
+    QString             audio_device_str; /* for alsa hw:0,0, for sun /dev/audio */
+    QStringList         audio_systems_list;
 
     QPushButton         *makeButton( int, int, int, int, const QString& );
 
 
-    void                initFont();
-    void                initWorkMan();
-    //  void            checkMount();
 
-    void    drawPanel();
-    void    loadBitmaps();
-    void    setLEDs(const QString& symbols);
-    void    cdtext();
+    void cdtext(struct cdtext_info* p_cdtext);
 
   /**
    * select a random track from the current disc.
    *
    */
-    int                 randomtrack();
+    int                 next_randomtrack();
+    int                 prev_randomtrack();
+    int                 real_randomtrack();
 
   /**
    * set the artist and title labels as well as the dock tooltip.
@@ -348,56 +298,45 @@ private:
    */
     void setArtistAndTitle(const QString& artist, const QString& title);
 
-//TODO get rid of the mixe stuff
+    int             tmppos;
+    int             save_track;
 
-    void                initMixer( const char *mixer = "/dev/mixer" );
+    QStringList     pathlist;
+    QStringList     tracktitlelist;
+    QStringList     playlist;
+    int             playlistpointer;
+    QStringList     extlist;
+    QString         category;
+    QString         genre;
+    QFont           smallfont;
+    QFont           verysmallfont;
+    bool            docking;
+    bool            autoplay;
+    bool            stopexit;
+    bool            ejectonfinish;
+    bool            digitalplayback;
 
-// These are the variables from workbone
+// cddb support
+public slots:
+    void cddb_done(CDDB::Result);
+    void cddb_failed();
+    void cddb_no_info();
+    void mycddb_inexact_read();
+    void CDDialogSelected();
+    void CDDialogDone();
+    void get_cddb_info(bool);
 
-        int             sss;
-        int             sel_stat;
-        int             dly;
-        int             fastin;
-        int             scmd;
-        int             tmppos;
-        int             save_track;
-        struct timeval  mydelay;
-        struct mntent   *mnt;
-        FILE            *fp;
-
-        CDDB            cddb;
-        QStringList        querylist;
-        QStringList        pathlist;
-        QStringList        discidlist;
-        QStringList     tracktitlelist;
-        QStringList     playlist;
-        int             playlistpointer;
-        QStringList     extlist;
-        int             revision;
-        QString         category;
-        QString         xmcd_data;
-        QStringList     cddbserverlist;
-        QString         cddbbasedir;
-        QString         current_server;
-        QString         mailcmd;
-        QString         submitaddress;
-        QStringList        cddbsubmitlist;
-        QFont           smallfont;
-        QFont           verysmallfont;
-        bool            cddb_remote_enabled;
-        /* edm new section */
-        bool            cddb_auto_enabled;
-        /* edm new section end */
-        bool            docking;
-        bool            autoplay;
-        bool            stopexit;
-        bool            ejectonfinish;
-        bool            randomonce;
-        bool            Fetch_remote_cddb;
-        bool            cddb_inexact_sentinel;
-        bool            updateDialog;
-        bool            ejectedBefore;
-        bool            currentlyejected;
+private:
+    KCDDB::Client*  cddb;
+    QString         xmcd_data;
+    QStringList     cddbserverlist;
+    QString         current_server;
+    QStringList     cddbsubmitlist;
+    bool            updateDialog;
+    int             revision;
+    int             year;
+    KActionCollection* m_actions;
+    KVolumeControl* m_volume;
 };
 
 
