@@ -1,5 +1,5 @@
 /*
- * $Id: cddb.c,v 1.4.8.2 2002/12/09 14:34:54 lunakl Exp $
+ * $Id: cddb.c,v 1.9 2003/06/27 01:40:10 mueller Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -29,7 +29,7 @@
  *
  */
 
-static char cddb_id[] = "$Id: cddb.c,v 1.4.8.2 2002/12/09 14:34:54 lunakl Exp $";
+static char cddb_id[] = "$Id: cddb.c,v 1.9 2003/06/27 01:40:10 mueller Exp $";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -49,6 +49,7 @@ static char cddb_id[] = "$Id: cddb.c,v 1.4.8.2 2002/12/09 14:34:54 lunakl Exp $"
 #include "include/wm_struct.h"
 #include "include/wm_cdinfo.h"
 #include "include/wm_helpers.h"
+#include "include/wm_cddb.h"
 
 /*
  * This is for identifying WorkMan at CDDB servers
@@ -58,12 +59,28 @@ static char cddb_id[] = "$Id: cddb.c,v 1.4.8.2 2002/12/09 14:34:54 lunakl Exp $"
 
 struct wm_cddb cddb;
 
+extern struct wm_cdinfo thiscd;
 int cur_cddb_protocol;
 char *cur_cddb_server;
 char *cur_cddb_mail_adress;
 char *cur_cddb_path_to_cgi;
 char *cur_cddb_proxy_server;
 
+/* local prototypes */
+int cddb_sum(int);
+char *string_split(char *line, char delim);
+void string_makehello(char *line, char delim);
+int connect_open(void);
+void connect_close(void);
+void connect_getline(char *line);
+void connect_read_entry(void);
+void cddbp_send(const char *line);
+void cddbp_read(char *category, unsigned int id);
+void http_send(char* line);
+void http_read(char *category, unsigned int id);
+void cddb_request(void);
+/* local prototypes END */
+
 int Socket;
 FILE *Connection;
 
@@ -152,7 +169,7 @@ cddb_discid(void)
 } /* cddb_discid() */
 
 /*
- * Split a string into two components according to the first occurance of
+ * Split a string into two components according to the first occurrence of
  * the delimiter.
  */
 char *
@@ -214,7 +231,9 @@ connect_open(void)
 	if(!port)
 	  port=8880;
 
+#ifndef NDEBUG
 	printf("%s:%d\n",host,port);
+#endif
 	hp  =gethostbyname(host);
   
 	if (hp == NULL)
@@ -228,7 +247,9 @@ connect_open(void)
 		defaddr.s_addr = inet_addr(host);
 		if (defaddr.s_addr == -1) 
 		{
+#ifndef NDEBUG
 			printf("unknown host: %s\n", host);
+#endif
 			return (-1);
 		}
 		strcpy(namebuf, host);
@@ -353,7 +374,7 @@ connect_read_entry(void)
  * Send a command to the server using cddbp
  */
 void
-cddbp_send(char *line)
+cddbp_send(const char *line)
 {
 	write(Socket, line, strlen(line));
 	write(Socket, "\n", 1);
@@ -379,22 +400,32 @@ http_send(char* line)
 	char tempbuf[2000];
 	
 	write(Socket, "GET ", 4);
+#ifndef NDEBUG
 	printf("GET ");
+#endif
 	if(cddb.protocol == 3)
 	{
 		write(Socket, "http://", 7);
 		write(Socket, cddb.cddb_server, strlen(cddb.cddb_server));
+#ifndef NDEBUG
 		printf("http://%s",cddb.cddb_server);
+#endif
 	}
 	write(Socket, cddb.path_to_cgi, strlen(cddb.path_to_cgi));
 	write(Socket, "?cmd=" ,5);
 	write(Socket, line, strlen(line));
+#ifndef NDEBUG
 	printf("%s?cmd=%s",cddb.path_to_cgi,line);
-	string_makehello(tempbuf,'+');
+#endif	
+    string_makehello(tempbuf,'+');
 	write(Socket, tempbuf, strlen(tempbuf));
+#ifndef NDEBUG
 	printf("%s",tempbuf);
-	write(Socket, "&proto=1 HTTP/1.0\n\n", 19);
+#endif	
+    write(Socket, "&proto=1 HTTP/1.0\n\n", 19);
+#ifndef NDEBUG
 	printf("&proto=1 HTTP/1.0\n");
+#endif
 	do
 	  connect_getline(tempbuf);
 	while(strcmp(tempbuf,""));
@@ -435,11 +466,15 @@ cddb_request(void)
 	switch(cddb.protocol)
 	{
 	 case 1: /* cddbp */
+#ifndef NDEBUG
 		printf("USING CDDBP\n");
 		printf("open\n");
+#endif
 		connect_open();
 		connect_getline(tempbuf);
+#ifndef NDEBUG
 		printf("[%s]\n",tempbuf);
+#endif        
 		/*
 		 * if(atoi(tempbuf) == 201) return;
 		 */
@@ -448,23 +483,29 @@ cddb_request(void)
 		 * strcpy(tempbuf,"cddb hello svolli bigfoot.com Eierkratzer eins");
 		 */
 		string_makehello(tempbuf,' ');
+#ifndef NDEBUG
 		fprintf(stderr, "%s\n", tempbuf);
+#endif
 		cddbp_send(tempbuf);
 		connect_getline(tempbuf);
+#ifndef NDEBUG
 		printf("[%s]\n",tempbuf);
-		
 		printf("query\n");
+#endif
 		sprintf(tempbuf, "cddb query %08x %d",thiscd.cddbid,thiscd.ntracks);
 		for (i = 0; i < cur_ntracks; i++)
 		  if (thiscd.trk[i].section < 2)
 		    sprintf(tempbuf + strlen(tempbuf), " %d",
 			    thiscd.trk[i].start);
 		sprintf(tempbuf + strlen(tempbuf), " %d\n", thiscd.length);
+#ifndef NDEBUG
 		printf(">%s<\n",tempbuf);
+#endif
 		cddbp_send(tempbuf);
 		connect_getline(tempbuf);
+#ifndef NDEBUG
 		printf("[%s]\n",tempbuf);
-		
+#endif
 		status=atoi(tempbuf);
 		/*
 		 * fprintf(stderr, "status:%d\n",status);
@@ -491,25 +532,32 @@ cddb_request(void)
 		
 		cddbp_send("quit");
 		connect_close();
+#ifndef NDEBUG
 		printf("close\n");
+#endif
 		break;
 	 case 2: /* http */
 	 case 3: /* http proxy */
+#ifndef NDEBUG
 		printf("USING HTTP%s\n",
 		       (cddb.protocol == 3) ? " WITH PROXY" : "");
 		printf("query\n");
+#endif
 		sprintf(tempbuf, "cddb+query+%08x+%d",thiscd.cddbid,thiscd.ntracks);
 		for (i = 0; i < cur_ntracks; i++)
 		  if (thiscd.trk[i].section < 2)
 		    sprintf(tempbuf + strlen(tempbuf), "+%d",
 			    thiscd.trk[i].start);
 		sprintf(tempbuf + strlen(tempbuf), "+%d", thiscd.length);
+#ifndef NDEBUG
 		printf(">%s<\n",tempbuf);
+#endif
 		connect_open();
 		http_send(tempbuf);
 		connect_getline(tempbuf);
+#ifndef NDEBUG
 		printf("[%s]\n",tempbuf);
-		
+#endif
 		status=atoi(tempbuf);
 		/*
 		 * fprintf(stderr, "status:%d\n",status);
