@@ -1,5 +1,5 @@
 /*
- * $Id: cdinfo.c,v 1.2.10.1 2002/12/09 14:34:54 lunakl Exp $
+ * $Id: cdinfo.c,v 1.7 2003/12/06 10:41:09 aseigo Exp $
  * 
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,8 +25,6 @@
  * Get information about a CD.
  */
 
-static char cdinfo_id[] = "$Id: cdinfo.c,v 1.2.10.1 2002/12/09 14:34:54 lunakl Exp $";
-
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -55,7 +53,7 @@ int	cur_tracklen;	/* Length in seconds of current track */
 int	cur_cdlen;	/* Length in seconds of entire CD */
 int	cur_ntracks;	/* Number of tracks on CD (= tracks + sections) */
 int	cur_nsections;	/* Number of sections currently defined */
-enum wm_cd_modes	cur_cdmode = WM_CDM_EJECTED;
+
 int	cur_listno;	/* Current index into the play list, if playing */
 char *	cur_artist;	/* Name of current CD's artist */
 char *	cur_cdname;	/* Album name */
@@ -76,8 +74,7 @@ int info_modified;
  * etc.  The new entry will be zeroed out.
  */
 void
-insert_trackinfo(num)
-	int	num;
+insert_trackinfo(int num)
 {
 	struct wm_trackinfo *newtrk;
 
@@ -86,7 +83,6 @@ insert_trackinfo(num)
 		if ((cd->trk = (struct wm_trackinfo *) calloc(1,
 						sizeof(*newtrk))) == NULL)
 		{
-nomem:
 			perror("insert_trackinfo");
 			exit(1);
 		} else {
@@ -96,7 +92,10 @@ nomem:
 	/* Stick the new entry in cd->trk[]. */
 	if ((newtrk = (struct wm_trackinfo *) malloc(sizeof(*newtrk) *
 						(cur_ntracks + 1))) == NULL)
-		goto nomem;
+	{
+		perror("insert_trackinfo");
+		exit(1);
+	}
 
 	if (num)
 		memcpy(newtrk, cd->trk, sizeof(*newtrk) * num);
@@ -275,7 +274,8 @@ char *
 listentry( int num )
 {
 	static char	buf[600];
-	char		*name, tracknum[20];
+	const char *name;
+    char* tracknum[20];
 	int		digits;
 	int		sdigits;
 
@@ -297,7 +297,7 @@ listentry( int num )
 
 		digits = 2;
 		sdigits = cur_nsections < 9 ? -1 : -2;
-		
+
 		name = cd->trk[num].songname ? cd->trk[num].songname : "";
 
 		if (cur_nsections)
@@ -345,7 +345,7 @@ listentry( int num )
  *
  * Return a track's name.
  */
-char *
+const char *
 trackname( int num )
 {
 	if (num >= 0 && num < cur_ntracks) 
@@ -640,18 +640,16 @@ stash_trkinfo( int track, char *songname, int contd, int avoid )
  * Add a playlist to a CD.
  */
 struct wm_playlist *
-new_list(cd, listname)
-	struct wm_cdinfo	*cd;
-	char		*listname;
+new_list(struct wm_cdinfo* cdinfo, char* listname)
 {
 	int	nlists = 0;
 	struct wm_playlist *l;
 
-	if (cd->lists != NULL)
+	if (cdinfo->lists != NULL)
 	{
-		for (nlists = 0; cd->lists[nlists].name != NULL; nlists++)
+		for (nlists = 0; cdinfo->lists[nlists].name != NULL; nlists++)
 			;
-		l = (struct wm_playlist *)realloc(cd->lists, (nlists + 2) *
+		l = (struct wm_playlist *)realloc(cdinfo->lists, (nlists + 2) *
 			sizeof (struct wm_playlist));
 	}
 	else
@@ -664,7 +662,7 @@ new_list(cd, listname)
 	l[nlists].name = NULL;		/* so wm_strmcpy doesn't free() it */
 	wm_strmcpy(&l[nlists].name, listname);
 	l[nlists].list = NULL;
-	cd->lists = l;
+	cdinfo->lists = l;
 
 	return (&l[nlists]);
 }
@@ -851,7 +849,9 @@ pl_find_track( int track )
 
 	if (playlist == NULL)
 	{
+#ifndef NDEBUG
 		fprintf(stderr, "Null playlist!  Huh?\n");
+#endif
 		return;
 	}
 
