@@ -1,5 +1,5 @@
 /*
- * $Id: database.c,v 1.2.10.1 2002/12/06 16:51:02 lunakl Exp $
+ * $Id: database.c,v 1.5 2003/03/06 19:39:31 kernalex Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -27,7 +27,7 @@
  * obviously it won't contain track titles just after a CD is inserted.)
  */
 
-static char database_id[] = "$Id: database.c,v 1.2.10.1 2002/12/06 16:51:02 lunakl Exp $";
+static char database_id[] = "$Id: database.c,v 1.5 2003/03/06 19:39:31 kernalex Exp $";
 
 #define RCFILE "/.workmanrc"
 #define DBFILE "/.workmandb"
@@ -54,7 +54,18 @@ static char database_id[] = "$Id: database.c,v 1.2.10.1 2002/12/06 16:51:02 luna
 
 #define WM_MSG_CLASS WM_MSG_CLASS_DB
 
-#define SWALLOW_LINE(fp) { int c; while ((c = getc(fp)) != '\n' && c != EOF); }
+#define SWALLOW_LINE(fp) { int _c; while ((_c = getc(fp)) != '\n' && _c != EOF); }
+
+/* local prototypes */
+char *print_cdinfo(struct wm_cdinfo *pcd, int prefs);
+FILE *open_rcfile(const char *name, const char *mode);
+int *reset_tracks(void);
+int search_db( FILE *fp, int prefs, int scan, int holesize_wanted );
+void spinwheels(int secs);
+int lockit(int fd, int type);
+void save_globals(FILE *fp);
+int save_entry(char *filename, int pref);
+/* local prototypes END */
 
 int	suppress_locking = 0;	/* Turn off locking of datafile (dangerous) */
 
@@ -179,6 +190,7 @@ nomem:
 
 	if (no_db || no_rc)
 	{
+#ifndef NDEBUG
 		fprintf(stderr,
 "WorkMan was run without a home directory, probably by a system daemon.\n");
 		fprintf(stderr, "It doesn't know where to find ");
@@ -193,7 +205,7 @@ nomem:
 
 		fprintf(stderr,
 ".\nYou can use the X resources \"workman.db.shared\" and \"workman.db.personal\"\nto tell WorkMan where to look.\n");
-
+#endif
 		wm_db_save_disabled = TRUE;
 	}
 }
@@ -365,7 +377,7 @@ print_cdinfo(struct wm_cdinfo *cd, int prefs)
  *	mode		"r" or "w"
  */
 FILE *
-open_rcfile(char *name, char *mode)
+open_rcfile(const char *name, const char *mode)
 {
 	FILE		*fp;
 	struct stat	st;
@@ -1095,13 +1107,13 @@ load( void )
 
 /* This is some kind of profiling code. I don't change it
    to wm_lib_message() for now... */
-#ifdef DEBUG
+#ifndef NDEBUG
 	long		t1, t2;
 	if( getenv( "WORKMAN_DEBUG" ) != NULL )
 	  {
 		time(&t1);
 		printf("%s (%d): search start = %ld\n", __FILE__, __LINE__, t1);
-		fflush(stdout);
+        fflush(stdout);
 	  }	
 #endif
 
@@ -1143,7 +1155,7 @@ load( void )
 		}
 	} while (*++dbfile != NULL && cd->whichdb == NULL);
 
-#ifdef DEBUG
+#ifndef NDEBUG
 	if( getenv( "WORKMAN_DEBUG" ) != NULL )
 	  {
 		time(&t2);
@@ -1177,7 +1189,7 @@ load( void )
 	if (cur_playnew == -1)
 		cur_playnew = 0;
 
-#ifdef DEBUG
+#ifndef NDEBUG
 	if( getenv( "WORKMAN_DEBUG" ) != NULL )
 	  {
 		time(&t2);
