@@ -1,7 +1,7 @@
 #ifndef WM_CONFIG_H
 #define WM_CONFIG_H
 /*
- * $Id: wm_config.h,v 1.12 2002/11/05 04:42:08 aseigo Exp $
+ * $Id: wm_config.h,v 1.13.2.2 2004/02/26 13:11:35 fawcett Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -54,7 +54,8 @@
  * The above order corresponds with the order of the platform specific
  * options below.
  */
-
+ 
+#include <config.h>
 /******************************************************************
  * generic options
  ******************************************************************
@@ -130,7 +131,11 @@
  ******************************************************************/
 #if defined(__FreeBSD__) || defined(__FreeBSD)
 
-#define DEFAULT_CD_DEVICE	"/dev/rcd0c"
+#if __FreeBSD_version >= 500100
+#define DEFAULT_CD_DEVICE	"/dev/acd0"
+#else
+#define DEFAULT_CD_DEVICE	"/dev/acd0c"
+#endif
 
 #endif /* freebsd */
 
