@@ -1,5 +1,5 @@
 /*
- * $Id: plat_irix.c,v 1.5 2001/01/29 05:55:52 dfoerste Exp $
+ * $Id: plat_irix.c,v 1.7 2003/03/06 19:39:31 kernalex Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -31,7 +31,7 @@
  * paul@kcbbs.gen.nz
  */
 
-static char plat_irix_id[] = "$Id: plat_irix.c,v 1.5 2001/01/29 05:55:52 dfoerste Exp $";
+static char plat_irix_id[] = "$Id: plat_irix.c,v 1.7 2003/03/06 19:39:31 kernalex Exp $";
 
 #if defined(sgi) || defined(__sgi)
  
@@ -62,6 +62,7 @@ static char plat_irix_id[] = "$Id: plat_irix.c,v 1.5 2001/01/29 05:55:52 dfoerst
 #include <errno.h>
 
 #include "include/wm_struct.h"
+#include "include/wm_cdtext.h"
 
 #define WM_MSG_CLASS WM_MSG_CLASS_PLATFORM
 
@@ -71,8 +72,6 @@ char *strchr();
 int	min_volume = 0;
 int	max_volume = 255;
 
-extern char	*cd_device;
-
 #ifdef CDDA
 static int playing = STOPPED;
 static CDPLAYER *icd;
@@ -171,18 +170,18 @@ wmcd_open( struct wm_drive *d )
   
   if (d->fd < 0)		/* Device already open? */
     {
-      if (cd_device == NULL)
-	cd_device = DEFAULT_CD_DEVICE;
+      if (d->cd_device == NULL)
+        d->cd_device = DEFAULT_CD_DEVICE;
       
       d->fd = 1;
       
       /* Now fill in the relevant parts of the wm_drive structure. */
       fd = d->fd;
-      *d = *(find_drive_struct("", "", ""));
+      find_drive_struct("", "", "");
       d->fd = fd;
       (d->init)(d);
       
-      d->daux = CDopen(cd_device,"r");
+      d->daux = CDopen(d->cd_device,"r");
       if (d->daux == 0)
 	{
           return (-6);
@@ -211,13 +210,7 @@ wmcd_reopen( struct wm_drive *d )
   
   do {
     wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_reopen\n");
-    if (d->fd >= 0)		/* Device really open? */
-      {
-	wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "closing the device\n");
-	status = close( d->fd );   /* close it! */
-	/* we know, that the file is closed, do we? */
-	d->fd = -1;
-      }
+    status = gen_close( d );
     wm_susleep( 1000 );
     wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "calling wmcd_open()\n");
     status = wmcd_open( d ); /* open it as usual */
@@ -237,14 +230,25 @@ wm_scsi( struct wm_drive *d, unsigned char *xcdb, int cdblen,
   return -1;
 } /* wm_scsi() */
 
+int
+gen_close( struct wm_drive *d )
+{
+  if(d->fd != -1) {
+    wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "closing the device\n");
+    close(d->fd);
+    d->fd = -1;
+  }
+  return 0;
+}
+
 /*--------------------------------------------------------------------------*
  * Get the current status of the drive: the current play mode, the absolute
  * position from start of disc (in frames), and the current track and index
  * numbers if the CD is playing or paused.
  *--------------------------------------------------------------------------*/
 int
-gen_get_drive_status( struct wm_drive *d, enum wm_cd_modes oldmode,
-                      enum wm_cd_modes *mode, int *pos, int *track,
+gen_get_drive_status( struct wm_drive *d, int oldmode,
+                      int *mode, int *pos, int *track,
                       int *index )
 {
 #ifdef CDDA
@@ -456,5 +460,17 @@ gen_get_volume( struct wm_drive *d, int *left, int *right )
   return 0;
 } /* gen_get_volume() */
 
+
+/*------------------------------------------------------------------------*
+ * gen_get_cdtext(drive, buffer, lenght)
+ *------------------------------------------------------------------------*/
+
+int
+gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_lenght)
+{
+  return -1; /* no SCSI, no CDTEXT */
+} /* gen_get_cdtext() */
+
+
 #endif
 
