@@ -1,5 +1,5 @@
 /*
- * $Id: plat_linux.c,v 1.17.2.1 2003/03/04 23:47:37 staikos Exp $
+ * $Id: plat_linux.c,v 1.31.2.1 2004/02/28 14:54:28 mueller Exp $
  *
  * This file is part of WorkMan, the civilized CD player library
  * (c) 1991-1997 by Steven Grimm (original author)
@@ -25,8 +25,6 @@
  * Linux-specific drive control routines.  Very similar to the Sun module.
  */
 
-static char plat_linux_id[] = "$Id: plat_linux.c,v 1.17.2.1 2003/03/04 23:47:37 staikos Exp $";
-
 #if defined(__linux__)
 
 #include <errno.h>
@@ -34,7 +32,6 @@ static char plat_linux_id[] = "$Id: plat_linux.c,v 1.17.2.1 2003/03/04 23:47:37
 #include <stdlib.h>
 #include <fcntl.h>
 #include <unistd.h>
-#include <malloc.h>
 #include <string.h>
 #include <sys/types.h>
 #include <sys/param.h>
@@ -43,6 +40,16 @@ static char plat_linux_id[] = "$Id: plat_linux.c,v 1.17.2.1 2003/03/04 23:47:37
 #include <sys/wait.h>
 /* Try to get around bug #29274 */
 #include <linux/version.h>
+#if 0
+/* this breaks the build on ia64 and s390 for example. 
+   sys/types.h is already included and should provide __u64.
+   please tell where we really need this and let's try to find
+   a working #if case for everyone ... adrian@suse.de */
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(2,5,50)) || (LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,21) && LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0))
+#undef __GNUC__
+typedef unsigned long long __u64; 
+#endif
+#endif
 
 #include "include/wm_config.h"
 #include "include/wm_struct.h"
@@ -60,9 +67,23 @@ static char plat_linux_id[] = "$Id: plat_linux.c,v 1.17.2.1 2003/03/04 23:47:37
   #endif
 #endif
 
+
 #include <sys/time.h>
 #include <sys/ioctl.h>
+
+#ifndef __GNUC__
+#define __GNUC__ 1
+#endif
+/* needed for vanilla kernel headers, which do provide __u64 only
+   for ansi */
+#undef __STRICT_ANSI__
+/* needed for non-ansi kernel headers */
+#define asm __asm__
+#define inline __inline__
+#include <asm/types.h>
 #include <linux/cdrom.h>
+#undef asm
+#undef inline
 
 #include "include/wm_cdda.h"
 #include "include/wm_struct.h"
@@ -85,6 +106,10 @@ static char plat_linux_id[] = "$Id: plat_linux.c,v 1.17.2.1 2003/03/04 23:47:37
 # define SCSI_IOCTL_SEND_COMMAND 1
 #endif
 
+#ifdef BUILD_CDDA
+int gen_cdda_init( struct wm_drive *d );
+#endif
+
 int	min_volume = 0;
 int	max_volume = 255;
 
@@ -92,9 +117,8 @@ int	max_volume = 255;
 int mixer;
 char mixer_dev_name[20] = "/dev/mixer";
 #endif
-extern char	*cd_device, *cddaslave_path;
-
-int	cdda_slave = -1;
+/*const char *cddaslave_path = "/home/kernalex/devel/kdemultimedia-3.0.6/kscd/libwm/.libs/cddaslave";*/
+const char *cddaslave_path = "cddaslave";
 
 /*-------------------------------------------------------*
  *
@@ -119,56 +143,66 @@ gen_init( struct wm_drive *d )
 int
 wmcd_open( struct wm_drive *d )
 {
-  int		fd;
-  static int	warned = 0;
-  int		retval = 0;
+  int fd;
   char vendor[32], model[32], rev[32];
-  
-  if (cd_device == NULL)
-    cd_device = DEFAULT_CD_DEVICE;
-    
-  
-  if (d->fd >= 0)		/* Device already open? */
-    {
+
+  if (d->cd_device == NULL)
+    d->cd_device = DEFAULT_CD_DEVICE;
+
+
+  if (d->fd >= 0) { /* Device already open? */
 /*      wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_open(): [device is open (fd=%d)]\n", d->fd);*/
       return (0);
-    }
-  
-  fd = open(cd_device, O_RDONLY | O_NONBLOCK);
+  }
 
-  if (fd < 0)
-    {
-      if (errno == EACCES)
-	{
-          return -EACCES;
-	}
-      /* Hack proposed by Carey Evans, introduced by Debian maintainer :
-       * treat EIO like ENXIO since some Linux drives do never return ENXIO
-       * ENOMEDIUM is returned by Kernel 2.2.x unified drivers.
-       */
-      else if ((errno != ENXIO) && (errno != EIO) && (errno != ENOMEDIUM))
-	{
-          return (-6);
-	}
-      
-      /* No CD in drive. */
-      retval = 1;
+  fd = open(d->cd_device, O_RDONLY | O_NONBLOCK);
+
+  if (fd < 0) {
+    if (errno == EACCES) {
+      return -EACCES;
     }
-  
-  
-#ifdef LINUX_SCSI_PASSTHROUGH
-  /* Can we figure out the drive type? */
-  retval = wm_scsi_get_drive_type(d, vendor, model, rev);
-  if (retval == WM_ERR_SCSI_INQUIRY_FAILED)
-    wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_open(): After failed inquiry\n");
+    /* Hack proposed by Carey Evans, introduced by Debian maintainer :
+     * treat EIO like ENXIO since some Linux drives do never return ENXIO
+     * ENOMEDIUM is returned by Kernel 2.2.x unified drivers.
+     */
+    else if ((errno != ENXIO) && (errno != EIO) && (errno != ENOMEDIUM)) {
+      return (-6);
+    }
+    /* No CD in drive. */
+    return 1;
+  }
+
+  /* Now fill in the relevant parts of the wm_drive structure. */
+  d->fd = fd;
+
+  /*
+   * See if we can do digital audio.
+   */
+#if defined(BUILD_CDDA)
+  if(d->cdda && gen_cdda_init(d)) {
+    wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_open(): failed in gen_cdda_init\n");
+    gen_close(d);
+    return -1;
+  }
 #endif
 
-  *d = *(find_drive_struct(vendor, model, rev));
-  wm_drive_settype(vendor, model, rev);
-  
-  d->fd = fd;
-  (d->init)(d);
-  return retval;
+  /* Can we figure out the drive type? */
+  if (wm_scsi_get_drive_type(d, vendor, model, rev)) {
+    wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_open(): inquiry failed\n");
+    strcpy(vendor, "Generic");
+    strcpy(model, "drive type");
+    strcpy(rev, "");
+  }
+
+  if(find_drive_struct(vendor, model, rev) < 0) {
+    gen_close(d);
+    return -1;
+  }
+
+  if(d->proto->gen_init)
+    return (d->proto->gen_init)(d);
+
+  return 0;
 } /* wmcd_open() */
 
 /*
@@ -182,12 +216,7 @@ wmcd_reopen( struct wm_drive *d )
   
   do {
     wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_reopen\n");
-    if (d->fd >= 0)		/* Device really open? */
-      {
-	wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "closing the device\n");
-	if(!close( d->fd ))   /* close it! */
-	  d->fd = -1;      /* closed */
-      }
+    gen_close(d);
     wm_susleep( 1000 );
     wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "calls wmcd_open()\n");
     status = wmcd_open( d ); /* open it as usual */
@@ -253,7 +282,7 @@ wm_scsi( struct wm_drive *d, unsigned char *cdb, int cdblen,
 
   struct cdrom_generic_command cdc;
   struct request_sense sense;
-  int ret, capability;
+  int capability;
 
   wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wm_scsi over CDROM_SEND_PACKET entered\n");
 
@@ -262,7 +291,6 @@ wm_scsi( struct wm_drive *d, unsigned char *cdb, int cdblen,
   if(!(capability & CDC_GENERIC_PACKET))
   {
     wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "your CDROM or/and kernel don't support CDC_GENERIC_PACKET ...\n");
-    printf("your CDROM or/and kernel don't support CDC_GENERIC_PACKET ...\n");
     return -1;
   }
 
@@ -286,6 +314,17 @@ wm_scsi( struct wm_drive *d, unsigned char *cdb, int cdblen,
 #endif
 } /* wm_scsi */
 
+int
+gen_close( struct wm_drive *d )
+{
+  if(d->fd != -1) {
+    wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "closing the device\n");
+    close(d->fd);
+    d->fd = -1;
+  }
+  return 0;
+}
+
 /*--------------------------------*
  * Keep the CD open all the time.
  * disabled, analogous to 1.4b3
@@ -333,8 +372,8 @@ keep_cd_open( void )
  * numbers if the CD is playing or paused.
  *--------------------------------------------------------------------------*/
 int
-gen_get_drive_status( struct wm_drive *d, enum wm_cd_modes oldmode,
-                      enum wm_cd_modes *mode, int *pos, int *track, int *index )
+gen_get_drive_status( struct wm_drive *d, int oldmode,
+  int *mode, int *pos, int *track, int *ind )
 {
   struct cdrom_subchnl		sc;
   
@@ -357,6 +396,11 @@ gen_get_drive_status( struct wm_drive *d, enum wm_cd_modes oldmode,
 	}
     }
  
+#if defined(BUILD_CDDA)
+  if (oldmode == WM_CDM_PAUSED || oldmode == WM_CDM_PLAYING || oldmode == WM_CDM_STOPPED) {
+       CDDARETURN(d) cdda_get_drive_status(d, oldmode, mode, pos, track, ind);
+  }
+#endif
 
   /* Try to get rid of the door locking    */
   /* Don't care about return value. If it  */
@@ -366,13 +410,13 @@ gen_get_drive_status( struct wm_drive *d, enum wm_cd_modes oldmode,
   sc.cdsc_format = CDROM_MSF;
  
   if (ioctl(d->fd, CDROMSUBCHNL, &sc))
-    return (0);
+    return 1;
   
   switch (sc.cdsc_audiostatus) {
   case CDROM_AUDIO_PLAY:
     *mode = WM_CDM_PLAYING;
     *track = sc.cdsc_trk;
-    *index = sc.cdsc_ind;
+    *ind = sc.cdsc_ind;
     *pos = sc.cdsc_absaddr.msf.minute * 60 * 75 +
       sc.cdsc_absaddr.msf.second * 75 +
       sc.cdsc_absaddr.msf.frame;
@@ -396,7 +440,7 @@ gen_get_drive_status( struct wm_drive *d, enum wm_cd_modes oldmode,
       {
 	*mode = WM_CDM_PAUSED;
 	*track = sc.cdsc_trk;
-	*index = sc.cdsc_ind;
+	*ind = sc.cdsc_ind;
 	*pos = sc.cdsc_absaddr.msf.minute * 60 * 75 +
 	  sc.cdsc_absaddr.msf.second * 75 +
 	  sc.cdsc_absaddr.msf.frame;
@@ -470,9 +514,11 @@ gen_get_cdlen(struct wm_drive *d, int *frames)
  * Play the CD from one position to another (both in frames.)
  *------------------------------------------------------------*/
 int
-gen_play(struct wm_drive *d, int start, int end)
+gen_play(struct wm_drive *d, int start, int end, int realstart)
 {
-  struct cdrom_msf		msf;
+  struct cdrom_msf msf;
+
+  CDDARETURN(d) cdda_play(d, start, end, realstart);
 
   msf.cdmsf_min0 = start / (60*75);
   msf.cdmsf_sec0 = (start % (60*75)) / 75;
@@ -481,13 +527,12 @@ gen_play(struct wm_drive *d, int start, int end)
   msf.cdmsf_sec1 = (end % (60*75)) / 75;
   msf.cdmsf_frame1 = end % 75;
   
-  if (ioctl(d->fd, CDROMPLAYMSF, &msf))
-    {
-      if (ioctl(d->fd, CDROMSTART))
-        return (-1);
-      if (ioctl(d->fd, CDROMPLAYMSF, &msf))
-        return (-2);
-    }
+  if (ioctl(d->fd, CDROMPLAYMSF, &msf)) {
+    if (ioctl(d->fd, CDROMSTART))
+      return (-1);
+    if (ioctl(d->fd, CDROMPLAYMSF, &msf))
+      return (-2);
+  }
   
   /*
    * I hope no drive gets really confused after CDROMSTART
@@ -510,6 +555,7 @@ gen_play(struct wm_drive *d, int start, int end)
 int
 gen_pause(struct wm_drive *d)
 {
+  CDDARETURN(d) cdda_pause(d);
   return (ioctl(d->fd, CDROMPAUSE));
 }
 
@@ -519,6 +565,7 @@ gen_pause(struct wm_drive *d)
 int
 gen_resume(struct wm_drive *d)
 {
+  CDDARETURN(d) cdda_pause(d);
   return (ioctl(d->fd, CDROMRESUME));
 }
 
@@ -528,6 +575,7 @@ gen_resume(struct wm_drive *d)
 int
 gen_stop(struct wm_drive *d)
 {
+  CDDARETURN(d) cdda_stop(d);
   return (ioctl(d->fd, CDROMSTOP));
 }
 
@@ -548,11 +596,10 @@ gen_eject(struct wm_drive *d)
   
   wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "ejecting?\n");
 
-  if (fstat(d->fd, &stbuf) != 0)
-    {
+  if (fstat(d->fd, &stbuf) != 0) {
       wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "that weird fstat() thingy\n");
       return (-2);
-    }
+  }
   
   /* Is this a mounted filesystem? */
 #if !defined(BSD_MOUNTTEST)
@@ -577,7 +624,7 @@ gen_eject(struct wm_drive *d)
     }
   while ((mnt = getmntent (fp)) != NULL)
     {
-      if (strcmp (mnt->mnt_fsname, cd_device) == 0)
+      if (strcmp (mnt->mnt_fsname, d->cd_device) == 0)
 	{
 	  wm_lib_message(WM_MSG_LEVEL_ERROR|WM_MSG_CLASS, "CDROM already mounted (according to mtab). Operation aborted.\n");
 	  endmntent (fp);
@@ -587,6 +634,10 @@ gen_eject(struct wm_drive *d)
   endmntent (fp);
 #endif /* BSD_MOUNTTEST */
  
+  IFCDDA(d) {
+    cdda_eject(d);
+  }
+
   ioctl( d->fd, CDROM_LOCKDOOR, 0 );
 
   if (ioctl(d->fd, CDROMEJECT))
@@ -609,10 +660,7 @@ gen_eject(struct wm_drive *d)
      * device open.
      */
     if (intermittent_dev)
-      {
-	close(d->fd);
-	d->fd = -1;
-      }			  
+      gen_close(d);
 #endif
   
   return (0);
@@ -632,18 +680,16 @@ gen_closetray(struct wm_drive *d)
     return (-1);
 #else
   wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "wmcd_reopen() closing tray...\n");
-  if(!close(d->fd))
+  if(!gen_close(d))
     {
-      d->fd=-1;
       return(wmcd_reopen(d));
     } else {
       return(-1);
     }
 #endif /* CDROMCLOSETRAY */
-#else /* CAN_CLOSE */
+#endif /* CAN_CLOSE */
   /* Always succeed if the drive can't close. */
   return(0);
-#endif /* CAN_CLOSE */
 } /* gen_closetray() */
 
 
@@ -675,6 +721,8 @@ gen_set_volume( struct wm_drive *d, int left, int right )
 {
   struct	cdrom_volctrl v;
   
+  CDDARETURN(d) cdda_set_volume(d, left, right);
+
   /* Adjust the volume to make up for the CD-ROM drive's weirdness. */
   left = scale_volume(left, 100);
   right = scale_volume(right, 100);
@@ -685,6 +733,21 @@ gen_set_volume( struct wm_drive *d, int left, int right )
   return (ioctl(d->fd, CDROMVOLCTRL, &v));
 } /* gen_set_volume() */
 
+/*---------------------------------------------------------------------*
+ * Read the volume from the drive, if available.  Each channel
+ * ranges from 0 to 100, with -1 indicating data not available.
+ *---------------------------------------------------------------------*/
+int
+gen_get_volume( struct wm_drive *d, int *left, int *right )
+{
+  CDDARETURN(d) cdda_get_volume(d, left, right);
+
+  /* Suns, HPs, Linux, NEWS can't read the volume; oh well */
+  *left = *right = -1;
+
+  return 0;
+} /* gen_get_volume() */
+
 /*------------------------------------------------------------------------*
  * gen_get_cdtext(drive, buffer, lenght)
  *
@@ -701,40 +764,8 @@ gen_get_cdtext(struct wm_drive *d, unsigned char **pp_buffer, int *p_buffer_leng
   return wm_scsi_get_cdtext(d, pp_buffer, p_buffer_lenght);
 } /* gen_get_cdtext() */
 
-/*---------------------------------------------------------------------*
- * Read the initial volume from the drive, if available.  Each channel
- * ranges from 0 to 100, with -1 indicating data not available.
- *---------------------------------------------------------------------*/
-int
-gen_get_volume( struct wm_drive *d, int *left, int *right )
-{
-#if defined(BUILD_CDDA) && defined(WMCDDA_DONE) /* { */
-  struct cdda_block	blk;
   
-  if (cdda_slave > -1)
-    {
-      write(cdda_slave, "G", 1);
-      get_ack(cdda_slave);
-      read(cdda_slave, &blk, sizeof(blk));
-      
-      *left = *right = (blk.volume * 100 + 254) / 255;
-      
-      if (blk.balance < 110)
-	{
-	  *right = (((blk.volume * blk.balance + 127) / 128) *
-		    100 + 254) / 255;
-	} else if (blk.balance > 146) {
-	  *left = (((blk.volume * (255 - blk.balance) +
-		     127) / 128) * 100 + 254) / 255;
-	}
-      return (0);
-    }
-#else /* } */
-  /* Suns, HPs, Linux, NEWS can't read the volume; oh well */
-  *left = *right = -1;
-#endif
-  return (0);
-} /* gen_get_volume() */
+#ifdef BUILD_CDDA
 
 /*-------------------------------------------------------*
  *
@@ -744,29 +775,25 @@ gen_get_volume( struct wm_drive *d, int *left, int *right )
  *
  *-------------------------------------------------------*/
 
-#ifdef BUILD_CDDA /* { */
-
 /*
- * Try to initialize the CDDA slave.  Returns 0 on error.
+ * Try to initialize the CDDA slave.  Returns 0 on success.
  */
 int
-cdda_init( struct wm_drive *d )
+gen_cdda_init( struct wm_drive *d )
 {
-#if defined(WMCDDA_DONE) /* { */
   int	slavefds[2];
   
-  if (cdda_slave > -1)
-    return (1);
-  
-  fprintf( stderr, "slave okay\n" );
+  if (d->cdda_slave > -1)
+    return (0);
   
   if (socketpair(AF_UNIX, SOCK_STREAM, 0, slavefds))
     {
       perror("socketpair");
-      return (0);
+      return (-2);
     }
   
-  fprintf( stderr, "going to fork\n" );
+  wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "gen_cdda_init(): going to fork\n" );
+
   switch (fork()) {
   case 0:
     close(slavefds[0]);
@@ -774,10 +801,9 @@ cdda_init( struct wm_drive *d )
     dup2(slavefds[1], 0);
     close(slavefds[1]);
     close(d->fd);
-    /* Try the default path first. */
-    execl(cddaslave_path, cddaslave_path, cd_device, NULL);
-    /* Search $PATH if that didn't work. */
-    execlp("cddaslave", "cddaslave", cd_device, NULL);
+
+    execlp(cddaslave_path, cddaslave_path, d->cd_device,
+      d->soundsystem, d->sounddevice, d->ctldevice, NULL);
     perror(cddaslave_path);
     exit(1);
     
@@ -785,135 +811,26 @@ cdda_init( struct wm_drive *d )
     close(slavefds[0]);
     close(slavefds[1]);
     perror("fork");
-    return (0);
+    return (-3);
   }
   
   close(slavefds[1]);
-  cdda_slave = slavefds[0];
+  d->cdda_slave = slavefds[0];
   
-  if (!get_ack(cdda_slave))
-    {
-      fprintf( stderr, "get_ack failed\n" );
-      cdda_slave = -1;
-      /*		codec_start(); */
-      return (0);
-    }
-  return (1);
+  wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "gen_cdda_init(): wait for slave reply\n");
 
-#else /* BUILD_CDDA only } { */
-  /*
-   * If we're not building CDDA support, don't even bother trying.
-   */
-  return (0);
-#endif
-} /* cdda_init()  */
+  if (!cdda_get_ack(d->cdda_slave)) {
+    fprintf( stderr, "get_ack failed slave fd %i\n", d->cdda_slave );
+    d->cdda_slave = -1;
+    return -4;
+  }
 
-/*
- * Wait for an acknowledgement from the CDDA slave.
- */
-static int
-get_ack(int fd)
-{
-#if defined(WMCDDA_DONE) /* { */
-  struct cdda_block	blk;
+  wm_lib_message(WM_MSG_LEVEL_DEBUG|WM_MSG_CLASS, "gen_cdda_init(): slave got reply\n");
+
+  return 0;
+} /* cdda_init() */
   
-  do {
-    if (read(fd, &blk, sizeof(blk)) <= 0)
-      {
-	return (0);
-      }
-  } while (blk.status != WMCDDA_ACK);
-#endif /* } */
-	return (1);
-} /* get_ack() */
 
-/*
- * Turn off the CDDA slave.
- */
-void
-cdda_kill( struct wm_drive *d )
-{
-  if (cdda_slave > -1)
-    {
-      write(cdda_slave, "Q", 1);
-      get_ack(cdda_slave);
-      wait(NULL);
-      cdda_slave = -1;
-      /*		codec_start(); */
-    }
-} /* cdda_kill() */
-
-
-/*
- * Tell the CDDA slave to set the play direction.
- */
-void
-gen_set_direction( int newdir )
-{
-  unsigned char	buf[2];
-  
-  if (cdda_slave > -1)
-    {
-      buf[0] = 'd';
-      buf[1] = newdir;
-      write(cdda_slave, buf, 2);
-      get_ack(cdda_slave);
-    }
-}
-
-/*
- * Tell the CDDA slave to set the play speed.
- */
-void
-gen_set_speed( int speed )
-{
-  unsigned char	buf[2];
-  
-  if (cdda_slave > -1)
-    {
-      buf[0] = 's';
-      buf[1] = speed;
-      write(cdda_slave, buf, 2);
-      get_ack(cdda_slave);
-    }
-} /* gen_set_speed() */
-
-/*
- * Tell the CDDA slave to set the loudness level.
- */
-void
-gen_set_loudness( int loud )
-{
-  unsigned char	buf[2];
-  
-  if (cdda_slave > -1)
-    {
-      buf[0] = 'L';
-      buf[1] = loud;
-      write(cdda_slave, buf, 2);
-      get_ack(cdda_slave);
-    }
-} /* gen_set_loudness() */
-
-/*
- * Tell the CDDA slave to start (or stop) saving to a file.
- */
-void
-gen_save( char *filename )
-{
-  int	len;
-  
-  if (filename == NULL || filename[0] == '\0')
-    len = 0;
-  else
-    len = strlen(filename);
-  write(cdda_slave, "F", 1);
-  write(cdda_slave, &len, sizeof(len));
-  if (len)
-    write(cdda_slave, filename, len);
-  get_ack(cdda_slave);
-} /* gen_save() */
-
-#endif /* BUILD_CDDA } */
+#endif /* BUILD_CDDA */
 
 #endif /* __linux__ */
