@@ -1,5 +1,5 @@
 /*
-  system dependend wrapper for access to cdrom (Linux)
+  system dependent wrapper for access to cdrom (Linux)
   Copyright (C) 1999  Martin Vogt
 
   This program is free software; you can redistribute it and/or modify
@@ -10,12 +10,14 @@
 
  */
 
-typedef unsigned long long __u64;
 
 #include "cdromToc.h"
 #include "cdromRawAccess.h"
-#include <sys/types.h>
-#define _LINUX_BYTEORDER_SWAB_H
+#ifndef __GNUC__
+#define __GNUC__ 1
+#endif
+#undef __STRICT_ANSI__
+#include <asm/types.h>
 #include <linux/cdrom.h>
 #include <sys/ioctl.h>
 
