@@ -3,7 +3,7 @@
 
 #include <qframe.h>
 #include <klistview.h>
-#include <noatun/pref.h>
+#include "noatun/pref.h"
 
 class KListView;
 class QSplitter;
@@ -23,12 +23,12 @@ public:
 	virtual ~Types();
 	virtual void save();
 	virtual void reopen();
-	
+
 	static QString commaVector(Arts::TraderOffer *t, const char *field, bool limit=false);
 
 public slots:
-	void selectionChanged(QListViewItem *item); 
-	
+	void selectionChanged(QListViewItem *item);
+
 private:
 	KListView *list;
 	bool first;
@@ -51,7 +51,7 @@ private slots:
 
 private:
 	QCheckBox *mAutoPlay, *mLoopList, *mOneInstance, *mRememberPositions,
-	          *mClearOnStart, *mClearOnOpen, *mHackUpPlaylist, *mFastVolume;
+	          *mClearOnOpen, *mFastVolume, *mRemaining;
 	KURLRequester *mDlSaver;
 	KLineEdit *mTitleFormat;
 };
