@@ -85,10 +85,10 @@ Visualization::Visualization(int timeout, int pid)
 	// stack, otherwise, get it from localhost :)
 	{
 		int parent=pid ? pid : getppid();
-		
+
 		if (getenv("NOATUN_PID"))
 			parent = QString::fromLatin1(getenv("NOATUN_PID")).toInt();
-		
+
 		DCOPClient c;
 		c.attach();
 
@@ -96,7 +96,7 @@ Visualization::Visualization(int timeout, int pid)
 		appids[0]=QString("noatun-%1").arg(parent).local8Bit();
 		appids[1]="noatun";
 		QCString &appid=appids[0];
-		
+
 		if (!internalVis && c.isApplicationRegistered(appids[0]))
 		{
 			appid=appids[0];
@@ -107,19 +107,19 @@ Visualization::Visualization(int timeout, int pid)
 		}
 		else
 		{
-			kdDebug() << "Internal Vis" <<endl;
+			kdDebug(66666) << "Internal Vis" <<endl;
 			mVisualizationStack=napp->player()->engine()->visualizationStack()->toString().c_str();
 			mServer=new Arts::SoundServerV2(*(napp->player()->engine()->server()));
 			return;
 		}
-		
+
 		{
 			QByteArray replyData;
 			QCString replyType;
-			
+
 			if (!c.call(appid, "Noatun", "visStack()", QByteArray(), replyType, replyData))
 			{
-				qDebug("Error communicating to parent noatun");
+				kdDebug(66666) << "Error communicating to parent noatun" << endl;
 			}
 			else
 			{
@@ -138,7 +138,7 @@ Visualization::Visualization(int timeout, int pid)
 Visualization::~Visualization()
 {
 //	napp->player()->engine()->visualizationStack()->remove(mId);
-	
+
 	delete mServer;
 	delete mTimerThingy;
 }
@@ -171,7 +171,7 @@ Noatun::StereoEffectStack Visualization::visualizationStack()
 	return Arts::Reference(mVisualizationStack);
 }
 
-Arts::SoundServerV2 *Visualization::server() 
+Arts::SoundServerV2 *Visualization::server()
 {
 	return mServer;
 }
@@ -493,11 +493,11 @@ void NoatunListenerNotif::message()
 ExitNotifier::ExitNotifier(int pid, QObject *parent) : NoatunListener(parent)
 {
 	mNotif=new NoatunListenerNotif(this);
-	
+
 	DCOPClient c;
 	c.attach();
 
-	
+
 	QCString appids[2];
 	appids[0]=QString("noatun-%1").arg(pid).local8Bit();
 	appids[1]="noatun";
@@ -515,15 +515,15 @@ ExitNotifier::ExitNotifier(int pid, QObject *parent) : NoatunListener(parent)
 	{
 		return;
 	}
-		
+
 	QByteArray replyData;
 	QCString replyType;
 
 	QCString sessionName;
-	
+
 	if (!c.call(appid, "Noatun", "session()", QByteArray(), replyType, replyData))
 	{
-		qDebug("Error communicating to parent noatun");
+		kdDebug(66666) << "Error communicating to parent noatun" << endl;
 	}
 	else
 	{
