@@ -3,6 +3,7 @@
 #include <klocale.h>
 #include <kglobal.h>
 #include <kiconloader.h>
+//#include <kdebug.h>
 #include <qlayout.h>
 #include <qlabel.h>
 #include "cmodule.h"
@@ -29,6 +30,18 @@ void NoatunPreferences::show()
 	KDialogBase::show();
 }
 
+void NoatunPreferences::show(CModule *page)
+{
+	for (CModule *i=mModules.first(); i != 0; i=mModules.next())
+		i->reopen();
+	int index = pageIndex( static_cast<QWidget *>(page->parent()) );
+//	kdDebug(66666) << k_funcinfo << "index=" << index << endl;
+	if (index != -1)
+		showPage(index);
+	KDialogBase::show();
+}
+
+
 void NoatunPreferences::slotApply()
 {
 	for (CModule *i=mModules.first(); i != 0; i=mModules.next())
@@ -45,7 +58,7 @@ void NoatunPreferences::remove(CModule *page)
 	mModules.removeRef(page);
 }
 
-CModule::CModule(const QString &name, const QString &description, const QString &icon, QObject *owner) 
+CModule::CModule(const QString &name, const QString &description, const QString &icon, QObject *owner)
 	: QWidget(napp->preferencesBox()->addPage(name,
 	                                          description,
 	                                          KGlobal::iconLoader()->loadIcon(icon,
@@ -66,7 +79,6 @@ CModule::~CModule()
 {
 	// TODO When kdialogbase is fixed, delete the parent QFrame, and
 	// all traces of the related page
-
 	napp->sendPostedEvents();
 	napp->preferencesBox()->remove(this);
 }
@@ -75,9 +87,7 @@ void CModule::ownerDeleted()
 {
 	QObject *p=parent();
 	delete this;
-	//delete p;
+	p->deleteLater();
 }
 
 #include <noatun/pref.moc>
-
-
