@@ -102,8 +102,10 @@ int NIF::state()
 		return 2;
 	if (napp->player()->isPaused())
 		return 1;
-	if (napp->player()->isStopped());
+	if (napp->player()->isStopped())
 		return 0;
+        //fix compile warning
+        return 0;
 }
 
 QString NIF::lengthString()
