@@ -1,7 +1,6 @@
 #ifndef DCOPIFACE_H
 #define DCOPIFACE_H
 
-#include "dcopiface.h"
 #include <noatun/player.h>
 #include <noatun/plugin.h>
 
@@ -63,6 +62,10 @@ k_dcop:
 	 * get a property from the current song
 	 **/
 	QString currentProperty(const QString &key);
+	/**
+	 * clear a property from the current song
+	 **/
+	void clearCurrentProperty(const QString &key);
 
 	QCString visStack();
 	QCString session();
@@ -71,6 +74,17 @@ k_dcop:
 	void addFile(const QStringList &f, bool autoplay);
 
 	void loadPlugin(const QString &specFile);
+	QStringList availablePlugins();
+	QStringList loadedPlugins();
+	bool unloadPlugin(const QString &specFile);
+
+	QStringList mimeTypes();
+	QCString version();
+
+	/**
+	 * clear the playlist
+	 **/
+	void clear();
 	
 #ifdef DOCUMENTATION_BLEH_BLEH_DONT_TRY_COMPILING_THIS
 signals:
