@@ -109,7 +109,7 @@ void IRPrefs::save()
 	int i = 1;
 	for (QMap<QString, Command>::ConstIterator it = s_commands.begin(); it != s_commands.end(); ++it)
 	{
-		c->writeEntry(QString("Command_%1").arg(i), it.key());
+		c->writePathEntry(QString("Command_%1").arg(i), it.key());
 		c->writeEntry(QString("Action_%1").arg(i), (int)((*it).action));
 		c->writeEntry(QString("Interval_%1").arg(i), (*it).interval);
 		++i;
@@ -268,8 +268,12 @@ const QString IRPrefs::actionName(Action action)
 			return i18n("Seek Backward");
 		case SeekForward:
 			return i18n("Seek Forward");
-        case ShowPlaylist:
-            return i18n("Show Playlist");
+		case ShowPlaylist:
+			return i18n("Show Playlist");
+		case NextSection:
+			return i18n("Next Section");
+		case PreviousSection:
+			return i18n("Previous Section");
 	}
 	return QString::null;
 }
@@ -286,7 +290,7 @@ void IRPrefs::readConfig()
 		Command cmd;
 		cmd.action = (Action)(c->readNumEntry(QString("Action_%1").arg(i)));
 		cmd.interval = c->readNumEntry(QString("Interval_%1").arg(i));
-		s_commands.insert(c->readEntry(QString("Command_%1").arg(i)), cmd);
+		s_commands.insert(c->readPathEntry(QString("Command_%1").arg(i)), cmd);
 	}
 	s_configRead = true;
 }
