@@ -14,7 +14,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 
@@ -25,9 +25,9 @@
 #include <qtextstream.h>
 #include <qpainter.h>
 #include <qdropsite.h>
-#include <qdragobject.h>
 #include <kdebug.h>
 #include <klocale.h>
+#include <kurldrag.h>
 #include <qtimer.h>
 
 #include <stdlib.h>
@@ -181,7 +181,7 @@ void KaimanStyleElement::paintEvent ( QPaintEvent */*qpe*/ )
 
 void KaimanStyleElement::dragEnterEvent( QDragEnterEvent *event )
 {
-    event->accept( QUriDrag::canDecode(event) );
+    event->accept( KURLDrag::canDecode(event) );
 }
 
 void KaimanStyleElement::dropEvent( QDropEvent *event )
@@ -834,9 +834,9 @@ int KaimanStyle::parseStyleFile(QString &l_s_tmpName)
                 // OK, this is not a comment line
                 if ( l_s_textLine.isNull())
                     l_s_textLine = "";
-                while ( l_s_textLine != "" ) {
+                while ( !l_s_textLine.isEmpty() ) {
                     l_s_token = getToken(l_s_textLine, ' ');
-                    if ( ( ! l_s_token.isNull() ) && ( l_s_token != "" ) ) {
+                    if ( ! l_s_token.isEmpty() ) {
                         // OK. There is a useful token. It is not NULL
                         if ( l_s_token.right(1) == ":" )
                             l_s_tokens.append(l_s_token.left(l_s_token.length() -1 ));
@@ -1330,7 +1330,7 @@ QString KaimanStyle::getToken(QString &val_s_string, char val_c_separator)
     int l_i_pos;
     QString l_s_token;
 
-    // Find the first occurence of the separator
+    // Find the first occurrence of the separator
     l_i_pos = val_s_string.find(val_c_separator, 0, false);
     if ( l_i_pos == -1 ) {
         // No sparator! Then the whole string is the token
@@ -1372,7 +1372,7 @@ bool KaimanStyle::loadStyle(const QString &styleName, const QString &descFile)
             // If parsiing OK, load the referenced pixmaps
             l_b_ret = loadPixmaps();
 
-            kdDebug() << "Found " << I_styleElem.count() << " elements." << endl;
+            kdDebug(66666) << "Found " << I_styleElem.count() << " elements." << endl;
         }
         else {
             if ( l_i_ret == KaimanStyle::FileNotFound ) {
