@@ -13,7 +13,7 @@
 
    You should have received a copy of the GNU General Public License
    aint with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #ifdef HAVE_CONFIG_H
@@ -255,7 +255,7 @@ void Kaiman::closeEvent(QCloseEvent*)
 
 void Kaiman::dragEnterEvent( QDragEnterEvent *event )
 {
-	event->accept( QUriDrag::canDecode(event) );
+	event->accept( KURLDrag::canDecode(event) );
 }
 
 
@@ -376,7 +376,7 @@ void Kaiman::execMixer()
 /*
 	if ( fork() == 0 )
 	{
-		execlp( QFile::encodeName("kmix"), QFile::encodeName("kmix"), 0 );
+		execlp( QFile::encodeName("kmix"), QFile::encodeName("kmix"), (void *)0 );
 		// We should never pass this line. If yes, execlp() failed.
 		// Please remember that we are here in the forked process,
 		// so doing exit() is OK. But we cannot open a dialog
