@@ -29,7 +29,7 @@ Keyz::Keyz() : QObject( 0L, "Keyz" ), Plugin(), preMuteVol(0)
 
     if ( !s_accel )
     {
-        s_accel = new KGlobalAccel( this );
+        s_accel = new KGlobalAccel( this, "noatunglobalaccel" );
         s_accel->insert( "PlayPause", i18n("Play/Pause"), QString::null,
                          CTRL+ALT+Key_P, KKey::QtWIN+CTRL+Key_P,
                          player, SLOT( playpause() ));
@@ -42,7 +42,7 @@ Keyz::Keyz() : QObject( 0L, "Keyz" ), Plugin(), preMuteVol(0)
         s_accel->insert( "Forward", i18n("Forward"), QString::null,
                          CTRL+ALT+Key_Right, KKey::QtWIN+CTRL+Key_Right,
                          player, SLOT( forward() ));
-        s_accel->insert( "Playlist", i18n("Show Playlist"), QString::null,
+        s_accel->insert( "Playlist", i18n("Show/Hide the Playlist"), QString::null,
                          CTRL+ALT+Key_L, KKey::QtWIN+CTRL+Key_L,
                          player, SLOT( toggleListView() ));
         s_accel->insert( "OpenFile", i18n("Open File to Play"), QString::null,
@@ -79,6 +79,10 @@ Keyz::Keyz() : QObject( 0L, "Keyz" ), Plugin(), preMuteVol(0)
                          CTRL+ALT+Key_C, KKey::QtWIN+CTRL+Key_C,
                          this, SLOT( slotCopyTitle() ));
 
+        s_accel->insert( "ToggleGUI", i18n("Show/Hide the Main Window"), QString::null,
+                         CTRL+ALT+Key_W, KKey::QtWIN+CTRL+Key_W,
+                         napp, SLOT( toggleInterfaces() ));
+
         s_accel->readSettings();
         s_accel->updateConnections();
     }
@@ -88,6 +92,8 @@ Keyz::Keyz() : QObject( 0L, "Keyz" ), Plugin(), preMuteVol(0)
 
 Keyz::~Keyz()
 {
+    delete s_accel;
+    s_accel = 0L;
 }
 
 void Keyz::slotVolumeUp()
