@@ -17,6 +17,7 @@
 #include "kjtextdisplay.h"
 #include "kjvis.h"
 #include "kjprefs.h"
+#include "kjequalizer.h"
 
 #include "helpers.cpp"
 
@@ -32,7 +33,7 @@
 #include <noatun/stdaction.h>
 #include <noatun/app.h>
 #include <noatun/player.h>
-//#include "equalizer.h"
+#include <noatun/vequalizer.h>
 
 // system includes
 #include <string.h>
@@ -58,7 +59,7 @@
 #include <kstdaction.h>
 #include <kpopupmenu.h>
 #include <klocale.h>
-#include <kconfig.h>
+#include <kglobalsettings.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
 #include <knotifyclient.h>
@@ -101,8 +102,8 @@ private:
 KJLoader *KJLoader::kjofol=0;
 
 
-KJLoader::KJLoader(void)
-	: QWidget(0,"KJLoader", WType_TopLevel | WStyle_NoBorderEx | WRepaintNoErase ),
+KJLoader::KJLoader()
+	: QWidget(0,"KJLoader", WType_TopLevel | WStyle_NoBorder | WRepaintNoErase ),
 	  UserInterface(), moving(false), mClickedIn(0), mText(0), mNumbers(0), mVolumeFont(0), mPitchFont(0), splashScreen(0)
 {
 	kjofol = this;
@@ -138,13 +139,12 @@ KJLoader::KJLoader(void)
 	}
 
 	mHelpMenu = new KHelpMenu(this, kapp->aboutData());
-	connect( napp->player(), SIGNAL(timeout()), SLOT(timeUpdate()));
-	connect( napp->player(), SIGNAL(newSong()), SLOT(newSong()));
-	connect( napp->player(), SIGNAL(playlistShown()), SLOT(playlistShown()) );
-	connect( napp->player(), SIGNAL(playlistHidden()), SLOT(playlistHidden()) );
+	connect(napp->player(), SIGNAL(timeout()), SLOT(timeUpdate()));
+	connect(napp->player(), SIGNAL(stopped()), SLOT(timeUpdate()));
+	connect(napp->player(), SIGNAL(newSong()), SLOT(newSong()));
 
-	connect( napp, SIGNAL(hideYourself()), SLOT(hide()) );
-	connect( napp, SIGNAL(showYourself()), SLOT(show()) );
+	connect(napp, SIGNAL(hideYourself()), SLOT(hide()));
+	connect(napp, SIGNAL(showYourself()), SLOT(show()));
 //	KStdAction::quit(napp, SLOT(quit()), actionCollection());
 
 	QApplication::restoreOverrideCursor();
@@ -178,7 +178,7 @@ void KJLoader::addChild(KJWidget *c)
 // this methode does all the hard work on loading these weird skins
 void KJLoader::loadSkin(const QString &file)
 {
-	kdDebug(66666) << "<KJLoader::loadSkin(const QString &file)>" << endl;
+//	kdDebug(66666) << "<KJLoader::loadSkin(const QString &file)>" << endl;
 //	kdDebug(66666) << " file = " << file.latin1() << endl;
 
 	if ( file == mCurrentSkin ) // we don't load the same skin again
@@ -355,8 +355,8 @@ void KJLoader::loadSkin(const QString &file)
 		}
 	}
 
-//	if (exist("EqualizerWindow"))
-//		subwidgets.append(new KJEqualizer(item("EqualizerWindow"), this));
+	if (exist("EqualizerWindow"))
+		subwidgets.append(new KJEqualizer(item("EqualizerWindow"), this));
 
 	// I cant believe it, there are skins without a seeker, now THATS stupid :)
 	if (exist("seekregion"))
@@ -366,10 +366,12 @@ void KJLoader::loadSkin(const QString &file)
 	for (QDictIterator<QStringList> i(*this); i.current(); ++i)
 	{
 		QString d=i.currentKey();
-		if(	d.contains("button") &&
+		if(d.contains("button") &&
 			!d.startsWith("playlistwindow") && // don't add buttons that belong to the playlistwindow
 			d != "pitchcontrolbutton" &&  // both already handled above as they aren't buttons but sliders
 			d != "volumecontrolbutton" &&
+			d != "spectrumanalyzerbutton" && // FIXME: unsupported button
+			d != "oscilloscopebutton" && // FIXME: unsupported button
 			i.count() >= 7 )
 		{
 			subwidgets.append(new KJButton(*(*i), this));
@@ -386,7 +388,7 @@ void KJLoader::loadSkin(const QString &file)
 	if (napp->player()->isPlaying())
 		newSong();
 
-	kdDebug(66666) << "</KJLoader::loadSkin(const QString &file)>" << endl;
+//	kdDebug(66666) << "</KJLoader::loadSkin(const QString &file)>" << endl;
 }
 
 void KJLoader::loadSeeker()
@@ -407,29 +409,28 @@ void KJLoader::unloadSkin()
 	// as some skins use the NumberFont for pitchtext
 	if ( mPitchFont && mPitchFont != mNumbers )
 	{
-		kdDebug(66666) << " freeing mPitchFont" << endl;
+//		kdDebug(66666) << " freeing mPitchFont" << endl;
 		delete mPitchFont;
 	}
 
 	if ( mText )
 	{
-		kdDebug(66666) << " freeing mText" << endl;
+//		kdDebug(66666) << " freeing mText" << endl;
 		delete mText;
 	}
 
 	if ( mNumbers )
 	{
-		kdDebug(66666) << " freeing mNumbers" << endl;
+//		kdDebug(66666) << " freeing mNumbers" << endl;
 		delete mNumbers;
 	}
 
 	if ( mVolumeFont )
 	{
-		kdDebug(66666) << " freeing mVolumeFont" << endl;
+//		kdDebug(66666) << " freeing mVolumeFont" << endl;
 		delete mVolumeFont;
 	}
 
-
 //	kdDebug(66666) << "</KJLoader::unloadSkin()>" << endl;
 }
 
@@ -448,7 +449,7 @@ void KJLoader::closeEvent(QCloseEvent*)
 void KJLoader::dragEnterEvent(QDragEnterEvent *event)
 {
 	// accept uri drops only
-	event->accept(QUriDrag::canDecode(event));
+	event->accept(KURLDrag::canDecode(event));
 }
 
 void KJLoader::dropEvent(QDropEvent *event)
@@ -456,7 +457,7 @@ void KJLoader::dropEvent(QDropEvent *event)
 	KURL::List urls;
 	if ( KURLDrag::decode(event,urls) )
 	{
-	    for ( KURL::List::iterator it = urls.begin(); it != urls.end(); ++it )
+		for ( KURL::List::iterator it = urls.begin(); it != urls.end(); ++it )
 			napp->player()->openFile((*it), false);
 	}
 }
@@ -464,13 +465,9 @@ void KJLoader::dropEvent(QDropEvent *event)
 void KJLoader::wheelEvent(QWheelEvent *e)
 {	// from QT-Docu: delta() is 120 for one step
 	if (e->state() & ControlButton)
-	{
 		napp->player()->setVolume ( napp->player()->volume() + (e->delta()/8) ); // 15% volumechange
-	}
 	else
-	{
 		napp->player()->setVolume ( napp->player()->volume() + (e->delta()/24) ); // 5% volumechange
-	}
 }
 
 // now for some dockmode stuff
@@ -516,7 +513,8 @@ void KJLoader::slotWindowActivate(WId win)
 		return;
 
 	// ensure we dock to the active window _except_ our own
-	if ( win != winId() )
+	// and stick to the last window if the NEW current one is a desktop
+	if ( (win != winId()) && (KWin::info(win).windowType != NET::Desktop) )
 		mDockToWin = win;
 
 	if ( mDockToWin )
@@ -572,9 +570,10 @@ void KJLoader::slotWindowChange(WId win)
 	{
 //		kdDebug(66666) << "changed our window:" << win << endl;
 		KWin::Info info = KWin::info( mDockToWin );
-		if (info.isIconified() || info.mappingState == NET::Withdrawn)
+		if (info.isIconified() || info.mappingState == NET::Withdrawn || info.windowType == NET::Desktop)
 		{
-			// target-window has been iconified
+//			kdDebug(66666) << "[KJLoader] changed our window:" << win << ". either iconified or desktop" << endl;
+			// target-window has been iconified or window is desktop
 			hide();
 			mDockToWin = 0L;
 		}
@@ -728,8 +727,8 @@ void KJLoader::mouseReleaseEvent(QMouseEvent */*e*/)
 
 void KJLoader::timeUpdate()
 {
-	for (KJWidget* i=subwidgets.first(); i!=0; i=subwidgets.next())
-		i->timeUpdate(napp->player()->getTime()/1000); // pass seconds to all Widgets
+	for (KJWidget* widget=subwidgets.first(); widget; widget=subwidgets.next())
+		widget->timeUpdate(napp->player()->getTime()/1000); // pass seconds to all Widgets
 }
 
 void KJLoader::newSong()
@@ -740,31 +739,17 @@ void KJLoader::newSong()
 		i->newFile();
 }
 
-void KJLoader::playlistShown(void)
-{
-	for (KJWidget* i=subwidgets.first(); i!=0; i=subwidgets.next())
-		i->playlistShown();
-}
-
-void KJLoader::playlistHidden(void)
-{
-	for (KJWidget* i=subwidgets.first(); i!=0; i=subwidgets.next())
-		i->playlistHidden();
-}
-
-
 void KJLoader::readConfig()
 {
-	kdDebug(66666) << "KJLoader::readConfig()" << endl;
+//	kdDebug(66666) << "KJLoader::readConfig()" << endl;
 	for (KJWidget* i=subwidgets.first(); i!=0; i=subwidgets.next())
 		i->readConfig();
 }
 
-
-void KJLoader::showSplash(void)
+void KJLoader::showSplash()
 {
 	splashScreen = new QLabel( 0L, "SplashScreen",
-		WType_TopLevel | WStyle_NoBorderEx | WRepaintNoErase | WX11BypassWM );
+		WType_TopLevel | WStyle_NoBorder | WRepaintNoErase | WX11BypassWM );
 
 	QPixmap splashPix = pixmap(item("splashscreen")[1]);
 	splashScreen->setPixmap( splashPix );
@@ -773,16 +758,9 @@ void KJLoader::showSplash(void)
 
 	QSize sh = splashScreen->sizeHint();
 
-#if QT_VERSION < 300
-	KDesktopWidget *desktop = KApplication::desktop();
-#else
-	QDesktopWidget *desktop = KApplication::desktop();
-#endif
-
-	QRect rect = desktop->screenGeometry(desktop->primaryScreen());
-
-	splashScreen->move (rect.x() + (rect.width() - sh.width())/2,
-		rect.y() + (rect.height() - sh.height())/2 );
+	QRect desk = KGlobalSettings::splashScreenDesktopGeometry();
+	splashScreen->move (desk.x() + (desk.width() - sh.width())/2,
+		desk.y() + (desk.height() - sh.height())/2 );
 
 	splashScreen->setFixedSize(sh);
 	splashScreen->show();
@@ -791,9 +769,8 @@ void KJLoader::showSplash(void)
 	QTimer::singleShot(3000, this, SLOT(hideSplash()) );
 }
 
-void KJLoader::hideSplash(void)
+void KJLoader::hideSplash()
 {
 	splashScreen->hide();
 	delete splashScreen;
 }
-
