@@ -23,6 +23,7 @@
 #include <qslider.h>
 #include <qpixmap.h>
 #include <qtabwidget.h>
+#include <qtextbrowser.h>
 #include <qfileinfo.h>
 #include <qstringlist.h>
 #include <qregexp.h>
@@ -38,7 +39,11 @@
 #include <knotifyclient.h>
 #include <kprocess.h>
 #include <kstandarddirs.h>
+#include <kglobalsettings.h>
+#include <kfontcombo.h>
+#include <kcolorcombo.h>
 
+static QString expand(QString s);
 
 KJPrefs::KJPrefs(QObject* parent)
 	: CModule(i18n("K-Jöfol Skins"), i18n("Skin Selection For the K-Jöfol Plugin"), "style", parent)
@@ -68,29 +73,35 @@ KJPrefs::KJPrefs(QObject* parent)
 
 void KJPrefs::reopen() // reload config and set stuff in dialog
 {
-	kdDebug(66666) << "[KJPrefs] reopen()" << endl;
+//	kdDebug(66666) << "[KJPrefs] reopen()" << endl;
 
 	cfg->setGroup("KJofol-Skins");
 
-	mGuiSettingsWidget->timeCountdown->setChecked( cfg->readBoolEntry("TimeCountMode", false) );
+//	mGuiSettingsWidget->timeCountdown->setChecked( cfg->readBoolEntry("TimeCountMode", false) );
 	mGuiSettingsWidget->displayTooltips->setChecked( cfg->readBoolEntry("DisplayTooltips", true) );
 	mGuiSettingsWidget->displaySplash->setChecked( cfg->readBoolEntry("DisplaySplashScreen", true) );
 
 	mGuiSettingsWidget->minPitch->setValue( cfg->readNumEntry("minimumPitch", 50) );
 	mGuiSettingsWidget->maxPitch->setValue( cfg->readNumEntry("maximumPitch", 200) );
-
 	mGuiSettingsWidget->visTimerValue->setValue( cfg->readNumEntry("VisualizationSpeed", 30) );
 
+	mGuiSettingsWidget->useSysFont->setChecked( cfg->readBoolEntry("Use SysFont", false) );
+	mGuiSettingsWidget->cmbSysFont->setCurrentFont(
+		cfg->readEntry("SysFont Family", KGlobalSettings::generalFont().family()) );
+	QColor tmpColor = QColor(255,255,255);
+	mGuiSettingsWidget->cmbSysFontColor->setColor(
+		cfg->readColorEntry("SysFont Color", &tmpColor));
+
 	// TODO somehow honor both config-entries, I want a custom mode
 	switch ( cfg->readNumEntry("TitleScrollSpeed", 400 ) )
 	{
-		case 200:
+		case 800:
 			mGuiSettingsWidget->titleScrollSpeed->setValue(1);
 			break;
 		case 400:
 			mGuiSettingsWidget->titleScrollSpeed->setValue(2);
 			break;
-		case 800:
+		case 200:
 			mGuiSettingsWidget->titleScrollSpeed->setValue(3);
 			break;
 	}
@@ -136,7 +147,7 @@ void KJPrefs::reopen() // reload config and set stuff in dialog
 			}
 		}
 	}
-	
+
 	skins.sort();
 
 	QString loaded = cfg->readEntry("SkinResource", locate("data", "noatun/skins/kjofol/kjofol/kjofol.rc") );
@@ -162,7 +173,7 @@ void KJPrefs::reopen() // reload config and set stuff in dialog
 
 void KJPrefs::save()
 {
-	kdDebug(66666) << "[KJPrefs] save()" << endl;
+// 	kdDebug(66666) << k_funcinfo << "called." << endl;
 	QString skin=::expand ( mSkinselectorWidget->mSkins->currentText() );
 
 	// first load skin and then save config to prevent
@@ -174,7 +185,7 @@ void KJPrefs::save()
 	cfg->setGroup("KJofol-Skins");
 
 	cfg->writeEntry("SkinResource", skin);
-	cfg->writeEntry("TimeCountMode", timeCountMode() );
+//	cfg->writeEntry("TimeCountMode", timeCountMode() );
 	cfg->writeEntry("DisplayTooltips", displayTooltips() );
 	cfg->writeEntry("DisplaySplashScreen", displaySplash() );
 
@@ -185,6 +196,11 @@ void KJPrefs::save()
 	cfg->writeEntry("maximumPitch", maximumPitch() );
 	cfg->writeEntry("VisualizationSpeed", visTimerValue() );
 
+	cfg->writeEntry("Use SysFont", mGuiSettingsWidget->useSysFont->isChecked());
+	cfg->writeEntry("SysFont Family", mGuiSettingsWidget->cmbSysFont->currentFont());
+// 	kdDebug(66666) << k_funcinfo << "currentfont=" << mGuiSettingsWidget->cmbSysFont->currentFont() << endl;
+	cfg->writeEntry("SysFont Color", mGuiSettingsWidget->cmbSysFontColor->color());
+
 	cfg->sync();
 
 	emit configChanged();
@@ -278,17 +294,39 @@ void KJPrefs::setVisType ( int vis )
 	save(); // not sure if that's a good idea or doing saving by hand in here
 }
 
-bool KJPrefs::timeCountMode( void ) const
+
+bool KJPrefs::useSysFont( void ) const
 {
-	return mGuiSettingsWidget->timeCountdown->isChecked();
+	return mGuiSettingsWidget->useSysFont->isChecked();
 }
 
-void KJPrefs::setTimeCountMode( bool mode )
+void KJPrefs::setUseSysFont( bool mode )
 {
-	mGuiSettingsWidget->timeCountdown->setChecked( mode );
+	mGuiSettingsWidget->useSysFont->setChecked( mode );
 	save(); // not sure if that's a good idea or doing saving by hand in here
 }
 
+QFont KJPrefs::sysFont(void) const
+{
+	QString family = mGuiSettingsWidget->cmbSysFont->currentFont();
+//	kdDebug(66666) << k_funcinfo << "family=" << family << endl;
+	return QFont( family );
+}
+
+void KJPrefs::setSysFont(QFont &fnt)
+{
+	mGuiSettingsWidget->cmbSysFont->setCurrentFont( fnt.family() );
+}
+
+QColor KJPrefs::sysFontColor(void) const
+{
+	return mGuiSettingsWidget->cmbSysFontColor->color();
+}
+
+void KJPrefs::sysFontColor(QColor &c)
+{
+	mGuiSettingsWidget->cmbSysFontColor->setColor( c );
+}
 
 bool KJPrefs::displayTooltips( void ) const
 {
@@ -316,6 +354,7 @@ void KJPrefs::showPreview(const QString &_skin)
 		mPixmap=QPixmap();
 
 	mSkinselectorWidget->mPreview->setPixmap(mPixmap);
+	mSkinselectorWidget->mAboutText->setText(p.about());
 	mSkinselectorWidget->updateGeometry();
 }
 
@@ -332,7 +371,7 @@ void KJPrefs::installNewSkin( void )
 
 	kdDebug(66666) << "file to work on: " << srcFile.path().latin1() << endl;
 
-	if ( srcFile.isMalformed() || srcFile.isEmpty() ) // stop working on broken URLs
+	if ( !srcFile.isValid() || srcFile.isEmpty() ) // stop working on broken URLs
 	{
 		kdDebug(66666) << "srcFile is malformed or empty !!!" << endl;
 		return;
@@ -408,7 +447,7 @@ void KJPrefs::installNewSkin( void )
 		if ( dirList[i] == "." ) // zip did not contain a subdir, we have to create one
 		{
 			// skindir is named like the archive without extension (FIXME: extension is not stripped from name)
-			
+
 			int dotPos = srcFile.fileName().findRev('.');
 			if ( dotPos > 0 ) // found a dot -> (hopefully) strip the extension
 			{
@@ -421,17 +460,23 @@ void KJPrefs::installNewSkin( void )
 
 			kdDebug(66666) << "want to create: " << dst.path().latin1() << endl;
 
-			if ( dst.isMalformed() )
+			if ( !dst.isValid() )
 			{
-				KMessageBox::error ( this, i18n("Installing new skin failed: Destination path is invalid.\nPlease report a bug to the K-Jöfol maintainer") );
+				KMessageBox::error ( this,
+					i18n("Installing new skin failed: Destination path is invalid.\n"
+						"Please report a bug to the K-Jöfol maintainer") );
 				KIO::del( tmpUnpackPath );
 				return;
 			}
 			KIO::mkdir( dst );
 		}
 
-		if ( src.isMalformed() || dst.isMalformed() )
-			KMessageBox::error ( this, i18n("Installing new skin failed: Either source or destination path is invalid.\nPlease report a bug to the K-Jöfol maintainer") );
+		if ( !src.isValid() || !dst.isValid() )
+		{
+			KMessageBox::error ( this,
+				i18n("Installing new skin failed: Either source or destination path is invalid.\n"
+					"Please report a bug to the K-Jöfol maintainer") );
+		}
 		else
 		{
 			kdDebug(66666) << "src: " << src.path().latin1() << endl;
