@@ -16,7 +16,6 @@
 // kde includes
 #include <klocale.h>
 #include <kdebug.h>
-#include <kconfig.h>
 #include <kpixmap.h>
 #include <kurl.h>
 #include <krun.h>
@@ -68,6 +67,11 @@ KJFilename::KJFilename(const QStringList &l, KJLoader *p)
 	killTimers();
 }
 
+KJFilename::~KJFilename()
+{
+	delete mBack;
+}
+
 void KJFilename::paint(QPainter *p, const QRect &)
 {
 	QPixmap temp ( rect().width(), rect().height() );
@@ -132,14 +136,15 @@ void KJFilename::mouseRelease(const QPoint &, bool in)
 
 void KJFilename::readConfig()
 {
-	kdDebug(66666) << "KJFilename::readConfig()" << endl;
+//	kdDebug(66666) << "KJFilename::readConfig()" << endl;
 	mDistance = (int)( textFont().fontWidth() * KJLoader::kjofol->prefs()->titleMovingDistance() );
 	if ( mDistance <= 0 )
 		mDistance = 1;
 	mTimerUpdates = KJLoader::kjofol->prefs()->titleMovingUpdates();
+	textFont().recalcSysFont();
+	mLastTitle=""; // invalidate title so it gets repainted on next timeUpdate()
 }
 
-
 void KJFilename::prepareString(const QCString &str)
 {
 	killTimers(); // i.e. stop timers
@@ -149,7 +154,6 @@ void KJFilename::prepareString(const QCString &str)
 	startTimer(mTimerUpdates);
 }
 
-
 void KJFilename::timeUpdate(int)
 {
 	if ( !napp->player()->current() ) // just for safety
@@ -167,7 +171,6 @@ void KJFilename::timeUpdate(int)
 	prepareString ( title + " (" + timestring + ")   ");
 }
 
-
 QString KJFilename::tip()
 {
 	if ( !napp->player()->current() ) // just for safety
@@ -182,7 +185,7 @@ QString KJFilename::tip()
  *******************************************/
 
 KJTime::KJTime(const QStringList &l, KJLoader *p)
-	: KJWidget(p)
+	: KJWidget(p), mBack(0)
 {
 	int x  = l[1].toInt();
 	int y  = l[2].toInt();
@@ -212,6 +215,11 @@ KJTime::KJTime(const QStringList &l, KJLoader *p)
 	prepareString("00:00");
 }
 
+KJTime::~KJTime()
+{
+	delete mBack;
+}
+
 void KJTime::paint(QPainter *p, const QRect &)
 {
 //	kdDebug(66666) << "KJTime::paint(QPainter *p, const QRect &)" << endl;
@@ -238,17 +246,18 @@ void KJTime::mouseRelease(const QPoint &, bool in)
 		return;
 
 	countDown = !countDown;
-	KJLoader::kjofol->prefs()->setTimeCountMode( countDown );
+	napp->setDisplayRemaining( countDown );
+//	KJLoader::kjofol->prefs()->setTimeCountMode( countDown );
 }
 
-
 void KJTime::readConfig()
 {
 //	kdDebug(66666) << "KJTime::readConfig()" << endl;
-	countDown = KJLoader::kjofol->prefs()->timeCountMode();
+	countDown = napp->displayRemaining();
+	timeFont().recalcSysFont();
+	mLastTime=""; // invalidate time so it gets repainted on next timeUpdate()
 }
 
-
 QString KJTime::lengthString ( void )
 {
 	int pos = 0;
@@ -296,7 +305,6 @@ QString KJTime::lengthString ( void )
 	return posString;
 }
 
-
 void KJTime::timeUpdate(int)
 {
 //	kdDebug(66666) << "START KJTime::timeUpdate(int)" << endl;
@@ -335,7 +343,7 @@ QString KJTime::tip()
  *******************************************/
 
 KJVolumeText::KJVolumeText(const QStringList &l, KJLoader *p)
-	: KJWidget(p)
+	: KJWidget(p), mBack(0)
 {
 	int x=l[1].toInt();
 	int y=l[2].toInt();
@@ -363,6 +371,11 @@ KJVolumeText::KJVolumeText(const QStringList &l, KJLoader *p)
 	prepareString("100%");
 }
 
+KJVolumeText::~KJVolumeText()
+{
+	delete mBack;
+}
+
 void KJVolumeText::paint(QPainter *p, const QRect &)
 {
 	QPixmap temp ( rect().width(), rect().height() );
@@ -382,6 +395,12 @@ bool KJVolumeText::mousePress(const QPoint &)
 	return false;
 }
 
+void KJVolumeText::readConfig()
+{
+	volumeFont().recalcSysFont();
+	mLastVolume=""; // invalidate value so it gets repainted on next timeUpdate()
+}
+
 void KJVolumeText::timeUpdate(int)
 {
 	QCString volume;
@@ -416,7 +435,7 @@ QString KJVolumeText::tip()
  *******************************************/
 
 KJPitchText::KJPitchText(const QStringList &l, KJLoader *p)
-	: KJWidget(p)
+	: KJWidget(p), mBack(0)
 {
 	int x  = l[1].toInt();
 	int y  = l[2].toInt();
@@ -442,6 +461,12 @@ KJPitchText::KJPitchText(const QStringList &l, KJLoader *p)
 	prepareString("100");
 }
 
+KJPitchText::~KJPitchText()
+{
+	delete mBack;
+}
+
+
 void KJPitchText::paint(QPainter *p, const QRect &)
 {
 	QPixmap temp ( rect().width(), rect().height() );
@@ -473,6 +498,12 @@ void KJPitchText::mouseRelease(const QPoint &, bool in)
 	pitchable.speed( 1.00f ); // reset pitch
 }
 
+void KJPitchText::readConfig()
+{
+	pitchFont().recalcSysFont();
+	mLastPitch=""; // invalidate value so it gets repainted on next timeUpdate()
+}
+
 void KJPitchText::timeUpdate(int)
 {
 	QCString speed;
@@ -512,7 +543,7 @@ QString KJPitchText::tip()
  *******************************************/
 
 KJFileInfo::KJFileInfo(const QStringList &l, KJLoader *p)
-	: KJWidget(p)
+	: KJWidget(p), mBack(0)
 {
 	mInfoType = l[0]; // type of info-display
 
@@ -542,6 +573,11 @@ KJFileInfo::KJFileInfo(const QStringList &l, KJLoader *p)
 	prepareString("");
 }
 
+KJFileInfo::~KJFileInfo()
+{
+	delete mBack;
+}
+
 void KJFileInfo::paint(QPainter *p, const QRect &)
 {
 	QPixmap temp ( rect().width(), rect().height() );
@@ -561,13 +597,19 @@ bool KJFileInfo::mousePress(const QPoint &)
 	return false;
 }
 
+void KJFileInfo::readConfig()
+{
+	textFont().recalcSysFont();
+	mLastTime=""; // invalidate value so it gets repainted on next timeUpdate()
+}
+
 void KJFileInfo::timeUpdate(int)
 {
 	if (!napp->player()->current())
 		return;
 
-	const PlaylistItem &item = napp->playlist()->current();
-    QString prop;
+	const PlaylistItem &item = napp->player()->current();
+	QString prop;
 
 	if ( mInfoType == "mp3khzwindow" )
 	{
