@@ -14,6 +14,7 @@ class KJFilename : public QObject, public KJWidget
 Q_OBJECT
 public:
 	KJFilename(const QStringList &, KJLoader *parent);
+	~KJFilename();
 
 	virtual void paint(QPainter *, const QRect &rect);
 	virtual bool mousePress(const QPoint &pos);
@@ -42,6 +43,7 @@ class KJTime : public KJWidget
 {
 public:
 	KJTime(const QStringList &, KJLoader *parent);
+	~KJTime();
 
 	virtual void paint(QPainter *, const QRect &rect);
 	virtual bool mousePress(const QPoint &pos);
@@ -71,11 +73,12 @@ class KJVolumeText : public KJWidget
 {
 public:
 	KJVolumeText(const QStringList &, KJLoader *parent);
+	~KJVolumeText();
 
 	virtual void paint(QPainter *, const QRect &rect);
 	virtual bool mousePress(const QPoint &pos);
 	virtual void timeUpdate(int);
-//	virtual void readConfig();
+	virtual void readConfig();
 
 	void prepareString(const QCString &time);
 	virtual QString tip();
@@ -92,12 +95,13 @@ class KJPitchText : public KJWidget
 {
 public:
 	KJPitchText(const QStringList &, KJLoader *parent);
+	~KJPitchText();
 
 	virtual void paint(QPainter *, const QRect &rect);
 	virtual bool mousePress(const QPoint &pos);
 	virtual void mouseRelease(const QPoint &, bool in);
 	virtual void timeUpdate(int);
-//	virtual void readConfig();
+	virtual void readConfig();
 
 	void prepareString(const QCString &time);
 	virtual QString tip();
@@ -114,11 +118,12 @@ class KJFileInfo : public KJWidget
 {
 public:
 	KJFileInfo(const QStringList &, KJLoader *parent);
+	~KJFileInfo();
 
 	virtual void paint(QPainter *, const QRect &rect);
 	virtual bool mousePress(const QPoint &pos);
 	virtual void timeUpdate(int);
-//	virtual void readConfig();
+	virtual void readConfig();
 
 	void prepareString(const QCString &time);
 	virtual QString tip();
