@@ -12,12 +12,14 @@
 // system includes
 #include <qtextstream.h>
 #include <qimage.h>
+#include <qfile.h>
 #include <kdebug.h>
 #include <kmimemagic.h>
 #include <kurl.h>
 
 Parser::Parser() : QDict<QStringList>(17,false)
 {
+	mSkinAbout="";
 	mImageCache.setAutoDelete(true);
 	setAutoDelete(true);
 }
@@ -31,6 +33,7 @@ void Parser::open(const QString &file)
 {
 	clear();
 	mImageCache.clear();
+	mSkinAbout="";
 	mDir=KURL(file).directory();
 	QFile f(file);
 	if ( !f.exists() )
@@ -47,7 +50,20 @@ void Parser::open(const QString &file)
 			continue;
 		QStringList *l=new QStringList(QStringList::split(" ", (line.lower())));
 		QString first=l->first();
-		insert(first, l);
+
+ 		// special handling for about-texts as the key "about" can appear multiple
+		// times and thus does not fit into qdict.
+ 		if (first=="about")
+		{
+			if (!mSkinAbout.isEmpty())
+				mSkinAbout+="\n";
+
+			mSkinAbout += line.mid(6);
+//			kdDebug(66666) << "found About-line, mSkinAbout is now '" << mSkinAbout << "'" << endl;
+			delete l; // don't need the stringlist anymore
+		}
+		else
+			insert(first, l);
 	}
 }
 
