@@ -8,17 +8,17 @@
 // to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 // copies of the Software, and to permit persons to whom the Software is
 // furnished to do so, subject to the following conditions:
-// 
+//
 // The above copyright notice and this permission notice shall be included in
 // all copies or substantial portions of the Software.
-// 
+//
 // THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 // IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 // FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 // THE AUTHOR(S) BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 // AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 // CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
-// 
+//
 // Except as contained in this notice, the name(s) of the author(s) shall not be
 // used in advertising or otherwise to promote the sale, use or other dealings
 // in this Software without prior written authorization from the author(s).
@@ -71,7 +71,7 @@ Marquis::Marquis()
 {
 	NOATUNPLUGINC(Marquis);
 	hide();
-	kdDebug(66666) << "number of members == " << memberList->count() << endl;
+	kdDebug(66666) << k_funcinfo << "number of members == " << memberList->count() << endl;
 
 // for testing: uncomment this and use
 // dcop `dcop | grep noatun` Marquis activateAction dynamicRestore
@@ -87,14 +87,14 @@ Marquis::~Marquis()
 
 void Marquis::restore(void)
 {
-	kdDebug(66666) << "Marquis::restore()" << endl;
+	kdDebug(66666) << k_funcinfo << endl;
 	dynamicRestore();
 }
 
 // unload every window, and save the config as QStringList of those loaded
 void Marquis::saveSessionConfig(KConfig *c)
 {
-	kdDebug(66666) << "Marquis::saveSessionConfig()" << endl;
+	kdDebug(66666) << k_funcinfo << endl;
 
 	Player *player = napp->player();
 	c->writeEntry("Volume", player->volume());
@@ -106,10 +106,10 @@ void Marquis::saveSessionConfig(KConfig *c)
 	{
 		KURL songURL = player->current().url();
 		songURL.setPass( QString::null ); // don't save passwords
-		c->writeEntry("Current Song", songURL.url());
+		c->writePathEntry("Current Song", songURL.url());
 	}
 	else
-		c->writeEntry("Current Song", QString::null);
+		c->writePathEntry("Current Song", QString::null);
 
 	c->writeEntry("Current Position", player->getTime());
 	c->writeEntry("PlayStatus", getPlayStatus( player ));
@@ -146,7 +146,23 @@ void Marquis::readSessionConfig(KConfig *c)
 	napp->libraryLoader()->loadAll(list);
 
 	Player *player = napp->player();
+	player->setVolume( 0 );
 	player->loop( c->readNumEntry("Loop Style", (int) Player::None) );
+	if ( c->readBoolEntry( "Playlist Visible", false ))
+		napp->playlist()->showList();
+
+// this is broken (pfeiffer)
+//	KURL songURL = c->readPathEntry("Current Song");
+// kdDebug(66666) << "song: " << songURL.url() << endl;
+//	if ( songURL.isValid() )
+//	{
+// kdDebug(66666) << "is Valid, setting as current now!" << endl;
+//		napp->playlist()->addFile( songURL, true );
+//		int position = c->readNumEntry("Current Position", 0);
+//		player->skipTo( position );
+//		setPlayStatus( player, c->readNumEntry("PlayStatus", 0) );
+//	}
+
 	player->setVolume( c->readNumEntry("Volume", 100) );
 }
 
@@ -159,7 +175,7 @@ void Marquis::dynamicSave()
 void Marquis::dynamicRestore()
 {
 	KConfig config( "marquisrc" );
-	readSessionConfig( &config );	
+	readSessionConfig( &config );
 }
 
 #include "marquis.moc"
