@@ -34,7 +34,6 @@ SplitPlaylist::~SplitPlaylist()
 
 void SplitPlaylist::reset()
 {
-	previousItem=0;
 	SafeListViewItem *i;
 	setCurrent(i=static_cast<SafeListViewItem*>(view->listView()->firstChild()), false);
 	if (i && !i->isOn())
@@ -48,14 +47,18 @@ PlaylistItem SplitPlaylist::next()
 
 PlaylistItem SplitPlaylist::next(bool play)
 {
+	PlaylistItem nextItem;
+
 	if (napp->player()->loopStyle() == Player::Random)
 	{
 		// Ignore all this order stuff and select a random item
 		List *lview = view->listView();
 
 		if (lview->childCount())
-		{	
-			SafeListViewItem *slvi = static_cast<SafeListViewItem*>(lview->itemAtIndex(KApplication::random() % lview->childCount()));
+		{
+			SafeListViewItem *slvi = static_cast<SafeListViewItem*>(
+					lview->itemAtIndex(KApplication::random() % lview->childCount())
+				);
 			nextItem = PlaylistItem(slvi);
 		}
 		else
@@ -63,15 +66,28 @@ PlaylistItem SplitPlaylist::next(bool play)
 			nextItem = 0;
 		}
 	}
+	else
+	{
+		if(!current())
+		{
+			nextItem = static_cast<SafeListViewItem*>(static_cast<SafeListViewItem*>(getFirst().data()));
+		}
+		else
+		{
+			nextItem = static_cast<SafeListViewItem*>(
+				static_cast<SafeListViewItem*>(current().data())->itemBelow());
+		}
+	}
 
-	if (!nextItem) return 0;
+	if (!nextItem) // don't set a null-item as current item
+		return 0;
 
 	PlaylistItem oldCurrent = currentItem;
 	setCurrent(nextItem, play);
 
 	// Hack for back button on randomized play
 	if (oldCurrent)
-		previousItem = oldCurrent;
+		randomPrevious = oldCurrent;
 
 	if (currentItem)
 		if (!static_cast<SafeListViewItem*>(currentItem.data())->isOn())
@@ -87,8 +103,46 @@ PlaylistItem SplitPlaylist::current()
 
 PlaylistItem SplitPlaylist::previous()
 {
-	if (!previousItem) return 0;
-	setCurrent(previousItem);
+	if (napp->player()->loopStyle() == Player::Random && randomPrevious)
+	{
+		List *list = view->listView();
+		// check if the item still exists (hackitude: 50%)
+		bool found=false;
+		for (QListViewItem *i = list->firstChild(); i; i = i->nextSibling())
+		{
+			if (i == static_cast<SafeListViewItem*>(randomPrevious.data()))
+			{
+				found = true;
+				break;
+			}
+		}
+
+		if (found)
+		{
+			// setCurrent modified randomPrevious, and setCurrent is pass-by-reference
+			PlaylistItem prev = randomPrevious;
+
+			setCurrent(prev);
+			return currentItem;
+		}
+	}
+	// there's a possibility that I will fall out to here
+	// from the above branch
+
+	PlaylistItem nextItem;
+	if(!current())
+	{
+		nextItem = static_cast<SafeListViewItem*>(static_cast<SafeListViewItem*>(getFirst().data()));
+	}
+	else
+	{
+		nextItem = static_cast<SafeListViewItem*>(
+			static_cast<SafeListViewItem*>(current().data())->itemAbove());
+	}
+	if (!nextItem) // don't set a null-item as current item
+		return 0;
+
+	setCurrent(nextItem);
 
 	if (currentItem)
 		if (!static_cast<SafeListViewItem*>(currentItem.data())->isOn())
@@ -134,11 +188,6 @@ void SplitPlaylist::addFile(const KURL &file, bool play)
 	view->addFile(file, play);
 }
 
-void SplitPlaylist::setNext(const PlaylistItem &i)
-{
-	nextItem=i;
-}
-
 void SplitPlaylist::setCurrent(const PlaylistItem &i)
 {
 	setCurrent(i, true);
@@ -146,6 +195,7 @@ void SplitPlaylist::setCurrent(const PlaylistItem &i)
 
 void SplitPlaylist::setCurrent(const PlaylistItem &i, bool emitC)
 {
+	randomPrevious = PlaylistItem();
 	emitC = emitC && currentItem;
 	if (!i)
 	{
@@ -157,31 +207,23 @@ void SplitPlaylist::setCurrent(const PlaylistItem &i, bool emitC)
 		SafeListViewItem *now=static_cast<SafeListViewItem*>(current().data());
 		if (now)
 			now->setPixmap(0, QPixmap());
-		
+
 		QRect rect(view->listView()->itemRect(static_cast<SafeListViewItem*>(current().data())));
 		rect.setWidth(view->listView()->viewport()->width());
 		currentItem=i;
 		view->listView()->viewport()->repaint(rect,true);
-	
+
 		view->listView()->ensureItemVisible(static_cast<SafeListViewItem*>(current().data()));
 		QRect currentRect= view->listView()->itemRect(static_cast<SafeListViewItem*>(current().data()));
 		view->listView()->viewport()->repaint(currentRect);
-	
-		setNext(static_cast<SafeListViewItem*>(static_cast<SafeListViewItem*>(current().data())->itemBelow()));
-		setPrevious(static_cast<SafeListViewItem*>(static_cast<SafeListViewItem*>(current().data())->itemAbove()));
 
 		now=static_cast<SafeListViewItem*>(current().data());
-		if (now)
+		if(now)
 			now->setPixmap(0, ::SmallIcon("noatunplay"));
 	}
 
 	if (emitC && !exiting())
-		playCurrent();
-}
-
-void SplitPlaylist::setPrevious(const PlaylistItem &i)
-{
-	previousItem=i;
+		emit playCurrent();
 }
 
 void SplitPlaylist::remove(const PlaylistItem &)
@@ -204,7 +246,7 @@ void SplitPlaylist::randomize()
 	// eeeeevil :)
 	QPtrList<void> list;
 	QPtrList<QListViewItem> items;
-	for ( int i = 0; i < lview->childCount(); i++ )
+	for(int i = 0; i < lview->childCount(); i++)
 	{
 		list.append( (void*) i );
 		items.append( lview->itemAtIndex( i ) );
@@ -213,10 +255,9 @@ void SplitPlaylist::randomize()
 	KRandomSequence seq;
 	seq.randomize( &list );
 
-	for ( int i = 0; i < lview->childCount(); i++ )
+	for(int i = 0; i < lview->childCount(); i++)
 	{
-		lview->moveItem( items.take(), 0,
-				 lview->itemAtIndex( (int) list.take() ) );
+		items.take()->moveItem(lview->itemAtIndex((int) list.take()));
 	}
 
 	setCurrent(currentItem, false);
