@@ -16,6 +16,7 @@
 #include <qmap.h>
 #include <qregexp.h>
 #include <qtextstream.h>
+#include <qpainter.h>
 
 #include <kaction.h>
 #include <kdebug.h>
@@ -57,18 +58,10 @@ SafeListViewItem::SafeListViewItem(QListView *parent, QListViewItem *after, cons
 	//	if (!isDownloaded()) setText(1, "0%");
 
 //	mProperties.setAutoDelete(true);
-	
-	SplitPlaylist *p=SPL;
-	if (!(p->currentItem || p->nextItem || p->previousItem))
-		p->setCurrent(this);
-	if (p->currentItem==(SafeListViewItem*)itemAbove())
-		p->setNext(this);
-	if (p->currentItem==(SafeListViewItem*)itemBelow())
-		p->setPrevious(this);
 
 	if (!streamable() && enqueue(url()))
 		setUrl(KURL(localFilename()));
-	
+
 	PlaylistItemData::added();
 }
 
@@ -101,18 +94,6 @@ SafeListViewItem::SafeListViewItem(QListView *parent, QListViewItem *after, cons
 	static_cast<KListView*>(parent)->moveItem(this, 0, after);
 	modified();
 
-	//	if (!isDownloaded()) setText(1, "0%");
-
-//	mProperties.setAutoDelete(true);
-	
-	SplitPlaylist *p=SPL;
-	if (!(p->currentItem || p->nextItem || p->previousItem))
-		p->setCurrent(this);
-	if (p->currentItem==(SafeListViewItem*)itemAbove())
-		p->setNext(this);
-	if (p->currentItem==(SafeListViewItem*)itemBelow())
-		p->setPrevious(this);
-
 	if (!streamable() && enqueue(url()))
 	{
 		KURL u;
@@ -140,15 +121,15 @@ static void pad(QString &str)
 	int blocklen=0;
 
 	static const int paddingsize=12;
-	
+
 	// not static for reason
-	const QChar chars[paddingsize] = 
+	const QChar chars[paddingsize] =
 	{
 		QChar('0'), QChar('0'), QChar('0'), QChar('0'),
 		QChar('0'), QChar('0'), QChar('0'), QChar('0'),
 		QChar('0'), QChar('0'), QChar('0'), QChar('0')
 	};
-	
+
 	for (int i=0; i < len; i++)
 	{
 		if (str[i].isNumber())
@@ -228,7 +209,7 @@ void SafeListViewItem::clearProperty(const QString &n)
 		modified();
 		return;
 	}
-	
+
 	for (QValueList<Property>::Iterator i=mProperties.begin(); i != mProperties.end(); ++i)
 	{
 		if ((*i).key==n)
@@ -278,19 +259,19 @@ void SafeListViewItem::downloadFinished()
 void SafeListViewItem::modified()
 {
 	bool widthChangeNeeded = false;
-	
+
 	if (text(0)!=title())
 	{
 		setText(0, title());
 		widthChangeNeeded = true;
 	}
-	
+
 	if (isDownloaded() && length()!=-1 && text(1)!=lengthString())
 	{
 		setText(1, lengthString());
 		widthChangeNeeded = true;
 	}
-	
+
 	if (widthChangeNeeded)
 		widthChanged(-1);
 
@@ -312,6 +293,20 @@ void SafeListViewItem::stateChange(bool s)
 		QCheckListItem::stateChange(s);
 }
 
+void SafeListViewItem::paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int align)
+{
+	QCheckListItem::paintCell(p, cg, column, width, align);
+
+	if (SPL->current() == this)
+	{
+		p->save();
+		p->setRasterOp(XorROP);
+		p->fillRect(0, 0, width, height(), QColor(255,255,255));
+
+		p->restore();
+	}
+}
+
 void SafeListViewItem::remove()
 {
 	removed=true;
@@ -323,21 +318,24 @@ void SafeListViewItem::remove()
 	}
 	else if (napp->player()->current()==this)
 	{
-		SPL->setCurrent(0);
-		napp->player()->playCurrent();
+//		SPL->setCurrent(0);
+//		napp->player()->playCurrent();
 		if (!SPL->exiting())
 			napp->player()->forward();
 	}
 
-	if (SPL->nextItem==this)
-		SPL->setNext(static_cast<SafeListViewItem*>(itemBelow()));
-	if (SPL->currentItem==this) // just optimizing for least unreadably
-		SPL->setCurrent(0), SPL->setNext(static_cast<SafeListViewItem*>(itemBelow()));
-	if (SPL->previousItem==this)
-		SPL->setPrevious(static_cast<SafeListViewItem*>(itemAbove()));
-
 	if (listView())
+	{
+		if (SPL->currentItem==this) // just optimizing for least unreadably
+			SPL->setCurrent(static_cast<SafeListViewItem*>(itemBelow()));
+
 		listView()->takeItem(this);
+	}
+	else if (SPL->currentItem==this)
+	{
+		SPL->setCurrent(0);
+	}
+
 	PlaylistItemData::removed();
 }
 
@@ -353,7 +351,7 @@ List::List(View *parent)
 	setItemsMovable(true);
 	setSelectionMode(QListView::Extended);
 	connect(this, SIGNAL(dropped(QDropEvent*, QListViewItem*)), SLOT(dropEvent(QDropEvent*, QListViewItem*)));
-	connect(this, SIGNAL(moved(QPtrList<QListViewItem>&,QPtrList<QListViewItem>&,QPtrList<QListViewItem>&)), SLOT(move(QPtrList<QListViewItem>&,QPtrList<QListViewItem>&,QPtrList<QListViewItem>&)));
+	connect(this, SIGNAL(moved()), SLOT(move()));
 	connect(this, SIGNAL(aboutToMove()), parent, SLOT(setNoSorting()));
 	connect(this, SIGNAL(deleteCurrentItem()), parent, SLOT(deleteSelected()));
 }
@@ -362,28 +360,14 @@ List::~List()
 {
 }
 
-void List::move(QPtrList<QListViewItem>& item, QPtrList<QListViewItem>&, QPtrList<QListViewItem>&)
+void List::move()
 {
-	bool bidimerge=static_cast<bool>(item.containsRef(static_cast<SafeListViewItem*>(SPL->currentItem.data())));
-	bool current=SPL->currentItem;
-	if (current)
-	{
-		if (bidimerge || item.containsRef(static_cast<SafeListViewItem*>(SPL->previousItem.data()))
-		              || (current && item.containsRef(static_cast<SafeListViewItem*>(SPL->currentItem.data())->itemAbove())))
-			SPL->setPrevious(static_cast<SafeListViewItem*>(static_cast<SafeListViewItem*>(SPL->currentItem.data())->itemAbove()));
-	
-		if (bidimerge || item.containsRef(static_cast<SafeListViewItem*>(SPL->nextItem.data()))
-		              || item.containsRef(static_cast<SafeListViewItem*>(static_cast<SafeListViewItem*>(SPL->currentItem.data())->itemBelow())))
-			SPL->setNext(static_cast<SafeListViewItem*>(static_cast<SafeListViewItem*>(SPL->currentItem.data())->itemBelow()));
-	}
-
-
 	emit modified();
 }
 
 bool List::acceptDrag(QDropEvent *event) const
 {
-	return QUriDrag::canDecode(event) || KListView::acceptDrag(event);
+	return KURLDrag::canDecode(event) || KListView::acceptDrag(event);
 }
 
 void List::dropEvent(QDropEvent *event, QListViewItem *after)
@@ -401,29 +385,6 @@ void List::dropEvent(QDropEvent *event, QListViewItem *after)
 	emit modified();
 }
 
-void List::viewportPaintEvent(QPaintEvent *e)
-{
-	KListView::viewportPaintEvent(e);
-
-	static bool recurse=false;
-	if (!recurse && SPL->current())
-	{
-		QListViewItem *current=static_cast<SafeListViewItem*>(SPL->current().data());
-		QRect item(itemRect(current).intersect(e->rect()));
-		if (item.isEmpty()) return;
-
-		QPixmap pix(e->rect().width(), e->rect().height());
-		pix.fill(QColor(255,255,255));
-
-		recurse=true;
-		viewport()->repaint(item,true);
-		recurse=false;
-
-		bitBlt(viewport(), item.topLeft(), &pix,
-		       QRect(0,0, item.width(), item.height()), XorROP,false);
-	}
-}
-
 void List::keyPressEvent(QKeyEvent *e)
 {
 	if (e->key()==Key_Enter || e->key()==Key_Return)
@@ -447,7 +408,7 @@ void List::keyPressEvent(QKeyEvent *e)
 	}
 
 	KListView::keyPressEvent(e);
-	
+
 
 }
 
@@ -466,13 +427,13 @@ public:
 	}
 
 	QListViewItem *getAfter() { return after;}
-	
+
 protected:
 	virtual void readItem(const QMap<QString,QString> &properties)
 	{
 		after=new SafeListViewItem(mList, after, properties);
 	}
-	
+
 	virtual PlaylistItem writeItem()
 	{
 		if (!after)
@@ -488,10 +449,18 @@ protected:
 };
 
 
-void View::saveToURL(const KURL &url)
+bool View::saveToURL(const KURL &url)
 {
 	NoatunSaver saver(list);
-	saver.save(url);
+	if(saver.save(url))
+	{
+		return true;
+	}
+	else
+	{
+		KMessageBox::error( this, i18n("Could not write to %1.").arg(url.prettyURL()) );
+		return false;
+	}
 }
 
 void View::exportTo(const KURL &url)
@@ -512,7 +481,7 @@ void View::exportTo(const KURL &url)
 	}
 	saver.close();
 
-	KIO::NetAccess::upload(local, url);
+	KIO::NetAccess::upload(local, url, this);
 
 	saver.remove();
 }
@@ -522,7 +491,7 @@ QListViewItem *List::openGlobal(const KURL &u, QListViewItem *after)
 	clear();
 	NoatunSaver saver(this, after);
 	saver.metalist(u);
-	
+
 	return saver.getAfter();
 }
 
@@ -536,7 +505,7 @@ QListViewItem *List::importGlobal(const KURL &u, QListViewItem *after)
 //		SPL->listItemSelected(after);
 		return after;
 	}
-	
+
 	return saver.getAfter();
 }
 
@@ -656,7 +625,7 @@ View::View(SplitPlaylist *)
 	connect(list->header(),SIGNAL(clicked(int)),this,SLOT(headerClicked(int)) );
 
 	mOpen=new KAction(i18n("Add &Files..."), "queue", 0, this, SLOT(addFiles()), actionCollection(), "add_files");
-	(void) new KAction(i18n("Add &Directories..."), "folder", 0, this, SLOT(addDirectory()),  actionCollection(), "add_dir");
+	(void) new KAction(i18n("Add Fol&ders..."), "folder", 0, this, SLOT(addDirectory()),  actionCollection(), "add_dir");
 	mDelete=new KAction(i18n("Delete"), "editdelete", Key_Delete, this, SLOT(deleteSelected()),  actionCollection(), "delete");
 
 	mClose=KStdAction::close(this, SLOT(close()), actionCollection());
@@ -795,7 +764,7 @@ void View::init()
 {
 	// see if we are importing an old-style list
 	bool importing= ! QFile(napp->dirs()->saveLocation("data", "noatun/") + "splitplaylist.xml").exists();
-	
+
 	if (importing)
 	{
 		KURL internalURL;
@@ -815,7 +784,10 @@ void View::init()
 
 	// this has to come after openGlobal, since openGlobal emits modified()
 	setModified(config.readBoolEntry("modified", false));
-	mPlaylistFile.setPath(config.readEntry("file", QString::null));
+	QString path = config.readPathEntry("file");
+	// don't call setPath with an empty path, that would make the url "valid"
+	if ( !path.isEmpty() )
+		mPlaylistFile.setPath(path);
 
 	SPL->reset();
 	int saved = config.readNumEntry("current", 0);
@@ -831,15 +803,21 @@ void View::init()
 
 void View::save()
 {
-	if (mPlaylistFile.isMalformed()) { saveAs(); return; }
-	saveToURL(mPlaylistFile);
-	setModified(false);
+	if(mPlaylistFile.isEmpty() || !mPlaylistFile.isValid())
+	{
+		saveAs();
+		return;
+	}
+
+	if(saveToURL(mPlaylistFile))
+		setModified(false);
 }
 
 void View::saveAs()
 {
 	KURL u=KFileDialog::getSaveURL(0, "*.xml splitplaylistdata *.pls *.m3u\n*", this, i18n("Save Playlist"));
-	if (u.isMalformed()) return;
+	if(!u.isValid())
+		return;
 	mPlaylistFile = u;
 	save();
 }
@@ -847,7 +825,8 @@ void View::saveAs()
 void View::open()
 {
 	KURL u=KFileDialog::getOpenURL(0, "*.xml splitplaylistdata *.pls *.m3u\n*", this, i18n("Insert Playlist"));
-	if (u.isMalformed()) return;
+	if(!u.isValid())
+		return;
 	list->openGlobal(u);
 	setModified(false);
 }
@@ -855,7 +834,8 @@ void View::open()
 void View::openNew()
 {
 	KURL u=KFileDialog::getOpenURL(0, "*.xml splitplaylistdata *.pls *.m3u\n*", this, i18n("Open New Playlist"));
-	if (u.isMalformed()) return;
+	if(!u.isValid())
+		return;
 	mPlaylistFile = u;
 
 	listView()->clear();
@@ -882,7 +862,7 @@ void View::deleteSelected()
 
 void View::addFiles()
 {
-	KURL::List files=KFileDialog::getOpenURLs(0, napp->mimeTypes(), this, i18n("Select File to Play"));
+	KURL::List files=KFileDialog::getOpenURLs(":mediadir", napp->mimeTypes(), this, i18n("Select File to Play"));
 
 	QListViewItem *last = list->lastItem();
 	for(KURL::List::Iterator it=files.begin(); it!=files.end(); ++it)
@@ -893,7 +873,7 @@ void View::addFiles()
 
 void View::addDirectory()
 {
-	QString file=KFileDialog::getExistingDirectory(0, this, i18n("Select Directory"));
+	QString file=KFileDialog::getExistingDirectory(0, this, i18n("Select Folder"));
 
 	if (!file) return;
 	KURL url;
@@ -935,10 +915,10 @@ void View::saveState(void)
 	config.setGroup("splitplaylist");
 
 	config.writeEntry("modified", modified);
-	config.writeEntry("file", mPlaylistFile.path());
+	config.writePathEntry("file", mPlaylistFile.path());
 	saveToURL(napp->dirs()->saveLocation("data", "noatun/") + "splitplaylist.xml");
 
-	int i;
+	unsigned int i;
 	PlaylistItem item=SPL->getFirst();
 	for(i = 0; item && item != SPL->current(); )
 		item=SPL->getAfter(item), i++;
@@ -954,12 +934,12 @@ void View::configureToolBars()
 	saveMainWindowSettings(KGlobal::config(), "SPL Window");
 	KEditToolbar dlg(actionCollection(), "splui.rc");
 	connect(&dlg, SIGNAL(newToolbarConfig()), SLOT(newToolBarConfig()));
-	if (dlg.exec())
-		createGUI("splui.rc");
+	dlg.exec();
 }
 
 void View::newToolBarConfig()
 {
+	createGUI("splui.rc");
 	applyMainWindowSettings(KGlobal::config(), "SPL Window");
 }
 
