@@ -23,6 +23,9 @@
 // used in advertising or otherwise to promote the sale, use or other dealings
 // in this Software without prior written authorization from the author(s).
 
+#include "cmodule.h"
+#include "systray.h"
+
 #include <kconfig.h>
 #include <kdialog.h>
 #include <kglobal.h>
@@ -35,18 +38,17 @@
 #include <noatun/app.h>
 #include <noatun/pluginloader.h>
 
-#include "cmodule.h"
-#include "systray.h"
-
 YHModule::YHModule(QObject *_parent)
 	: CModule(i18n("Young Hickory"), i18n("Configure System Tray Icon"), "noatuntrayplay", _parent)
 {
-	QVBoxLayout *layout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
+	QVBoxLayout *layout = new QVBoxLayout(this, 0, KDialog::spacingHint());
 
 	tip = new QCheckBox(i18n("Show a tooltip for the current track"), this);
 	passivePopup = new QCheckBox(i18n("Announce tracks with a popup window"), this);
+	connect(passivePopup, SIGNAL(toggled(bool)), this, SLOT(slotPassivePopupChanged(bool)));
+	passivePopupCovers = new QCheckBox(i18n("Show covers in popup window"), this);
 
-	icon = new QButtonGroup(1, Horizontal, i18n("State Icon Display"), this);
+	icon = new QButtonGroup(1, Horizontal, i18n("State Icon Display"), this, "icon");
 	icon->setExclusive(true);
 	new QRadioButton(i18n("Blink"), icon);
 	new QRadioButton(i18n("Show"), icon);
@@ -54,6 +56,7 @@ YHModule::YHModule(QObject *_parent)
 
 	layout->addWidget(tip);
 	layout->addWidget(passivePopup);
+	layout->addWidget(passivePopupCovers);
 	layout->addWidget(icon);
 	layout->addStretch();
 
@@ -69,6 +72,7 @@ void YHModule::save(void)
 	config.writeEntry("icon", iconPressed);
 	config.writeEntry("tip", tip->isChecked());
 	config.writeEntry("passivePopup", passivePopup->isChecked());
+	config.writeEntry("passivePopupCovers", passivePopupCovers->isChecked());
 	config.sync();
 
 	applySettings();
@@ -78,21 +82,27 @@ void YHModule::reopen(void)
 {
 	KConfig &config = *(KGlobal::config());
 	config.setGroup("Young Hickory");
-	static_cast<QRadioButton *>(icon->find(config.readLongNumEntry("icon", 0)))->setChecked(true);
+	static_cast<QRadioButton *>(icon->find(config.readLongNumEntry("icon", 1)))->setChecked(true);
 	tip->setChecked(config.readBoolEntry("tip", true));
 	passivePopup->setChecked(config.readBoolEntry("passivePopup", true));
+	passivePopupCovers->setChecked(config.readBoolEntry("passivePopupCovers", true));
 }
 
 void YHModule::applySettings()
 {
 	NoatunSystray *yh = NoatunSystray::jasonkb;
-	if(yh)
-	{
-		int iconPressed = icon->id(icon->selected());
-		yh->setBlink((NoatunSystray::Blink)iconPressed);
-		yh->setTip(tip->isChecked());
-		yh->setPassivePopup(passivePopup->isChecked());
-	}
+	if(!yh) return;
+
+	int iconPressed = icon->id(icon->selected());
+	yh->setBlink((NoatunSystray::Blink)iconPressed);
+	yh->setTip(tip->isChecked());
+	yh->setPassivePopup(passivePopup->isChecked());
+	yh->setShowCovers(passivePopupCovers->isChecked());
+}
+
+void YHModule::slotPassivePopupChanged(bool check)
+{
+	passivePopupCovers->setEnabled(check);
 }
 
 #include "cmodule.moc"
