@@ -45,7 +45,11 @@ private:
 	void applySettings();
 	QCheckBox *tip;
 	QCheckBox *passivePopup;
+	QCheckBox *passivePopupCovers;
 	QButtonGroup *icon;
+
+private slots:
+	void slotPassivePopupChanged(bool);
 };
 
 #endif
