@@ -38,6 +38,7 @@ class KPopupMenu;
 class KToggleAction;
 class KitSystemTray;
 class Player;
+class QTimer;
 
 class KPassivePopup;
 
@@ -49,11 +50,12 @@ public:
 	NoatunSystray();
 	virtual ~NoatunSystray();
 	void load(const QString& url);
-	virtual void init(void);
+	virtual void init();
 
 	void setBlink(Blink);
 	void setTip(bool);
 	void setPassivePopup(bool pop);
+	void setShowCovers(bool);
 
 	static NoatunSystray *jasonkb;
 
@@ -65,16 +67,16 @@ public slots:
 	void slotStopped();
 	void slotPaused();
 
-	void changeLoopType(int t);
-
 private slots:
-	void changeTray(const QPixmap &);
+	void changeTray(const QString &);
 
-	void blinkTimer(void);
+	void slotBlinkTimer();
 	void showPassivePopup();
+	QPixmap *renderIcon(const QString &, const QString &) const;
 
 private:
-	QPixmap *trayDefault, *trayStatus;
+	QTimer *mBlinkTimer;
+	QPixmap *trayStatus, *trayBase;
 	bool showingTrayStatus;
 	Blink blink;
 	KitSystemTray *mTray;
@@ -83,12 +85,16 @@ private:
 	bool tip;
 	QString tipText;
 
-	KAction *mBack, *mStop, *mPlay, *mForward, *mLoop;
+	void updateCover();
+	void removeCover();
+	QString tmpCoverPath;
+	bool mShowCovers;
+
+	KAction *mBack, *mStop, *mPlay, *mForward;
 	KToggleAction *mPlaylist;
 	KPopupMenu *menu;
 	KXMLGUIFactory *factory;
 	KPassivePopup *mPassivePopup;
-	QTimer mTimer;
 };
 
 #endif
