@@ -22,6 +22,7 @@
 #include <kstdaction.h>
 #include <kaction.h>
 #include <qdragobject.h>
+#include <kstandarddirs.h>
 #include <kwin.h>
 #include <time.h>
 
@@ -79,7 +80,7 @@ WaSkin::WaSkin() : UserInterface()
     KWin::setType(this->winId(), NET::Override);
     setBackgroundMode(NoBackground);
 
-    setAcceptDrops(true); 
+    setAcceptDrops(true);
 
     title_shaded = false;
 
@@ -148,10 +149,10 @@ void WaSkin::loadSkin(QString newSkinDir)
     if (title_shaded) {
         // waSkinModel::load() resets our skin model :(
         waSkinModel->setSkinModel(WA_MODEL_WINDOWSHADE);
-        setMask(*windowRegion->mainWindowShadeMask()); 
+        setMask(*windowRegion->mainWindowShadeMask());
     }
     else {
-        setMask(*windowRegion->mainWindowMask()); 
+        setMask(*windowRegion->mainWindowMask());
     }
 }
 
@@ -339,7 +340,7 @@ void WaSkin::shade() {
     waSkinModel->setSkinModel(WA_MODEL_WINDOWSHADE);
 
     setMinimumSize(sizeHint());
-    setMask(*windowRegion->mainWindowShadeMask()); 
+    setMask(*windowRegion->mainWindowShadeMask());
 
     title_shaded = true;
 }
@@ -348,7 +349,7 @@ void WaSkin::unshade() {
     waSkinModel->setSkinModel(WA_MODEL_NORMAL);
 
     setMinimumSize(sizeHint());
-    setMask(*windowRegion->mainWindowMask()); 
+    setMask(*windowRegion->mainWindowMask());
 
     title_shaded = false;
 }
@@ -525,7 +526,7 @@ void WaSkin::doClose() {
 void WaSkin::dragEnterEvent(QDragEnterEvent * event)
 {
     // accept uri drops only
-    event->accept(QUriDrag::canDecode(event));
+    event->accept(KURLDrag::canDecode(event));
 }
 
 void WaSkin::dropEvent(QDropEvent * event)
@@ -584,7 +585,7 @@ void WaSkin::loopChange(int loopType)
 {
     shuffle->setToggled(loopType == Player::Random);
 
-    if (loopType != Player::Random) 
+    if (loopType != Player::Random)
         repeat->setToggled(loopType != Player::None);
 }
 
@@ -687,7 +688,7 @@ void WaSkin::slotPlaying()
     }
 
     fileInfo info(napp->playlist()->current());
- 
+
     if (!info.bps())
         waBPS->setText("");
     else
@@ -717,7 +718,7 @@ void WaSkin::slotStopped()
 
     waBPS->setText("");
     waFreq->setText("");
-    setChannels(0); 
+    setChannels(0);
 
     waJumpSlider->setJumpValue(0);
     // -1 == disable jump bar
@@ -755,7 +756,7 @@ void WaSkin::keyPressEvent(QKeyEvent *e) {
             napp->player()->skipTo(napp->player()->getTime() + 5000);
 
         break;
-    
+
     case Key_Z:
         napp->player()->back();
         break;
@@ -783,7 +784,7 @@ void WaSkin::keyPressEvent(QKeyEvent *e) {
         break;
 
     case Key_R:
-        repeat->setToggled(!repeat->toggled());        
+        repeat->setToggled(!repeat->toggled());
         updateLoopStyle();
         break;
 
