@@ -134,7 +134,7 @@ void WinSkinConfig::remove()
 
     // Ask the user first
     if( KMessageBox::questionYesNo( this,
-        QString( i18n("<qt>Are you sure you want to remove the <b>%1</b> skin?</qt>") ).arg( skin_list->currentText() ) )
+        i18n("<qt>Are you sure you want to remove the <b>%1</b> skin?</qt>").arg( skin_list->currentText() ) )
         == KMessageBox::Yes ) {
 
         mWaSkinManager->removeSkin( skin_list->currentText() );
