@@ -18,9 +18,6 @@
 #include <X11/Xutil.h>
 #include <X11/extensions/XShm.h>
 #include <xine.h>
-#ifndef HAVE_XINE_1
-#include <xine/video_out_x11.h>
-#endif
 
 #include "audio_fifo_out.h"
 #include "xinePlayObject.h"
@@ -71,11 +68,7 @@ protected:
     }
 
     // C -> C++ wrapper for xine API
-#ifdef HAVE_XINE_1
     static inline void xine_handle_event( void *obj, const xine_event_t *event )
-#else
-    static inline void xine_handle_event( void *obj, xine_event_t *event )
-#endif
     {
 	((xinePlayObject_impl *)obj)->xineEvent( *event );
     }
@@ -83,20 +76,12 @@ protected:
     // C -> C++ wrapper for xine API
     static inline void frame_output_cb( void *obj,
 					int video_width, int video_height,
-#ifdef HAVE_XINE_1
 					double video_pixel_aspect,
-#endif
 					int *dest_x, int *dest_y,
 					int *dest_width, int *dest_height,
-#ifdef HAVE_XINE_1
 					double *dest_pixel_aspect,
-#endif
 					int *win_x, int *win_y )
     {
-#ifndef HAVE_XINE_1
-	double video_pixel_aspect = 1.0;
-	double *dest_pixel_aspect = &video_pixel_aspect;
-#endif
 	((xinePlayObject_impl *)obj)->frameOutput( *win_x, *win_y,
 						   *dest_width, *dest_height,
 						   *dest_pixel_aspect,
@@ -110,19 +95,11 @@ protected:
     // C -> C++ wrapper for xine API
     static inline void dest_size_cb( void *obj,
 				     int video_width, int video_height,
-#ifdef HAVE_XINE_1
 				     double video_pixel_aspect,
 				     int *dest_width, int *dest_height,
 				     double *dest_pixel_aspect )
-#else
-				     int *dest_width, int *dest_height )
-#endif
     {
 	int win_x, win_y;
-#ifndef HAVE_XINE_1
-	double video_pixel_aspect = 1.0;
-	double *dest_pixel_aspect = &video_pixel_aspect;
-#endif
 
 	((xinePlayObject_impl *)obj)->frameOutput( win_x, win_y,
 						   *dest_width, *dest_height,
@@ -139,22 +116,11 @@ private:
     pthread_t		 thread;
 
     // xine data
-#ifndef HAVE_XINE_1
-    config_values_t	*config;
-    bool		 xineForceXShm;
-#endif
     xine_t		*xine;
-#ifdef HAVE_XINE_1
     xine_stream_t	*stream;
     xine_event_queue_t	*queue;
     xine_audio_port_t	*ao_port;
     xine_video_port_t	*vo_port;
-#else
-    xine_t		*stream;
-    xine_t		*queue;
-    ao_driver_t		*ao_port;
-    vo_driver_t		*vo_port;
-#endif
     void		*ao_driver;
     x11_visual_t	 visual;
     xine_arts_audio	 audio;
